<?php if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'OVABRW_Abstract_Admin_Rental_Types', false ) ) {
	abstract class OVABRW_Abstract_Admin_Rental_Types {
		/**
		 * This is the name of this rental ID.
		 *
		 * @var string
		 */
		protected $ID = null;

		/**
		 * This is the name of this rental type.
		 *
		 * @var string
		 */
		protected $type = null;

		/**
		 * This is the name of this rental title.
		 *
		 * @var string
		 */
		protected $title = null;

		/**
		 * This is the prefix.
		 *
		 * @var string
		 */
		protected $prefix = OVABRW_PREFIX;

		/**
		 * This is the layout metabox.
		 *
		 * @var string
		 */
		protected $view = null;

		public function __construct() {
			add_action( 'woocommerce_product_options_general_product_data', array( $this, 'output' ) );
			add_action( 'woocommerce_process_product_meta', array( $this, 'save' ), 11, 2 );
		}

		public function set_ID( $id ) {
			$this->ID = $id;
		}

		public function get_id() {
			return $this->ID;
		}

		public function get_type() {
			return $this->type;
		}

		public function output() {
			do_action( 'ovabrw_action_before_output', $this->type, $this->view );

			if ( $this->get_value( 'price_type', 'day' ) === $this->type ) {
				include( $this->view );
			}

			do_action( 'ovabrw_action_after_output', $this->type, $this->view );
		}

		abstract public function save( $post_id, $data );

		public function get_name( $name = '' ) {
			return $this->prefix . $name;
		}

		public function get_value( $key = '', $default = false ) {
			if ( ! $this->ID ) $this->ID = get_the_ID();
			
			$value = get_post_meta( $this->ID, $this->prefix . $key, true );

			if ( $value == '' && $default != '' ) {
				$value = $default;
			}

			return $value;
		}

		public function get_html() {
			ob_start();
			include( $this->view );
			return ob_get_clean();
		}

		public function show_location( $type = 'pickup' ) {
			$show_location = $this->get_value( 'show_pickup_location_product' );

			if ( $type === 'dropoff' ) $show_location = $this->get_value( 'show_pickoff_location_product' );

			switch ( $show_location ) {
				case 'yes':
					return true;
				case 'no':
					return false;
				default:
					$categories 	= wp_get_post_terms( $this->ID, 'product_cat' );
					$term_id 		= isset( $categories[0] ) ? $categories[0]->term_id : '';
					$term_location 	= $term_id ? get_term_meta( $term_id, 'ovabrw_show_loc_booking_form', true ) : '';

					if ( $type === 'pickup' ) {
						if ( $this->is_array_exists( $term_location ) ) {
							if ( in_array( 'pickup_loc', $term_location ) ) {
								return true;
							} else {
								return false;
							}
						} else {
							if ( get_option( 'ova_brw_booking_form_show_pickup_location', 'no' ) === 'yes' ) {
								return true;
							} else {
								return false;
							}
						}
					}

					if ( $type === 'dropoff' ) {
						if ( $this->is_array_exists( $term_location ) ) {
							if ( in_array( 'dropoff_loc', $term_location ) ) {
								return true;
							} else {
								return false;
							}
						} else {
							if ( get_option( 'ova_brw_booking_form_show_pickoff_location', 'no' ) === 'yes' ) {
								return true;
							} else {
								return false;
							}
						}
					}
			}

			return true;
		}

		public function show_date( $type = 'pickup' ) {
			$show_date = $this->get_value( 'show_pickup_date_product' );

			if ( $type === 'dropoff' ) $show_date = $this->get_value( 'show_pickoff_date_product' );

			switch ( $show_date ) {
				case 'yes':
					return true;
				case 'no':
					return false;
				default:
					if ( $type === 'pickup' ) {
						if ( get_option( 'ova_brw_booking_form_show_pickup_date', 'yes' ) === 'yes' ) {
							return true;
						} else {
							return false;
						}
					}

					if ( $type === 'dropoff' ) {
						if ( get_option( 'ova_brw_booking_form_show_dropoff_date', 'yes' ) === 'yes' ) {
							return true;
						} else {
							return false;
						}
					}
			}

			return true;
		}

		public function show_quantity() {
			$show_quantity = $this->get_value( 'show_number_vehicle', 'in_setting' );
			
			switch ( $show_quantity ) {
				case 'in_setting':
					if ( get_option( 'ova_brw_booking_form_show_number_vehicle', 'yes' ) === 'yes' ) {
						return true;
					} else {
						return false;
					}
				case 'yes':
					return true;
				case 'no':
					return false;
				default:
					return true;
			}

			return true;
		}

		public function is_array_exists( $arr = [] ) {
			if ( ! empty( $arr ) && is_array( $arr ) ) {
				return true;
			}

			return false;
		}
	}
}