<?php defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'OVABRW_Admin_Ajax' ) ) {
	class OVABRW_Admin_Ajax {
		public function __construct() {
			$this->init();
		}

		public function init() {
			// Define All Ajax function
			$arr_ajax = array(
				'update_order_status_woo',
				'get_custom_tax_in_cat',
				'update_ckf',
				'change_rental_type',
				'get_rental_type_product',
				'load_data_product_create_order',
				'get_total_price_and_quantity',
				'get_dropoff_date_transportation',
				'get_packages',
				'add_specification',
				'edit_specification',
				'delete_specification',
				'sort_specifications',
				'enable_specification',
				'disable_specification',
				'change_type_specification'
			);

			foreach ( $arr_ajax as $name ) {
				add_action( 'wp_ajax_'.OVABRW_PREFIX.$name, array( $this, OVABRW_PREFIX.$name ) );
				add_action( 'wp_ajax_nopriv_'.OVABRW_PREFIX.$name, array( $this, OVABRW_PREFIX.$name ) );
			}
		}

		/**
		 * Schedule Ajax
		 */
		public function ovabrw_update_order_status_woo() {
			$order_id 			= isset( $_POST['order_id'] ) ? sanitize_text_field( $_POST['order_id'] ) : '';
			$new_order_status 	= isset( $_POST['new_order_status'] ) ? sanitize_text_field( $_POST['new_order_status'] ) : ''  ;

			if ( $order_id && $new_order_status ) {
				$order = new WC_Order($order_id);

				if ( ! current_user_can( apply_filters( 'ovabrw_update_order_status' ,'publish_posts' ) ) ) {
					echo 'error_permission';	
				} elseif ( $order->update_status( $new_order_status ) ) {
					echo 'true';
				} else {
					echo 'false';
				}
			} else {
				echo 'false';
			}
			
			wp_die();
		}

		/**
		 * Get Custom Taxonomy choosed in Category
		 */
		public function ovabrw_get_custom_tax_in_cat() {
			$checked_tax = isset( $_POST['checked_tax'] ) ?  $_POST['checked_tax'] : '';
			
			$list_tax_values = array();
			
			if ( $checked_tax ) {
				foreach ( $checked_tax as $key => $term_id ) {
					$ovabrw_custom_tax = get_term_meta($term_id, 'ovabrw_custom_tax', true);
					
					if ( $ovabrw_custom_tax ) {
						foreach ( $ovabrw_custom_tax as $key => $value ) {
							if ( ! in_array( $value, $list_tax_values ) ) {
								if ( $value ) {
									array_push( $list_tax_values, $value);		
								}
							}
						}
					}
				}
			}
			
			echo implode(",", $list_tax_values ); 
			wp_die();
		}

		/**
		 * Update CKF when sortable
		 */
		public function ovabrw_update_ckf() {
			if ( ! isset( $_POST['fields'] ) || empty( $_POST['fields'] ) ) wp_die();

			$fields = $_POST['fields'];

			if ( is_array( $fields ) ) {
				$new_fields 	= [];
				$list_fields 	= recursive_array_replace( '\\', '', get_option( 'ovabrw_booking_form', array() ) );

				foreach ( $fields as $field ) {
                    if ( ! empty( $field ) && array_key_exists( $field, $list_fields ) ) {
                        $new_fields[$field] = $list_fields[$field];
                    }
                }

                if ( ! empty( $new_fields ) && is_array( $new_fields ) ) {
                    $list_fields = $new_fields;
                }

                update_option( 'ovabrw_booking_form', $list_fields );
			}

			wp_die();
		}

		// Change Rental Type
		public function ovabrw_change_rental_type() {
			if ( ! isset( $_POST ) || empty( $_POST ) ) wp_die();

			$product_id 	= isset( $_POST['product_id'] ) ? $_POST['product_id'] : '';
			$type 			= isset( $_POST['rental_type'] ) ? $_POST['rental_type'] : '';
			$rental_object 	= isset( OVABRW_Admin_Meta_Boxes::instance()->rental_types[$type] ) ? OVABRW_Admin_Meta_Boxes::instance()->rental_types[$type] : '';

			if ( $rental_object && is_object( $rental_object ) ) {
				$rental_object->set_ID( $product_id );
				echo $rental_object->get_html();
			}

			wp_die();
		}

		public function ovabrw_get_rental_type_product() {
			$id_product 	= isset($_POST['id_product']) ? sanitize_text_field( $_POST['id_product'] ) : '';
			$rental_type 	= get_post_meta( $id_product, 'ovabrw_price_type', true );

			$data = [
				'rental_type' => $rental_type,
			];

			echo json_encode( $data );
			wp_die();
		}

		public function ovabrw_load_data_product_create_order() {
			$product_id = isset( $_POST['product_id'] ) ? trim( sanitize_text_field( $_POST['product_id'] ) ) : '';
			$currency 	= isset( $_POST['currency'] ) ? sanitize_text_field( $_POST['currency'] ) : '';

			if ( ! $product_id ) wp_die();

			// Rental type
			$type 		= get_post_meta( $product_id, 'ovabrw_price_type', true );
			$rental_obj = isset( OVABRW_Admin_Meta_Boxes::instance()->rental_types[$type] ) ? OVABRW_Admin_Meta_Boxes::instance()->rental_types[$type] : '';

			if ( $rental_obj && is_object( $rental_obj ) ) {
				$rental_obj->set_ID( $product_id );

				$statuses 	= brw_list_order_status();
				$order_time = OVABRW_Get_Data::instance()->get_order_rent_time( $product_id, $statuses );

				echo $rental_obj->create_order_get_meta_boxes_html( [ 'currency' => $currency, 'order_time' => $order_time ] );
			}

			wp_die();
		}

		public function ovabrw_get_total_price_and_quantity() {
			$data = $_POST;

			if ( ! $data ) wp_die();

			$product_id 		= isset( $data['product_id'] ) ? trim( sanitize_text_field( $data['product_id'] ) ) : '';
			$currency 			= isset( $data['currency'] ) ? trim( sanitize_text_field( $data['currency'] ) ) : '';
			$pickup_location 	= isset( $data['pickup_location'] ) ? trim( sanitize_text_field( $data['pickup_location'] ) ) : '';
			$dropoff_location 	= isset( $data['dropoff_location'] ) ? trim( sanitize_text_field( $data['dropoff_location'] ) ) : '';
			$pickup_taxi_location 	= isset( $data['pickup_taxi_location'] ) ? trim( sanitize_text_field( $data['pickup_taxi_location'] ) ) : '';
			$dropoff_taxi_location 	= isset( $data['dropoff_taxi_location'] ) ? trim( sanitize_text_field( $data['dropoff_taxi_location'] ) ) : '';
			$pickup_date 	= isset( $data['pickup_date'] ) ? trim( sanitize_text_field( $data['pickup_date'] ) ) : '';
			$pickup_time 	= isset( $data['pickup_time'] ) ? trim( sanitize_text_field( $data['pickup_time'] ) ) : '';
			$dropoff_date 	= isset( $data['dropoff_date'] ) ? trim( sanitize_text_field( $data['dropoff_date'] ) ) : '';
			$package_id 	= isset( $data['package_id'] ) ? trim( sanitize_text_field( $data['package_id'] ) ) : '';
			$quantity 		= isset( $data['quantity'] ) ? intval( $data['quantity'] ) : 1;
			$vehicle_id 	= isset( $data['vehicle_id'] ) ? trim( sanitize_text_field( $data['vehicle_id'] ) ) : '';
			$extra_time 	= isset( $data['extra_time'] ) ? trim( sanitize_text_field( $data['extra_time'] ) ) : '';
			$duration_map 	= isset( $data['duration_map'] ) ? trim( sanitize_text_field( $data['duration_map'] ) ) : '';
			$duration_map 	= isset( $data['duration_map'] ) ? trim( sanitize_text_field( $data['duration_map'] ) ) : '';
			$duration 		= isset( $data['duration'] ) ? sanitize_text_field( $data['duration'] ) : '';
			$distance 		= isset( $data['distance'] ) ? sanitize_text_field( $data['distance'] ) : '';

			// Custom Checkout Fields
			$custom_ckf 	= isset( $data['custom_ckf'] ) ? str_replace( '\\', '', $data['custom_ckf'] ) : '';
			$custom_ckf 	= (array) json_decode( $custom_ckf );
			$custom_ckf_qty = isset( $data['custom_ckf_qty'] ) ? str_replace( '\\', '', $data['custom_ckf_qty'] ) : '';
			$custom_ckf_qty = (array) json_decode( $custom_ckf_qty );

			// Resources
			$resources 		= isset( $data['resources'] ) ? str_replace( '\\', '', $data['resources'] ) : '';
			$resources 		= (array)json_decode( $resources );
			$resources_qty 	= isset( $data['resources_qty'] ) ? str_replace( '\\', '', $data['resources_qty'] ) : [];
			$resources_qty 	= (array)json_decode( $resources_qty );

			// Services
			$services 		= isset( $data['services'] ) ? str_replace( '\\', '', $data['services'] ) : '';
			$services 		= (array)json_decode( $services );
			$services_qty 	= isset( $data['services_qty'] ) ? str_replace( '\\', '', $data['services_qty'] ) : '';
			$services_qty 	= (array)json_decode( $services_qty );

			// Get rental type product
			$type = get_post_meta( $product_id, 'ovabrw_price_type', true );

			// Object Rental Types
        	$rental_object = isset( OVABRW_Rental_Types::instance()->rental_types[$type] ) ? OVABRW_Rental_Types::instance()->rental_types[$type] : '';

        	if ( empty( $rental_object ) || ! is_object( $rental_object ) ) {
        		echo 0;
				wp_die();
        	}

        	// Set Product ID
        	$rental_object->set_ID( $product_id );

        	$new_date = [
        		'pickup_date_new' 	=> '',
        		'dropoff_date_new' 	=> '',
        	];

        	switch ( $type ) {
        		case 'day':
        			$new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), strtotime( $dropoff_date ) );
        			break;
        		case 'hour':
        			$new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), strtotime( $dropoff_date ) );
        			break;
        		case 'mixed':
        			$new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), strtotime( $dropoff_date ) );
        			break;
        		case 'period_time':
        			$new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), $package_id );
        			break;
        		case 'transportation':
        			$new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), strtotime( $dropoff_date ), $pickup_location, $dropoff_location );
        			break;
        		case 'taxi':
        			$pickup_location 	= $pickup_taxi_location;
        			$dropoff_location 	= $dropoff_taxi_location;

        			$new_date = $rental_object->get_strtotime_input_date( $pickup_date, $pickup_time, $duration );
        			break;
        		case 'hotel':
        			$new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), strtotime( $dropoff_date ) );
        		default:
        			break;
        	}
			
        	// Check Pick-up & Drop-off Date
			// if ( ! $new_date['pickup_date_new'] || ! $new_date['dropoff_date_new'] ) {
			// 	echo 0;
			// 	wp_die();
			// }

			// Ajax Validation Booking
			$validation_booking = $rental_object->ovabrw_ajax_validation_booking( $new_date['pickup_date_new'], $new_date['dropoff_date_new'], $data );

			if ( $validation_booking ) {
				$total['error'] = $validation_booking;
				echo json_encode( $total ); wp_die();
			}

			// Check available quantity
			if ( $vehicle_id ) {
				$vehicle_available = $rental_object->get_vehicle_available( $new_date['pickup_date_new'], $new_date['dropoff_date_new'], $pickup_location, $dropoff_location, 'check' );
				
				if ( $rental_object->is_array_exists( $vehicle_available ) ) {
					if ( ! in_array( $vehicle_id, $vehicle_available ) ) {
						$total['error'] = sprintf( esc_html__( 'Vehicle ID: %s is not available!', 'ova-brw' ), $vehicle_id );
						echo json_encode( $total ); wp_die();
					}

					$qty_available = count( $vehicle_available );
				} else {
					$total['error'] = esc_html__( 'Out stock!', 'ova-brw' );
					echo json_encode( $total ); wp_die();
				}
			} else {
				$data_available = $rental_object->get_qty_available( $new_date['pickup_date_new'], $new_date['dropoff_date_new'], $pickup_location, $dropoff_location, 'check' );
		        $qty_available 	= $data_available['qty_available'];

		        if ( $quantity > $qty_available ) {
		        	if ( $qty_available > 0 ) {
		        		$total['error'] = sprintf( esc_html__( 'Available vehicle is %s', 'ova-brw'  ), $qty_available );
		        	} else {
		        		$total['error'] = esc_html__( 'Out stock!', 'ova-brw' );
		        	}

	                echo json_encode( $total ); wp_die();
		        }
			}

	        // Qty available
		    $total['number_vehicle_available'] = $qty_available;

	        // Add Cart item
	        $cart_item = [
	        	'ovabrw_checkin' 			=> $new_date['pickup_date_new'],
	        	'ovabrw_checkout' 			=> $new_date['dropoff_date_new'],
	        	'ovabrw_pickup_loc' 		=> $pickup_location,
	        	'ovabrw_pickoff_loc' 		=> $dropoff_location,
	        	'package_id' 				=> $package_id,
	        	'ovabrw_number_vehicle' 	=> $quantity,
	        	'custom_ckf' 				=> $custom_ckf,
	        	'custom_ckf_qty' 			=> $custom_ckf_qty,
	        	'resources' 				=> $resources,
	        	'resources_qty' 			=> $resources_qty,
	        	'ovabrw_service' 			=> $services,
	        	'ovabrw_service_qty' 		=> $services_qty,
	        	'ovabrw_amount_insurance' 	=> $quantity * floatval( $rental_object->get_value( 'amount_insurance' ) ),
	        	'duration_map' 				=> $duration_map,
	        	'duration' 					=> $duration,
	        	'distance' 					=> $distance,
	        	'extra_time' 				=> $extra_time,
	        ];

			$line_total = $rental_object->get_total( $cart_item );
			$insurance 	= floatval( $cart_item['ovabrw_amount_insurance'] );

			// Multi Currency
        	if ( is_plugin_active( 'woocommerce-multilingual/wpml-woocommerce.php' ) ) {
                $line_total = ovabrw_convert_price( $line_total );
                $insurance 	= ovabrw_convert_price( $insurance );
            }

            // Insurance Amount
            $total['amount_insurance'] = $insurance;
			
			if ( $line_total <= 0 ) {
				echo 0;	
			} else {
				$total['line_total'] = round( ovabrw_convert_price( $line_total, [ 'currency' => $currency ] ), wc_get_price_decimals() );
			}

			echo json_encode( $total );
			wp_die();
		}

		public function ovabrw_get_dropoff_date_transportation() {
			$date_format 	= ovabrw_get_date_format();
		    $time_format 	= ovabrw_get_time_format_php();
			$id_product 	= isset($_POST['id_product']) ? sanitize_text_field( $_POST['id_product'] ) : '';
			$pickup_date 	= isset($_POST['pickup_date']) ? strtotime(sanitize_text_field( $_POST['pickup_date'] )) : '';
			$pickup_loc 	= isset($_POST['pickup_loc']) ? sanitize_text_field( $_POST['pickup_loc'] ) : '';
			$dropoff_loc 	= isset($_POST['dropoff_loc']) ? sanitize_text_field( $_POST['dropoff_loc'] ) : '';
			$time_dropoff 	= ovabrw_get_time_by_pick_up_off_loc_transport( $id_product, $pickup_loc, $dropoff_loc );

		    // Get Second
		    $time_dropoff_seconds = 60 * $time_dropoff;
		    
		    $dropoff_date_timestamp =  $pickup_date + $time_dropoff_seconds;
		    $pickoff_date = date( $date_format . ' ' . $time_format, $dropoff_date_timestamp );
			
			if ( $pickoff_date && $pickup_loc && $dropoff_loc ) {
				$data = [
					'error' => false,
					'dropoff' => $pickoff_date
				];
			} else {
				$data = [
					'error' => true,
					'start_date' => 'empty',
					'message' => esc_html__("Please insert Pick-up, Drop-off Location", 'ova-brw'),
				];
			}
			
			echo json_encode( $data );
			wp_die();
		}

		public function ovabrw_get_packages() {
			$product_id 		= isset( $_POST['product_id'] ) ? sanitize_text_field( $_POST['product_id'] ) : '';
			$pickup_location 	= isset( $_POST['pickup_location'] ) ? sanitize_text_field( $_POST['pickup_location'] ) : '';
			$dropoff_location 	= isset( $_POST['dropoff_location'] ) ? sanitize_text_field( $_POST['dropoff_location'] ) : '';
			$pickup_date 		= isset( $_POST['pickup_date'] ) ? strtotime( $_POST['pickup_date'] ) : '';

			if ( ! $product_id || ! $pickup_date ) {
				echo 0; wp_die();
			}

			$rental_type 	= get_post_meta( $product_id, 'ovabrw_price_type', true );
			$rental_object 	= isset( OVABRW_Rental_Types::instance()->rental_types[$rental_type] ) ? OVABRW_Rental_Types::instance()->rental_types[$rental_type] : '';

        	if ( empty( $rental_object ) || ! is_object( $rental_object ) ) {
        		echo 0;
				wp_die();
        	}

        	// Set Product ID
        	$rental_object->set_ID( $product_id );

        	$packages = [];

        	// Get Data
        	$package_ids 	= $rental_object->get_value( 'petime_id', [] );
			$package_labels = $rental_object->get_value( 'petime_label', [] );

			if ( $rental_object->is_array_exists( $package_ids ) ) {
				foreach ( $package_ids as $k => $package_id ) {
					$label 		= isset( $package_labels[$k] ) ? $package_labels[$k] : '';
					$new_date 	= $rental_object->get_strtotime_input_date( $pickup_date, $package_id );

					if ( ! $new_date['pickup_date_new'] || ! $new_date['dropoff_date_new'] ) continue;

					// Check available quantity
			        $data_available = $rental_object->get_qty_available( $new_date['pickup_date_new'], $new_date['dropoff_date_new'], $pickup_location, $dropoff_location, 'seach' );
			        $qty_available 	= $data_available['qty_available'];

			        if ( $qty_available > 0 ) {
			        	$packages[$package_id] = $label;
			        }
				}
			}

			if ( empty( $packages ) || count( $packages ) < 1 ) {
				$packages = array( esc_html__( 'There are no packages', 'ova-brw' ) );
			}
			
			echo json_encode( $packages );
			wp_die();
		}

		// Add new specification
		public function ovabrw_add_specification() {
			ob_start();

			// include html add new
			OVABRW_Admin_Specifications::instance()->ovavbrw_popup_specification_field();
			$html = ob_get_contents();

			ob_clean();

			echo $html;

			wp_die();
		}

		// Edit specification
		public function ovabrw_edit_specification() {
			$name = isset( $_POST['name'] ) ? $_POST['name'] : '';
			$type = isset( $_POST['type'] ) ? $_POST['type'] : '';

			if ( ! $name || ! $type ) wp_die();

			ob_start();

			// include html add new
			OVABRW_Admin_Specifications::instance()->ovavbrw_popup_specification_field( 'edit', $type, $name );
			$html = ob_get_contents();

			ob_clean();

			echo $html;

			wp_die();
		}

		// Delete specification
		public function ovabrw_delete_specification() {
			$name = isset( $_POST['name'] ) ? $_POST['name'] : '';

			if ( ! $name ) wp_die();

			$post['fields'] = [ $name ];

			OVABRW_Admin_Specifications::instance()->delete( $post );

			echo 1;
			wp_die();
		}

		// Sort specifications
		public function ovabrw_sort_specifications() {
			OVABRW_Admin_Specifications::instance()->sort( $_POST ); wp_die();
		}

		// Enable specification
		public function ovabrw_enable_specification() {
			$name = isset( $_POST['name'] ) ? $_POST['name'] : '';

			if ( ! $name ) wp_die();

			$post['fields'] = [ $name ];

			OVABRW_Admin_Specifications::instance()->enable( $post );

			echo 1;
			wp_die();
		}

		// Disable specification
		public function ovabrw_disable_specification() {
			$name = isset( $_POST['name'] ) ? $_POST['name'] : '';

			if ( ! $name ) wp_die();

			$post['fields'] = [ $name ];

			OVABRW_Admin_Specifications::instance()->disable( $post );

			echo 1;
			wp_die();
		}

		// Change type specification
		public function ovabrw_change_type_specification() {
			$type = isset( $_POST['type'] ) ? $_POST['type'] : '';

			if ( ! $type ) wp_die();

			ob_start();

			// include html add new
			OVABRW_Admin_Specifications::instance()->ovavbrw_popup_specification_field( 'new', $type );
			$html = ob_get_contents();

			ob_clean();

			echo $html;

			wp_die();
		}
	}

	new OVABRW_Admin_Ajax();
}