<?php defined( 'ABSPATH' ) || exit;
	$specifications = ovabrw_get_all_specifications( $this->ID );
?>
<div class="ovabrw-advanced-settings">
	<div class="advanced-header">
		<h3 class="advanced-label"><?php esc_html_e( 'Specifications', 'ova-brw' ); ?></h3>
		<span aria-hidden="true" class="dashicons dashicons-arrow-up"></span>
		<span aria-hidden="true" class="dashicons dashicons-arrow-down"></span>
	</div>
	<div class="advanced-content">
		<div class="ovabrw-form-field ovabrw-specifications">
			<table class="widefat">
				<thead>
					<tr>
						<th width="30%"><?php esc_html_e( 'Label', 'ova-brw' ); ?></th>
						<th width="70%"><?php esc_html_e( 'Value', 'ova-brw' ); ?></th>
					</tr>
				</thead>
				<tbody>
				<?php if ( ! empty( $specifications ) && is_array( $specifications ) ):
					$product_specifications = $this->get_value( 'specifications' );

					foreach ( $specifications as $name => $item ):
						if ( ! isset( $item['enable'] ) || ! $item['enable'] ) continue;

						$type 		= isset( $item['type'] ) ? $item['type'] : '';
						$label 		= isset( $item['label'] ) ? $item['label'] : '';
						$default 	= isset( $item['default'] ) ? $item['default'] : '';
						$options 	= isset( $item['options'] ) ? $item['options'] : '';

						if ( isset( $product_specifications[$name] ) ) {
							$default = $product_specifications[$name];
						}
				?>
					<tr>
						<td><strong><?php echo esc_html( $label ); ?></strong></td>
						<td>
						<?php if ( $type == 'number' ): ?>
							<input
								type="number"
								name="<?php echo esc_attr( 'ovabrw_specifications['.$name.']' ); ?>"
								value="<?php echo esc_attr( $default ); ?>"
								autocomplete="off"
							/>
						<?php elseif ( $type === 'email' ): ?>
							<input
								type="email"
								name="<?php echo esc_attr( 'ovabrw_specifications['.$name.']' ); ?>"
								value="<?php echo esc_attr( $default ); ?>"
								autocomplete="off"
							/>
						<?php elseif ( $type === 'radio' ): ?>
							<div class="specification-radio">
								<?php if ( ! empty( $options ) && is_array( $options ) ):
									foreach ( $options as $option ):
										$checked = '';

										if ( is_string( $default ) && $default == $option ) {
											$checked = ' checked';
										} elseif ( is_array( $default ) && in_array( $option, $default ) ) {
											$checked = ' checked';
										}
								?>
									<label>
										<input
											type="radio"
											name="<?php echo esc_attr( 'ovabrw_specifications['.$name.'][]' ); ?>"
											value="<?php echo esc_attr( $option ); ?>"
											<?php echo esc_attr( $checked ); ?>
										/>
										<span><?php echo esc_html( $option ); ?></span>
									</label>
								<?php endforeach; endif; ?>	
							</div>
						<?php elseif ( $type === 'checkbox' ): ?>
							<div class="specification-checkbox">
								<?php if ( ! empty( $options ) && is_array( $options ) ):
									foreach ( $options as $option ):
										$checked = '';

										if ( is_string( $default ) && $default == $option ) {
											$checked = ' checked';
										} elseif ( is_array( $default ) && in_array( $option, $default ) ) {
											$checked = ' checked';
										}
								?>
									<label>
										<input
											type="checkbox"
											name="<?php echo esc_attr( 'ovabrw_specifications['.$name.'][]' ); ?>"
											value="<?php echo esc_attr( $option ); ?>"
											<?php echo esc_attr( $checked ); ?>
										/>
										<span><?php echo esc_html( $option ); ?></span>
									</label>
								<?php endforeach; endif; ?>	
							</div>
						<?php elseif ( $type === 'select' ):
							$multiple = '';

							if ( isset( $item['multiple'] ) && $item['multiple'] ) {
								$multiple = ' multiple';
							}
						?>
							<select
								name="<?php echo esc_attr( 'ovabrw_specifications['.$name.'][]' ); ?>"
								class="ovabrw-specifications-select2"
								<?php echo esc_attr( $multiple ); ?>
							>
							<?php if ( ! empty( $options ) && is_array( $options ) ):
								foreach ( $options as $option ):
									$selected = '';

									if ( is_string( $default ) && $default == $option ) {
										$selected = ' selected';
									} elseif ( is_array( $default ) && in_array( $option, $default ) ) {
										$selected = ' selected';
									}
							?>
								<option value="<?php echo esc_attr( $option ); ?>"<?php echo esc_attr( $selected ); ?>>
									<?php echo esc_html( $option ); ?>
								</option>
							<?php endforeach; endif; ?>	
							</select>
						<?php elseif ( $type === 'date' ): ?>
							<input
								type="date"
								name="<?php echo esc_attr( 'ovabrw_specifications['.$name.']' ); ?>"
								value="<?php echo esc_attr( $default ); ?>"
							/>
						<?php elseif ( $type === 'color' ): ?>
							<input
								type="color"
								name="<?php echo esc_attr( 'ovabrw_specifications['.$name.']' ); ?>"
								value="<?php echo esc_attr( $default ); ?>"
							/>
						<?php elseif ( $type === 'file' ):
							$attachment_title = $attachment_url = '';

							if ( $default ) {
								$attachment_title 	= get_the_title( $default );
								$attachment_url 	= get_edit_post_link( $default );
							}
						?>
							<button class="button button-primary specification-add-file">
								<?php esc_html_e( 'Add file', 'ova-brw' ); ?>
							</button>
							<p class="file-default" style="<?php echo $default ? 'display: block;' : ''; ?>">
								<a href="<?php echo esc_url( $attachment_url ); ?>" target="_blank">
									<?php echo esc_html( $attachment_title ); ?>
								</a>
								<button class="btn">X</button>
							</p>
							<input
								type="hidden"
								class="attachment-id"
								name="<?php echo esc_attr( 'ovabrw_specifications['.$name.']' ); ?>"
								value="<?php echo esc_attr( $default ); ?>"
							/>
						<?php else: ?>
							<input
								type="text"
								name="<?php echo esc_attr( 'ovabrw_specifications['.$name.']' ); ?>"
								value="<?php echo esc_attr( $default ); ?>"
								autocomplete="off"
							/>
						<?php endif; ?>
						</td>
					</tr>
				<?php endforeach; endif; ?>
				</tbody>
			</table>
		</div>
	</div>
</div>