<?php if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'OVABRW_Admin_Rental_By_Period_Time', false ) ) {
	class OVABRW_Admin_Rental_By_Period_Time extends OVABRW_Abstract_Admin_Rental_Types {
		protected static $_instance = null;

		public function __construct() {
			$this->ID 		= '';
			$this->type 	= 'period_time';
			$this->title 	= esc_html__( 'Period Time', 'ova-brw' );
			$this->prefix 	= OVABRW_PREFIX;
			$this->view 	= OVABRW_PLUGIN_PATH.'admin/meta-boxes/views/html-rental-by-period-time.php';

			parent::__construct();
		}

		public function save( $post_id, $data ) {
			if ( ! is_array( $data ) ) {
                $data = $_POST;
            }

            $product_type 	= isset( $data['product-type'] ) ? $data['product-type'] : '';
            $rental_type 	= isset( $data[$this->get_name('price_type')] ) ? $data[$this->get_name('price_type')] : '';

            if ( $product_type === 'ovabrw_car_rental' && $this->type === $rental_type ) {
            	// Rental Type
            	if ( $rental_type ) {
	            	update_post_meta( $post_id, $this->get_name('price_type'), $rental_type );
	            } else {
	            	delete_post_meta( $post_id, $this->get_name('price_type'), $rental_type );
	            }

	            // Regular Price
	            update_post_meta( $post_id, '_regular_price', 0 );
	            update_post_meta( $post_id, '_price', 0 );

	            // Unfixed time
	            $unfixed_time = isset( $data[$this->get_name('unfixed_time')] ) ? $data[$this->get_name('unfixed_time')] : 'no';
	            update_post_meta( $post_id, $this->get_name('unfixed_time'), $unfixed_time );

	            // Insurance Amount
	            $insurance_amount = isset( $data[$this->get_name('amount_insurance')] ) ? wc_format_decimal( $data[$this->get_name('amount_insurance')] ) : '';
	            update_post_meta( $post_id, $this->get_name('amount_insurance'), $insurance_amount );

	            // Enable deposit
	            $enable_deposit = isset( $data[$this->get_name('enable_deposit')] ) ? $data[$this->get_name('enable_deposit')] : '';
	            update_post_meta( $post_id, $this->get_name('enable_deposit'), $enable_deposit );

	            // Show full payment
	            $show_full_payment = isset( $data[$this->get_name('force_deposit')] ) ? $data[$this->get_name('force_deposit')] : 'yes';
	            update_post_meta( $post_id, $this->get_name('force_deposit'), $show_full_payment );

	            // Deposit type
	            $deposit_type = isset( $data[$this->get_name('type_deposit')] ) ? $data[$this->get_name('type_deposit')] : 'percent';
	            update_post_meta( $post_id, $this->get_name('type_deposit'), $deposit_type );

	            // Deposit amount
	            $deposit_amount = isset( $data[$this->get_name('amount_deposit')] ) ? wc_format_decimal( $data[$this->get_name('amount_deposit')] ) : '';
	            update_post_meta( $post_id, $this->get_name('amount_deposit'), $deposit_amount );

	            // Inventory
	            $inventory = isset( $data[$this->get_name('manage_store')] ) ? $data[$this->get_name('manage_store')] : 'store';
	            update_post_meta( $post_id, $this->get_name('manage_store'), $inventory );

	            // Stock quantity
	            $stock_quantity = isset( $data[$this->get_name('car_count')] ) ? absint( $data[$this->get_name('car_count')] ) : '';
	            update_post_meta( $post_id, $this->get_name('car_count'), $stock_quantity );

	            // Vehicle ids
	            $vehicle_ids = isset( $data[$this->get_name('id_vehicles')] ) ? $data[$this->get_name('id_vehicles')] : '';
	            update_post_meta( $post_id, $this->get_name('id_vehicles'), $vehicle_ids );

	            // Prepare vehicle
	            $prepare_vehicle = isset( $data[$this->get_name('prepare_vehicle')] ) ? $data[$this->get_name('prepare_vehicle')] : '';
	            update_post_meta( $post_id, $this->get_name('prepare_vehicle'), $prepare_vehicle );

	            // Preparation time
	            $preparation_time = isset( $data[$this->get_name('preparation_time')] ) ? $data[$this->get_name('preparation_time')] : '';
	            update_post_meta( $post_id, $this->get_name('preparation_time'), $preparation_time );

	            // Order Frontend
	            $order_frontend = isset( $data[$this->get_name('car_order')] ) ? $data[$this->get_name('car_order')] : '';
	            update_post_meta( $post_id, $this->get_name('car_order'), $order_frontend );

	            // Packages
	            $package_ids = isset( $data[$this->get_name('petime_id')] ) ? $data[$this->get_name('petime_id')] : '';
	            update_post_meta( $post_id, $this->get_name('petime_id'), $package_ids );

	            $package_prices = isset( $data[$this->get_name('petime_price')] ) ? $data[$this->get_name('petime_price')] : '';
	            if ( ! empty( $package_prices ) && is_array( $package_prices ) ) {
	            	foreach ( $package_prices as $k => $price ) {
	            		$package_prices[$k] = wc_format_decimal( $price );
	            	}
	            }
	            update_post_meta( $post_id, $this->get_name('petime_price'), $package_prices );

	            $package_types = isset( $data[$this->get_name('package_type')] ) ? $data[$this->get_name('package_type')] : '';
	            update_post_meta( $post_id, $this->get_name('package_type'), $package_types );

	            $package_types = isset( $data[$this->get_name('package_type')] ) ? $data[$this->get_name('package_type')] : '';
	            update_post_meta( $post_id, $this->get_name('package_type'), $package_types );

	            $package_days = isset( $data[$this->get_name('petime_days')] ) ? $data[$this->get_name('petime_days')] : '';
	            update_post_meta( $post_id, $this->get_name('petime_days'), $package_days );

	            $package_start_time = isset( $data[$this->get_name('pehour_start_time')] ) ? $data[$this->get_name('pehour_start_time')] : '';
	            update_post_meta( $post_id, $this->get_name('pehour_start_time'), $package_start_time );

	            $package_end_time = isset( $data[$this->get_name('pehour_end_time')] ) ? $data[$this->get_name('pehour_end_time')] : '';
	            update_post_meta( $post_id, $this->get_name('pehour_end_time'), $package_end_time );

	            $package_hours = isset( $data[$this->get_name('pehour_unfixed')] ) ? $data[$this->get_name('pehour_unfixed')] : '';
	            update_post_meta( $post_id, $this->get_name('pehour_unfixed'), $package_hours );

	            $package_labels = isset( $data[$this->get_name('petime_label')] ) ? $data[$this->get_name('petime_label')] : '';
	            update_post_meta( $post_id, $this->get_name('petime_label'), $package_labels );

	            $package_discounts = isset( $data[$this->get_name('petime_discount')] ) ? $data[$this->get_name('petime_discount')] : '';
	            if ( ! empty( $package_discounts ) && is_array( $package_discounts ) ) {
	            	foreach ( $package_discounts as $k => $items ) {
	            		if ( isset( $items['price'] ) && ! empty( $items['price'] ) && is_array( $items['price'] ) ) {
	            			foreach ( $items['price'] as $i => $price ) {
	            				$package_discounts[$k]['price'][$i] = wc_format_decimal( $price );
	            			}
	            		}
	            	}
	            }
	            update_post_meta( $post_id, $this->get_name('petime_discount'), $package_discounts );

	            // Locations
	            $pickup_location = isset( $data[$this->get_name('st_pickup_loc')] ) ? $data[$this->get_name('st_pickup_loc')] : '';
	            update_post_meta( $post_id, $this->get_name('st_pickup_loc'), $pickup_location );

	            $dropoff_location = isset( $data[$this->get_name('st_dropoff_loc')] ) ? $data[$this->get_name('st_dropoff_loc')] : '';
	            update_post_meta( $post_id, $this->get_name('st_dropoff_loc'), $dropoff_location );

	            // Specifications
	            $specifications = isset( $data[$this->get_name('specifications')] ) ? $data[$this->get_name('specifications')] : '';
	            if ( ! empty( $specifications ) && is_array( $specifications ) ) {
	            	update_post_meta( $post_id, $this->get_name('specifications'), $specifications );
	            }

	            // Features
	            $feature_icons = isset( $data[$this->get_name('features_icons')] ) ? $data[$this->get_name('features_icons')] : '';
	            update_post_meta( $post_id, $this->get_name('features_icons'), $feature_icons );

	            $feature_labels = isset( $data[$this->get_name('features_label')] ) ? $data[$this->get_name('features_label')] : '';
	            update_post_meta( $post_id, $this->get_name('features_label'), $feature_labels );

	            $features_desc = isset( $data[$this->get_name('features_desc')] ) ? $data[$this->get_name('features_desc')] : '';
	            update_post_meta( $post_id, $this->get_name('features_desc'), $features_desc );

	            $features_special = isset( $data[$this->get_name('features_special')] ) ? $data[$this->get_name('features_special')] : 'no';
	            update_post_meta( $post_id, $this->get_name('features_special'), $features_special );

	            $features_featured = isset( $data[$this->get_name('features_featured')] ) ? $data[$this->get_name('features_featured')] : 'no';
	            update_post_meta( $post_id, $this->get_name('features_featured'), $features_featured );

	            // Resources
	            $resource_ids = isset( $data[$this->get_name('resource_id')] ) ? $data[$this->get_name('resource_id')] : '';
	            update_post_meta( $post_id, $this->get_name('resource_id'), $resource_ids );

	            $resource_names = isset( $data[$this->get_name('resource_name')] ) ? $data[$this->get_name('resource_name')] : '';
	            update_post_meta( $post_id, $this->get_name('resource_name'), $resource_names );

	            $resource_prices = isset( $data[$this->get_name('resource_price')] ) ? $data[$this->get_name('resource_price')] : '';
	            if ( ! empty( $resource_prices ) && is_array( $resource_prices ) ) {
	            	foreach ( $resource_prices as $k => $price ) {
	            		$resource_prices[$k] = wc_format_decimal( $price );
	            	}
	            }
	            update_post_meta( $post_id, $this->get_name('resource_price'), $resource_prices );

	            $resource_quantity = isset( $data[$this->get_name('resource_quantity')] ) ? $data[$this->get_name('resource_quantity')] : '';
	            update_post_meta( $post_id, $this->get_name('resource_quantity'), $resource_quantity );

	            $resource_duration = isset( $data[$this->get_name('resource_duration_type')] ) ? $data[$this->get_name('resource_duration_type')] : 'day';
	            update_post_meta( $post_id, $this->get_name('resource_duration_type'), $resource_duration );

	            // Services
	            $service_lables = isset( $data[$this->get_name('label_service')] ) ? $data[$this->get_name('label_service')] : '';
	            update_post_meta( $post_id, $this->get_name('label_service'), $service_lables );

	            $service_required = isset( $data[$this->get_name('service_required')] ) ? $data[$this->get_name('service_required')] : 'yes';
	            update_post_meta( $post_id, $this->get_name('service_required'), $service_required );

	            $service_ids = isset( $data[$this->get_name('service_id')] ) ? $data[$this->get_name('service_id')] : '';
	            update_post_meta( $post_id, $this->get_name('service_id'), $service_ids );

	            $service_names = isset( $data[$this->get_name('service_name')] ) ? $data[$this->get_name('service_name')] : '';
	            update_post_meta( $post_id, $this->get_name('service_name'), $service_names );

	            $service_prices = isset( $data[$this->get_name('service_price')] ) ? $data[$this->get_name('service_price')] : '';
	            if ( ! empty( $service_prices ) && is_array( $service_prices ) ) {
	            	foreach ( $service_prices as $k => $items ) {
	            		if ( ! empty( $items ) && is_array( $items ) ) {
	            			foreach ( $items as $i => $price ) {
	            				$service_prices[$k][$i] = wc_format_decimal( $price );
	            			}
	            		}
	            	}
	            }
	            update_post_meta( $post_id, $this->get_name('service_price'), $service_prices );

	            $service_qty = isset( $data[$this->get_name('service_qty')] ) ? $data[$this->get_name('service_qty')] : '';
	            update_post_meta( $post_id, $this->get_name('service_qty'), $service_qty );

	            $service_duration = isset( $data[$this->get_name('service_duration_type')] ) ? $data[$this->get_name('service_duration_type')] : '';
	            update_post_meta( $post_id, $this->get_name('service_duration_type'), $service_duration );

	            // Unavailable time
	            $untime_startdate = isset( $data[$this->get_name('untime_startdate')] ) ? $data[$this->get_name('untime_startdate')] : '';
	            update_post_meta( $post_id, $this->get_name('untime_startdate'), $untime_startdate );

	            $untime_enddate = isset( $data[$this->get_name('untime_enddate')] ) ? $data[$this->get_name('untime_enddate')] : '';
	            update_post_meta( $post_id, $this->get_name('untime_enddate'), $untime_enddate );

	            // Disable weekday
	            $disable_weekday = isset( $data[$this->get_name('product_disable_week_day')] ) ? $data[$this->get_name('product_disable_week_day')] : '';
	            update_post_meta( $post_id, $this->get_name('product_disable_week_day'), $disable_weekday );

	            // Extra Tab
	            $extra_tab = isset( $data[$this->get_name('manage_extra_tab')] ) ? $data[$this->get_name('manage_extra_tab')] : 'in_setting';
	            update_post_meta( $post_id, $this->get_name('manage_extra_tab'), $extra_tab );

	            if ( $extra_tab === 'new_form' ) {
	            	$extra_tab_shortcode = isset( $data[$this->get_name('extra_tab_shortcode')] ) ? $data[$this->get_name('extra_tab_shortcode')] : '';
	            	update_post_meta( $post_id, $this->get_name('extra_tab_shortcode'), $extra_tab_shortcode );
	            }

	            // Start Date For Booking
	            $time_book_start = isset( $data[$this->get_name('manage_time_book_start')] ) ? $data[$this->get_name('manage_time_book_start')] : 'in_setting';
	            update_post_meta( $post_id, $this->get_name('manage_time_book_start'), $time_book_start );

	            if ( $time_book_start === 'new_time' ) {
	            	$new_time_book_start = isset( $data[$this->get_name('product_time_to_book_start')] ) ? $data[$this->get_name('product_time_to_book_start')] : '';
	            	update_post_meta( $post_id, $this->get_name('product_time_to_book_start'), $new_time_book_start );
	            }

	            $default_hour_start = isset( $data[$this->get_name('manage_default_hour_start')] ) ? $data[$this->get_name('manage_default_hour_start')] : 'in_setting';
	            update_post_meta( $post_id, $this->get_name('manage_default_hour_start'), $default_hour_start );

	            if ( $default_hour_start === 'new_time' ) {
	            	$new_default_hour_start = isset( $data[$this->get_name('product_default_hour_start')] ) ? $data[$this->get_name('product_default_hour_start')] : '';
	            	update_post_meta( $post_id, $this->get_name('product_default_hour_start'), $new_default_hour_start );
	            }

	            // End Date For Booking
	            $time_book_end = isset( $data[$this->get_name('manage_time_book_end')] ) ? $data[$this->get_name('manage_time_book_end')] : 'in_setting';
	            update_post_meta( $post_id, $this->get_name('manage_time_book_end'), $time_book_end );

	            if ( $time_book_end === 'new_time' ) {
	            	$new_time_book_end = isset( $data[$this->get_name('product_time_to_book_end')] ) ? $data[$this->get_name('product_time_to_book_end')] : '';
	            	update_post_meta( $post_id, $this->get_name('product_time_to_book_end'), $new_time_book_end );
	            }

	            $default_hour_end = isset( $data[$this->get_name('manage_default_hour_end')] ) ? $data[$this->get_name('manage_default_hour_end')] : 'in_setting';
	            update_post_meta( $post_id, $this->get_name('manage_default_hour_end'), $default_hour_end );

	            if ( $default_hour_end === 'new_time' ) {
	            	$new_default_hour_end = isset( $data[$this->get_name('product_default_hour_end')] ) ? $data[$this->get_name('product_default_hour_end')] : '';
	            	update_post_meta( $post_id, $this->get_name('product_default_hour_end'), $new_default_hour_end );
	            }

	            // Custom Checkout Field
	            $checkout_field = isset( $data[$this->get_name('manage_custom_checkout_field')] ) ? $data[$this->get_name('manage_custom_checkout_field')] : 'all';
	            update_post_meta( $post_id, $this->get_name('manage_custom_checkout_field'), $checkout_field );

	            if ( $checkout_field === 'new' ) {
	            	$new_checkout_field = isset( $data[$this->get_name('product_custom_checkout_field')] ) ? $data[$this->get_name('product_custom_checkout_field')] : '';
	            	update_post_meta( $post_id, $this->get_name('product_custom_checkout_field'), $new_checkout_field );
	            }

	            // Show Pick-Up Location
	            $show_pickup_location = isset( $data[$this->get_name('show_pickup_location_product')] ) ? $data[$this->get_name('show_pickup_location_product')] : 'in_setting';
	            update_post_meta( $post_id, $this->get_name('show_pickup_location_product'), $show_pickup_location );

	            $show_other_pickup_location = isset( $data[$this->get_name('show_other_location_pickup_product')] ) ? $data[$this->get_name('show_other_location_pickup_product')] : 'yes';
	            update_post_meta( $post_id, $this->get_name('show_other_location_pickup_product'), $show_other_pickup_location );

	            // Show Drop-Off Location
	            $show_dropoff_location = isset( $data[$this->get_name('show_pickoff_location_product')] ) ? $data[$this->get_name('show_pickoff_location_product')] : 'in_setting';
	            update_post_meta( $post_id, $this->get_name('show_pickoff_location_product'), $show_dropoff_location );

	            $show_other_dropoff_location = isset( $data[$this->get_name('show_other_location_dropoff_product')] ) ? $data[$this->get_name('show_other_location_dropoff_product')] : 'yes';
	            update_post_meta( $post_id, $this->get_name('show_other_location_dropoff_product'), $show_other_dropoff_location );

	            // Show Pick-up Date
	            $show_pickup_date = isset( $data[$this->get_name('show_pickup_date_product')] ) ? $data[$this->get_name('show_pickup_date_product')] : 'in_setting';
	            update_post_meta( $post_id, $this->get_name('show_pickup_date_product'), $show_pickup_date );

	            $pickup_date_label = isset( $data[$this->get_name('label_pickup_date_product')] ) ? $data[$this->get_name('label_pickup_date_product')] : 'category';
	            update_post_meta( $post_id, $this->get_name('label_pickup_date_product'), $pickup_date_label );

	            if ( $pickup_date_label === 'new' ) {
	            	$new_pickup_date_label = isset( $data[$this->get_name('new_pickup_date_product')] ) ? $data[$this->get_name('new_pickup_date_product')] : '';
	            	update_post_meta( $post_id, $this->get_name('new_pickup_date_product'), $new_pickup_date_label );
	            }

	            // Show Drop-off Date
	            $show_dropoff_date = isset( $data[$this->get_name('show_pickoff_date_product')] ) ? $data[$this->get_name('show_pickoff_date_product')] : 'in_setting';
	            update_post_meta( $post_id, $this->get_name('show_pickoff_date_product'), $show_dropoff_date );

	            $dropoff_date_label = isset( $data[$this->get_name('label_dropoff_date_product')] ) ? $data[$this->get_name('label_dropoff_date_product')] : 'category';
	            update_post_meta( $post_id, $this->get_name('label_dropoff_date_product'), $dropoff_date_label );

	            if ( $dropoff_date_label === 'new' ) {
	            	$new_dropoff_date_label = isset( $data[$this->get_name('new_dropoff_date_product')] ) ? $data[$this->get_name('new_dropoff_date_product')] : '';
	            	update_post_meta( $post_id, $this->get_name('new_dropoff_date_product'), $new_dropoff_date_label );
	            }

	            // Show Quantity
	            $show_quantity = isset( $data[$this->get_name('show_number_vehicle')] ) ? $data[$this->get_name('show_number_vehicle')] : 'in_setting';
	            update_post_meta( $post_id, $this->get_name('show_number_vehicle'), $show_quantity );

	            // Google map
	            $map_name = isset( $data[$this->get_name('map_name')] ) ? $data[$this->get_name('map_name')] : '';
	            update_post_meta( $post_id, $this->get_name('map_name'), $map_name );

	            $address = isset($data[$this->get_name('address')]) ? $data[$this->get_name('address')] : '';
	            update_post_meta( $post_id, $this->get_name('address'), $address );

	            $latitude = isset($data[$this->get_name('latitude')]) ? $data[$this->get_name('latitude')] : '';
	            update_post_meta( $post_id, $this->get_name('latitude'), $latitude );

	            $longitude = isset($data[$this->get_name('longitude')]) ? $data[$this->get_name('longitude')] : '';
	            update_post_meta( $post_id, $this->get_name('longitude'), $longitude );
            }
		}

		public function create_order_get_meta_boxes_html( $args = [] ) {
			ob_start();
			include( OVABRW_PLUGIN_PATH.'admin/orders/views/html-create-order-rental-period-time.php' );
			return ob_get_clean();
		}

		public function get_price_html( $currency = '' ) {
			$min = $max = 0;
			$petime_price = $this->get_value( 'petime_price', [] );

			if ( ! empty( $petime_price ) && is_array( $petime_price ) ) {
			    $min = min( $petime_price );
			    $max = max( $petime_price );
			}

			if ( $min && $max && $min == $max ) {
				return sprintf( esc_html__( 'From %s', 'ova-brw' ), ovabrw_wc_price( $min, ['currency' => $currency] ) );
			} elseif ( $min && $max ) {
				return sprintf( esc_html__( '%s - %s', 'ova-brw' ), ovabrw_wc_price( $min, ['currency' => $currency] ), ovabrw_wc_price( $max, ['currency' => $currency] ) );
			} else {
				return esc_html__( 'Option Price' );
			}
		}

		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}

			return self::$_instance;
		}
	}
}