<?php defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'OVABRW_Widget_Product_Booking_Form' ) ) {
	class OVABRW_Widget_Product_Booking_Form extends \Elementor\Widget_Base {
		public function get_name() {
			return 'ovabrw_product_booking_form';
		}

		public function get_title() {
			return esc_html__( 'Product Booking Form', 'ova-brw' );
		}

		public function get_icon() {
			return 'eicon-form-horizontal';
		}

		public function get_categories() {
			return [ 'ovabrw-product' ];
		}

		public function get_script_depends() {
			/* Google Maps */
			if ( get_option( 'ova_brw_google_key_map', false ) && ! wp_script_is( 'google_map' ) ) {
				wp_enqueue_script( 'google_map','https://maps.googleapis.com/maps/api/js?key='.get_option( 'ova_brw_google_key_map', '' ).'&libraries=places&callback=Function.prototype', false, true );
			}
			
			return [ 'script-elementor' ];
		}

		protected function register_controls() {
			$this->start_controls_section(
				'section_demo',
				[
					'label' => esc_html__( 'Demo', 'ova-brw' ),
				]
			);
				$arr_product 	= array( '0' => esc_html__( 'Choose Product', 'ova-brw' ) );
				$products 		= OVABRW_Get_Data::instance()->get_products_rental();

				if ( ! empty( $products ) && is_array( $products ) ) {
					foreach( $products as $product_id ) {
						$arr_product[$product_id] = get_the_title( $product_id );
					}
				} else {
					$arr_product[''] = esc_html__( 'There are no rental products', 'ova-brw' );
				}

				$this->add_control(
					'product_id',
					[
						'label' 	=> esc_html__( 'Choose Product', 'ova-brw' ),
						'type' 		=> \Elementor\Controls_Manager::SELECT,
						'default' 	=> '0',
						'options' 	=> $arr_product,
					]
				);

				$this->add_control(
					'product_template',
					[
						'label' 	=> esc_html__( 'Choose Template', 'ova-brw' ),
						'type' 		=> \Elementor\Controls_Manager::SELECT,
						'default' 	=> 'modern',
						'options' 	=> [
							'modern' 	=> esc_html__( 'Modern', 'ova-brw' ),
							'classic' 	=> esc_html__( 'Classic', 'ova-brw' )
						],
					]
				);

			$this->end_controls_section();

			$this->start_controls_section(
				'section_head_tab_style',
				[
					'label' 	=> esc_html__( 'Head Tab', 'ova-brw' ),
					'tab' 		=> \Elementor\Controls_Manager::TAB_STYLE,
					'condition' => [
						'product_template' => 'modern'
					]
				]
			);

				$this->add_group_control(
					\Elementor\Group_Control_Typography::get_type(),
					[
						'name' 		=> 'title_typography',
						'selector' 	=> '{{WRAPPER}} .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-head .item-tab',
					]
				);

				$this->add_control(
					'title_color',
					[
						'label' 	=> esc_html__( 'Color', 'ova-brw' ),
						'type' 		=> \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-head .item-tab' => 'color: {{VALUE}}',
						],
					]
				);

				$this->add_control(
					'title_active_color',
					[
						'label' 	=> esc_html__( 'Color Active', 'ova-brw' ),
						'type' 		=> \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-head .item-tab.active' => 'color: {{VALUE}}; border-color: {{VALUE}}'
						],
					]
				);

				$this->add_control(
					'head_bgcolor',
					[
						'label' 	=> esc_html__( 'Background Color', 'ova-brw' ),
						'type' 		=> \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-head' => 'background-color: {{VALUE}}',
						],
					]
				);

				$this->add_responsive_control(
					'head_padding',
					[
						'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
						'label' 		=> esc_html__( 'Padding', 'ova-brw' ),
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-head' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);

				$this->add_responsive_control(
					'head_border_radius',
					[
						'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
						'label' 		=> esc_html__( 'Border Radius', 'ova-brw' ),
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-head' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);

			$this->end_controls_section();

			$this->start_controls_section(
				'section_form_tab_style',
				[
					'label' 	=> esc_html__( 'Form', 'ova-brw' ),
					'tab' 		=> \Elementor\Controls_Manager::TAB_STYLE,
					'condition' => [
						'product_template' => 'modern'
					]
				]
			);

				$this->add_control(
					'form_bgcolor',
					[
						'label' 	=> esc_html__( 'Background Color', 'ova-brw' ),
						'type' 		=> \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #booking_form, .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #request_booking' => 'background-color: {{VALUE}}',
						],
					]
				);

				$this->add_responsive_control(
					'form_padding',
					[
						'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
						'label' 		=> esc_html__( 'Padding', 'ova-brw' ),
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #booking_form, .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #request_booking' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);

				$this->add_responsive_control(
					'form_border_radius',
					[
						'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
						'label' 		=> esc_html__( 'Border Radius', 'ova-brw' ),
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #booking_form, .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #request_booking' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);

			$this->end_controls_section();

			$this->start_controls_section(
				'section_button_style',
				[
					'label' 	=> esc_html__( 'Button', 'ova-brw' ),
					'tab' 		=> \Elementor\Controls_Manager::TAB_STYLE,
					'condition' => [
						'product_template' => 'modern'
					]
				]
			);

				$this->add_control(
					'button_color',
					[
						'label' 	=> esc_html__( 'Color', 'ova-brw' ),
						'type' 		=> \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #booking_form button.submit, .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #request_booking button.submit' => 'color: {{VALUE}}',
						],
					]
				);

				$this->add_control(
					'button_color_hover',
					[
						'label' 	=> esc_html__( 'Color Hover', 'ova-brw' ),
						'type' 		=> \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #booking_form button.submit:hover, .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #request_booking button.submit:hover' => 'color: {{VALUE}}',
						],
					]
				);

				$this->add_control(
					'button_bgcolor',
					[
						'label' 	=> esc_html__( 'Background Color', 'ova-brw' ),
						'type' 		=> \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #booking_form button.submit, .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #request_booking button.submit' => 'background-color: {{VALUE}}',
						],
					]
				);

				$this->add_control(
					'button_bgcolor_hover',
					[
						'label' 	=> esc_html__( 'Background Color Hover', 'ova-brw' ),
						'type' 		=> \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #booking_form button.submit:hover, .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #request_booking button.submit:hover' => 'background-color: {{VALUE}}',
						],
					]
				);

				$this->add_responsive_control(
					'button_padding',
					[
						'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
						'label' 		=> esc_html__( 'Padding', 'ova-brw' ),
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #booking_form button.submit, .ovabrw-modern-product .ovabrw-product-form-tabs .ovabrw-tab-content #request_booking button.submit' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);

			$this->end_controls_section();
		}

		protected function render() {
			$settings 	= $this->get_settings();
			$product_id = $settings['product_id'];
			$template 	= $settings['product_template'];

			global $product;

			if ( ! $product ) {
				$product = wc_get_product( $product_id );
			}

	    	if ( ! $product || ! $product->is_type('ovabrw_car_rental') ) {
				?>
				<div class="ovabrw_elementor_no_product">
					<span><?php echo $this->get_title(); ?></span>
				</div>
				<?php
				return;
			}

			if ( $template === 'modern' ): ?>
				<div class="ovabrw-modern-product">
					<?php ovabrw_get_template( 'modern/single/detail/ovabrw-product-form-tabs.php' ); ?>
				</div>
			<?php else:
				$product_id = $product->get_id();
			?>
				<div class="elementor-booking-form">
					<?php ovabrw_get_template( 'single/booking-form.php', array( 'id' => $product_id ) ); ?>
				</div>
			<?php endif;
		}
	}

	$widgets_manager->register( new OVABRW_Widget_Product_Booking_Form() );
}