<?php defined( 'ABSPATH' ) || exit();

// Validate Rent Day Max
if ( ! function_exists( 'ovabrw_val_day_max' ) ) {
    function ovabrw_val_day_max( $ovabrw_pickoff_date, $ovabrw_pickup_date, $ovabrw_rent_day_max ) {
        return ( $ovabrw_pickoff_date - $ovabrw_pickup_date ) > $ovabrw_rent_day_max*24*60*60 ? true : false;
    }
}

// Validate Rent Hour Max
if ( ! function_exists( 'ovabrw_val_hour_max' ) ) {
    function ovabrw_val_hour_max( $ovabrw_pickoff_date, $ovabrw_pickup_date, $ovabrw_rent_hour_max ) {
        return ( $ovabrw_pickoff_date - $ovabrw_pickup_date ) > $ovabrw_rent_hour_max*60*60 ? true : false;
    }
}

// Validate Rent Day Min
if ( ! function_exists( 'ovabrw_val_day_min' ) ) {
    function ovabrw_val_day_min( $ovabrw_pickoff_date, $ovabrw_pickup_date, $ovabrw_rent_day_min ) {
        return ( $ovabrw_pickoff_date - $ovabrw_pickup_date ) < $ovabrw_rent_day_min*24*60*60 ? true : false;
    }
}

// Validate Rent Hour Min
if ( ! function_exists( 'ovabrw_val_hour_min' ) ) {
    function ovabrw_val_hour_min( $ovabrw_pickoff_date, $ovabrw_pickup_date, $ovabrw_rent_hour_min ) {
        return ( $ovabrw_pickoff_date - $ovabrw_pickup_date ) < $ovabrw_rent_hour_min*60*60 ? true : false;
    }
}

// Return array deposit info
if ( ! function_exists( 'ova_calculate_deposit_remaining_amount' ) ) {
    function ova_calculate_deposit_remaining_amount ( $cart_item ) {
        $remaining_amount = $deposit_amount = 0;
        $product_id       = $cart_item['product_id'];
        $number_vehicle   = 1;

        if ( isset( $cart_item['ovabrw_number_vehicle'] ) && is_numeric( $cart_item['ovabrw_number_vehicle'] ) ) {
            $number_vehicle = $cart_item['ovabrw_number_vehicle'];
        }

        // Calculate Rent Time
        $ovabrw_pickup_date     = strtotime( $cart_item['ovabrw_pickup_date'] );
        $ovabrw_pickoff_date    = strtotime( $cart_item['ovabrw_pickoff_date'] );
        $rent_time              = get_time_bew_2day( $ovabrw_pickup_date, $ovabrw_pickoff_date, $product_id );

        if ( isset( $cart_item['rental_type'] ) && $cart_item['rental_type'] == 'period_time' ) {
            $line_total = floatval( $cart_item['period_price'] );
        } else {
            $get_price_by_date  = get_price_by_date( $product_id, $ovabrw_pickup_date, $ovabrw_pickoff_date );
            $quantity           = $get_price_by_date['quantity'];
            $line_total         = $get_price_by_date['line_total'];
        }

        // Total Resources & Services
        if ( $cart_item['resources'] && is_array( $cart_item['resources'] ) ) {
            $resources      = $cart_item['resources'];
            $resources_qty  = isset( $cart_item['resources_qty'] ) ? $cart_item['resources_qty'] : [];
            $line_total += ovabrw_get_total_resources( $product_id, $ovabrw_pickup_date, $ovabrw_pickoff_date, $resources, $resources_qty );
        }

        if ( $cart_item['ovabrw_service'] && is_array( $cart_item['ovabrw_service'] ) ) {
            $services       = $cart_item['ovabrw_service'];
            $services_qty   = isset( $cart_item['ovabrw_service_qty'] ) ? $cart_item['ovabrw_service_qty'] : [];
            $line_total += ovabrw_get_total_services( $product_id, $ovabrw_pickup_date, $ovabrw_pickoff_date, $services, $services_qty );
        }

        // x quantity
        $line_total = round( $line_total, wc_get_price_decimals() ) * $number_vehicle;

        // Custom Checkout Fields
        if ( isset( $cart_item['custom_ckf'] ) && ! empty( $cart_item['custom_ckf'] ) ) {
            $custom_ckf_qty = isset( $cart_item['custom_ckf_qty'] ) && ! empty( $cart_item['custom_ckf_qty'] ) ? $cart_item['custom_ckf_qty'] : [];

            $price_ckf = ovabrw_get_price_ckf( $product_id, $cart_item['custom_ckf'], $custom_ckf_qty );

            if ( $price_ckf ) {
                $line_total += $price_ckf * $number_vehicle;
            }
        }

        $deposit_enable = get_post_meta ( $product_id, 'ovabrw_enable_deposit', true );
        $value_deposit  = get_post_meta ( $product_id, 'ovabrw_amount_deposit', true );
        $value_deposit  = $value_deposit ? floatval( $value_deposit ) : 0;
        $deposit_type_deposit = get_post_meta ( $product_id, 'ovabrw_type_deposit', true );

        $sub_remaining_amount   = 0;
        $sub_deposit_amount     = $line_total;

        if ( $deposit_enable === 'yes' ) {
            if ( isset( $cart_item['ova_type_deposit'] ) && $cart_item['ova_type_deposit'] === 'full' ) {
                $sub_remaining_amount   = 0;
                $sub_deposit_amount     = $line_total;
            } elseif ( $cart_item['ova_type_deposit'] === 'deposit' ) {
                if ( $deposit_type_deposit === 'percent' ) {
                    $sub_deposit_amount     = ($line_total * $value_deposit) / 100;
                    $sub_remaining_amount   = $line_total - $sub_deposit_amount;
                } elseif ( $deposit_type_deposit === 'value' ) {
                    $sub_deposit_amount     = $value_deposit;
                    $sub_remaining_amount   = $line_total - $sub_deposit_amount;
                }
            }
        }

        $deposit_amount     += floatval( $sub_deposit_amount );
        $remaining_amount   += floatval( $sub_remaining_amount );

        $deposit_remaining_amount                       = [];
        $deposit_remaining_amount['deposit_amount']     = round( OVABRW_Get_Data::instance()->get_price_tax( $deposit_amount, $cart_item ), wc_get_price_decimals() );
        $deposit_remaining_amount['remaining_amount']   = round( OVABRW_Get_Data::instance()->get_price_tax( $remaining_amount, $cart_item ), wc_get_price_decimals() );
        $deposit_remaining_amount['ova_type_deposit']   = $cart_item['ova_type_deposit'];
        $deposit_remaining_amount['pay_total']          = round( $deposit_remaining_amount['deposit_amount'] + $deposit_remaining_amount['remaining_amount'] );

        return $deposit_remaining_amount;
    }
}

/**
 * [ova_validate_manage_store check product available]
 * @param  [number]  $car_id                product id
 * @param  [strtotime]  $ovabrw_pickup_date    the date has been filtered via function
 * @param  [strtotime]  $ovabrw_pickoff_date   the date has been filtered via function
 * @param  [string]  $ovabrw_pickup_loc     
 * @param  [string]  $ovabrw_pickoff_loc    
 * @param  [string]  $passed                true, false
 * @param  string  $validate              cart, checkout, empty
 * @param  integer $number_vehicle quantity in cart
 * @return [array]                         status, vehicle_availables
 */
if ( ! function_exists( 'ova_validate_manage_store' ) ) {
    function ova_validate_manage_store( $car_id, $pickup_date, $pickoff_date, $pickup_loc, $pickoff_loc, $passed,  $validate = 'cart', $number_vehicle = 1 ) {

        $number_vehicle = (int)$number_vehicle;
        
        // Check is Auto/Manual to make ID vehicle 
        $manage_store = get_post_meta( $car_id, 'ovabrw_manage_store', true );

        // Total Car in the Store
        $total_car_store = OVABRW_Get_Data::instance()->get_stock_quantity( $car_id );

        // Get array product ids when use WPML
        $array_product_ids = OVABRW_Get_Data::instance()->get_product_ids_multi_lang( $car_id );

        //init vedicle array
        $cart_vehicle_rented = $store_vehicle_rented = array();

        // Store all ID Vehicle avaiable
        $vehicle_availables = array();

        // Error: Unvailable time for renting
        $untime_startdate = get_post_meta( $car_id, 'ovabrw_untime_startdate', true );
        $untime_enddate   = get_post_meta( $car_id, 'ovabrw_untime_enddate', true );

        if ( $untime_startdate ) {
            foreach ( $untime_startdate as $key => $value ) {
                if ( ! ( $pickoff_date < strtotime( $untime_startdate[$key] ) || strtotime( $untime_enddate[$key] ) < $pickup_date ) ) {
                    if ( $validate != 'search' ) {
                        wc_clear_notices();
                        echo wc_add_notice( esc_html__( 'This time is not available for renting', 'ova-brw' ), 'error');
                    }
                    
                    return false; 
                }
            }
        }

        // Error: Unavailable Date for booking in settings
        $disable_week_day           = get_option( 'ova_brw_calendar_disable_week_day', '' );
        $product_disable_week_day   = get_post_meta( $car_id, 'ovabrw_product_disable_week_day', true );
        if ( $product_disable_week_day ) {
            $disable_week_day = $product_disable_week_day;
        }

        $data_disable_week_day = $disable_week_day != '' ? explode( ',', $disable_week_day ) : '';

        if ( $data_disable_week_day && $pickup_date && $pickoff_date ) {
            if ( ovabrw_allow_boooking_incl_disable_week_day() ) {
                $pickup_date_of_week    = date('w', $pickup_date );
                $pickoff_date_of_week   = date('w', $pickoff_date );

                if ( in_array( $pickup_date_of_week, $data_disable_week_day ) || in_array( $pickoff_date_of_week, $data_disable_week_day ) ) {

                    if ( $validate == 'search' ) {
                        return array( 'status' => false, 'vehicle_availables' => [] );
                    }

                    wc_clear_notices();
                    echo wc_add_notice( esc_html__( 'This time is not available for renting', 'ova-brw' ), 'error');
                    return false;
                }
            } else {
                $datediff       = (int)$pickoff_date - (int)$pickup_date;
                $total_datediff = round( $datediff / (60 * 60 * 24), wc_get_price_decimals() ) + 1;

                // get number day
                $pickup_date_of_week   = date('w', $pickup_date );
                $pickup_date_timestamp = $pickup_date;
                
                $i = 0;
                while ( $i <= $total_datediff ) {
                    if ( in_array( $pickup_date_of_week, $data_disable_week_day ) ) {
                        if ( $validate == 'search' ) {
                            return array( 'status' => false, 'vehicle_availables' => [] );
                        }
                        wc_clear_notices();
                        echo wc_add_notice( esc_html__( 'This time is not available for renting', 'ova-brw' ), 'error');
                        return false;
                    }

                    $pickup_date_of_week    = date('w', $pickup_date_timestamp );
                    $pickup_date_timestamp  = strtotime('+1 day', $pickup_date_timestamp);
                    $i++;
                }
            }
        }

        // Check Count Product in Order
        $store_vehicle_rented = ovabrw_vehicle_rented_in_order( $car_id, $pickup_date, $pickoff_date );
        
        // Check Count Product in Cart
        $cart_vehicle_rented  = ovabrw_vehicle_rented_in_cart( $car_id, $validate, $pickup_date, $pickoff_date );
        
        // Vehicle availables
        $data_vehicle = ovabrw_get_vehicle_available( $car_id, $store_vehicle_rented, $cart_vehicle_rented, $number_vehicle, $manage_store, $pickup_date, $pickoff_date, $pickup_loc, $pickoff_loc, $passed, $validate );
        
        if ( $data_vehicle && ( ! empty( $data_vehicle['vehicle_availables'] ) || ! empty( $data_vehicle['number_vehicle_available'] > 0 ) ) ) {
            return array( 'status' => $data_vehicle['passed'], 'vehicle_availables' => $data_vehicle['vehicle_availables'], 'number_vehicle_available' => $data_vehicle['number_vehicle_available'] );
        }

        return false;
    }
}

/**
 * Check vehicle rented in order
 */
if ( ! function_exists( 'ovabrw_vehicle_rented_in_order' ) ) {
    function ovabrw_vehicle_rented_in_order( $car_id, $pickup_date, $pickoff_date ) {
        $store_vehicle_rented_array = [];
        $quantity = $qty_order = 0;

        // Get array product ids when use WPML
        $array_product_ids = OVABRW_Get_Data::instance()->get_product_ids_multi_lang( $car_id );

        // Get Manage Vehicles
        $manage_vehicles = get_post_meta( $car_id, 'ovabrw_manage_store', true );

        // Get all Order ID by Product ID
        $statuses   = brw_list_order_status();
        $order_ids  = OVABRW_Get_Data::instance()->get_orders_by_product_id( $car_id, $statuses );

        if ( ! empty( $order_ids ) && is_array( $order_ids ) ) {
            foreach( $order_ids as $key => $value ) {
                // Get Order Detail by Order ID
                $order = wc_get_order($value);

                // Get Meta Data type line_item of Order
                $order_line_items = $order->get_items( apply_filters( 'woocommerce_purchase_order_item_types', 'line_item' ) );
                
                // For Meta Data
                foreach( $order_line_items as $item_id => $item ) {
                    $pickup_date_store = $pickoff_date_store = $id_vehicle_rented = '';

                    // Get product
                    $product_id = $item->get_product_id();

                    // Check Line Item have item ID is Car_ID
                    if ( in_array( $product_id , $array_product_ids ) ) {
                        // Get rental type
                        $ovabrw_rental_type = get_post_meta( $product_id, 'ovabrw_price_type', true );

                        // Check time to Prepare before delivered
                        if ( $ovabrw_rental_type == 'day' || $ovabrw_rental_type == 'transportation' ) {
                            $prepare_time = get_post_meta( $car_id, 'ovabrw_prepare_vehicle_day', true ) ? get_post_meta( $car_id, 'ovabrw_prepare_vehicle_day', true ) * 86400 : 0;
                        } else {
                            $prepare_time = get_post_meta( $car_id, 'ovabrw_prepare_vehicle', true ) ? get_post_meta( $car_id, 'ovabrw_prepare_vehicle', true ) * 60 : 0;
                        }

                        // Get value of pickup date, pickoff date
                        if ( $item && is_object( $item ) ) {
                            $pickup_date_store  = strtotime( $item->get_meta('ovabrw_pickup_date_real') );
                            $pickoff_date_store = strtotime( $item->get_meta('ovabrw_pickoff_date_real') ) + $prepare_time;
                            $id_vehicle_rented  = trim( $item->get_meta('id_vehicle') );
                            $qty_order          = trim( $item->get_meta('ovabrw_number_vehicle') );
                        }

                        // Only compare date when "PickOff Date in Store" > "Current Time" becaue "PickOff Date Rent" have to > "Current Time"
                        if ( $pickoff_date_store >= current_time( 'timestamp' ) ) {
                            if ( ! ( $pickup_date >= $pickoff_date_store || $pickoff_date <= $pickup_date_store ) ) {
                                $quantity += $qty_order;

                                if ( $id_vehicle_rented != '' ) {
                                    $id_vehicle_rented_arr = explode( ',', $id_vehicle_rented );

                                    if ( !empty( $id_vehicle_rented_arr ) && is_array( $id_vehicle_rented_arr ) ) {
                                        foreach( $id_vehicle_rented_arr as $value ) {
                                            array_push( $store_vehicle_rented_array, trim($value) );
                                        }
                                    }
                                }
                            }
                        }  
                    }
                } 
            }

            if ( $store_vehicle_rented_array != null ) {
                // Only get unique Id vehicle
                $store_vehicle_rented_array = array_unique( $store_vehicle_rented_array );
            }
        }

        if ( $manage_vehicles == 'store' ) {
            return $quantity;
        }

        return $store_vehicle_rented_array;
    }
}

/**
 * Check vehicle rented in cart
 */
if ( ! function_exists( 'ovabrw_vehicle_rented_in_cart' ) ) {
    function ovabrw_vehicle_rented_in_cart( $car_id, $validate, $pickup_date, $pickoff_date ) {
        // Init cart vehicle rented
        $cart_vehicle_rented_array = [];
        $quantity = 0;

        // Get Manage Vehicles
        $manage_vehicles = get_post_meta( $car_id, 'ovabrw_manage_store', true );

        // Get array product ids when use WPML
        $array_product_ids = OVABRW_Get_Data::instance()->get_product_ids_multi_lang( $car_id );

        if ( $validate == 'cart' ) {
            foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                $product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

                if ( in_array( $product_id, $array_product_ids ) ) {
                    $ovabrw_rental_type = get_post_meta( $product_id, 'ovabrw_price_type', true );

                    // Check time to Prepare before delivered
                    if ( $ovabrw_rental_type == 'day' || $ovabrw_rental_type == 'transportation' ) {
                        $prepare_time = get_post_meta( $car_id, 'ovabrw_prepare_vehicle_day', true ) ? get_post_meta( $car_id, 'ovabrw_prepare_vehicle_day', true ) * 86400 : 0;
                    } else {
                        $prepare_time = get_post_meta( $car_id, 'ovabrw_prepare_vehicle', true ) ? get_post_meta( $car_id, 'ovabrw_prepare_vehicle', true ) * 60 : 0;
                    }

                    if ( isset( $cart_item['ovabrw_pickup_date_real'] ) && isset( $cart_item['ovabrw_pickoff_date_real'] ) ) {
                        if ( !( $pickup_date >= strtotime( $cart_item['ovabrw_pickoff_date_real'] )+$prepare_time || $pickoff_date <= strtotime( $cart_item['ovabrw_pickup_date_real'] ) ) ) {
                            $quantity += $cart_item['ovabrw_number_vehicle'];

                            if ( isset( $cart_item['id_vehicle'] ) && $cart_item['id_vehicle'] != ''  ) {
                                $id_vehicle_rented_arr = json_decode( $cart_item['id_vehicle'], true );
                                
                                if ( !empty( $id_vehicle_rented_arr ) && is_array( $id_vehicle_rented_arr ) ) {
                                    foreach( $id_vehicle_rented_arr as $value ) {
                                        array_push( $cart_vehicle_rented_array, trim($value) );
                                    }
                                }  
                            }
                        }
                    }
                }
            }

            if ( $cart_vehicle_rented_array != null ) {
                $cart_vehicle_rented_array = array_unique( $cart_vehicle_rented_array );
            }
        }

        if ( $manage_vehicles == 'store' ) {
            return $quantity;
        }

        return $cart_vehicle_rented_array;
    }
}

/**
 * Get ids vehicle available
 */
if ( ! function_exists( 'ovabrw_get_ids_vehicle_available' ) ) {
    function ovabrw_get_ids_vehicle_available( $car_id = false, $store_vehicle_rented = [], $cart_vehicle_rented = [] ) {
        // init array
        $id_vehicles    = $ids_vehicle_available = [];
        $id_rented      = array_unique( array_merge( $store_vehicle_rented, $cart_vehicle_rented ) );

        if ( is_array( get_post_meta( $car_id, 'ovabrw_id_vehicles', true ) ) ) {
            $id_vehicles = get_post_meta( $car_id, 'ovabrw_id_vehicles', true );
        }

        $ids_vehicle_available  = array_diff( $id_vehicles, $id_rented );

        return $ids_vehicle_available;
    }
}

/**
 * Get vehicle available store
 */
if ( ! function_exists( 'ovabrw_get_vehicle_available' ) ) {
    function ovabrw_get_vehicle_available( $car_id = false, $store_vehicle_rented = [], $cart_vehicle_rented = [], $number_vehicle = 1, $manage_store = '', $pickup_date = '', $pickoff_date = '', $pickup_loc = '', $pickoff_loc = '', $passed = false, $validate = 'cart' ) {

        $vehicle_add_availables = $vehicle_availables = $data_vehicle = $id_rented = $ids_vehicle_available = [];

        // Total Car in the Store
        $total_car_store = OVABRW_Get_Data::instance()->get_stock_quantity( $car_id );

        if ( $manage_store == 'store' ) {
            $number_vehicle_available = $total_car_store - $store_vehicle_rented - $cart_vehicle_rented;
            if ( $number_vehicle_available > 0 && $number_vehicle_available >= $number_vehicle ) {
                $passed = true;
            }
        } else {
            // Unique Product ID Rented
            $id_rented = array_unique( array_merge( $store_vehicle_rented, $cart_vehicle_rented ) );

            // Array vehicle available
            $ids_vehicle_available    = ovabrw_get_ids_vehicle_available( $car_id, $store_vehicle_rented, $cart_vehicle_rented );
            $number_vehicle_available = count( $ids_vehicle_available );
        }

        if ( $manage_store == 'store' ) {
            if ( count( $id_rented ) < $total_car_store && ( $number_vehicle_available >= $number_vehicle ) ) {
                $i = 1;
                foreach( $ids_vehicle_available as $value ) {
                    $vehicle_add_availables[] = trim( $value );
                    $passed = true;
                    array_push( $vehicle_availables, $value );

                    if ( $i >= $number_vehicle ) {
                        break;
                    }
                    
                    $i++;
                }

                if ( $validate != 'search' && !wp_doing_ajax() ) {
                    WC()->session->set( 'id_vehicle_available' , json_encode( $vehicle_add_availables) );
                }
            } else {
                if ( $validate != 'search' && !wp_doing_ajax() ) {
                    if ( $number_vehicle > $number_vehicle_available && $number_vehicle_available != 0 && $number_vehicle_available > 0 ) {
                        wc_clear_notices();
                        echo wc_add_notice( sprintf( esc_html__( 'Available vehicle is %s', 'ova-brw'  ), $number_vehicle_available ), 'error');
                    } else {
                        wc_clear_notices();
                        echo wc_add_notice( esc_html__( 'Vehicle isn\'t available for this time, Please book other time.', 'ova-brw' ), 'error');
                    }

                    return false;
                }
            }
        }

        if ( $manage_store == 'id_vehicle' ) {
            $vehicle_avai = '';
            $check_vehicle_availables = [];

            if ( $ids_vehicle_available ) {
                foreach( $ids_vehicle_available as $key => $value ) {
                    $vehicle_avai = OVABRW_Get_Data::instance()->get_location_title_by_vehicle($value);
                    $id_vehicle_untime_startday = !empty( $vehicle_avai['untime'] ) ?  $vehicle_avai['untime']['startdate']  : '';
                    $id_vehicle_untime_enddate  = !empty( $vehicle_avai['untime'] ) ?  $vehicle_avai['untime']['enddate']  : '';

                    if ( isset($vehicle_avai['required']) && $vehicle_avai['required'] == 'yes' ) {
                        if ( $pickup_loc == $vehicle_avai['location'] ) {
                            if ( !( $pickup_date >= strtotime( $id_vehicle_untime_enddate ) || $pickoff_date <= strtotime( $id_vehicle_untime_startday ) ) && $id_vehicle_untime_startday != '' && $id_vehicle_untime_enddate != '' ) {
                                $number_vehicle_available--;
                            } else {
                                array_push( $check_vehicle_availables, $value );
                            }
                        } else {
                            $number_vehicle_available--;
                        }
                    } else {
                        if ( !( $pickup_date >= strtotime( $id_vehicle_untime_enddate ) || $pickoff_date <= strtotime( $id_vehicle_untime_startday ) ) && $id_vehicle_untime_startday != '' && $id_vehicle_untime_enddate != '' ) {
                                $number_vehicle_available--;
                        } else {
                            array_push( $check_vehicle_availables, $value );
                        }
                    }
                }
            }

            if ( $number_vehicle_available >= $number_vehicle ) {
                if ( !empty( $check_vehicle_availables ) && is_array( $check_vehicle_availables ) ) {
                    foreach ( $check_vehicle_availables as $val ) {
                        $vehicle_add_availables[] = $val;
                        array_push( $vehicle_availables, $val );
                    }
                }

                $passed = true;
                if ( $validate != 'search' && !wp_doing_ajax() ) {
                    WC()->session->set( 'id_vehicle_available' , json_encode( array_slice( $vehicle_add_availables, 0, $number_vehicle ) ) );
                }
            } else {
                if ( $validate != 'search' && !wp_doing_ajax() ) {
                    wc_clear_notices();
                    if ( $number_vehicle > $number_vehicle_available && $number_vehicle_available != 0 && $number_vehicle_available > 0 ) {
                        wc_clear_notices();
                        echo wc_add_notice( sprintf( esc_html__( 'Available vehicle is %s', 'ova-brw'  ), $number_vehicle_available ), 'error');
                    } else {
                        wc_clear_notices();
                        echo wc_add_notice( esc_html__( 'Vehicle isn\'t available for this time, Please book other time.', 'ova-brw' ), 'error');
                    }

                    return false;
                }
            }
        }

        $data_vehicle = [
            'passed'                    => $passed,
            'vehicle_availables'        => $vehicle_availables,
            'number_vehicle_available'  => $number_vehicle_available,
        ];

        return $data_vehicle;
    }
}

/**
 * Standardized Pick-up, Drop-off that the Guest enter at frontend
 * User for: Search, Compare with real date
 */
if ( ! function_exists( 'ovabrw_new_input_date' ) ) {
    function ovabrw_new_input_date( $product_id = '', $pickup_date = '', $pickoff_date = '', $period_package = '', $pick_up_loc = '', $pick_off_loc = '' ) {

        if ( ! $product_id ) return array( 'pickup_date_new' => '', 'pickoff_date_new' => '' );

        // When Rental Type is Period, We have to Set Start Time, End Time again.
        $rental_type = get_post_meta( $product_id, 'ovabrw_price_type', true );

        $defined_one_day = defined_one_day( $product_id );

        if ( $rental_type == 'period_time' && $period_package != '' && $pickup_date != '' ) {
            $rental_time_period = OVABRW_Get_Data::instance()->get_rental_info_period( $product_id, $pickup_date, $rental_type, $period_package );
            $pickup_date        = $rental_time_period['start_time'];
            $pickoff_date       = $rental_time_period['end_time'];
        }

        if ( $rental_type == 'day' && $defined_one_day == 'day' ) {
            $pickup_date    = $pickup_date ? strtotime( date( apply_filters( 'ovabrw_new_pickup_date_day_day' , 'Y-m-d H:i' ), $pickup_date ) ) : '';
            $pickoff_date   = $pickoff_date ? strtotime( date( apply_filters( 'ovabrw_new_dropoff_date_day_day' , 'Y-m-d H:i' ), $pickoff_date ) ) : '';

        } elseif ( $rental_type == 'day' && $defined_one_day == 'hour' ) {
            $pickup_date    = $pickup_date ? strtotime( date( apply_filters( 'ovabrw_new_pickup_date_day_hour' , 'Y-m-d H:i' ), $pickup_date ) ) : '';
            $pickoff_date   = $pickoff_date ? strtotime( date( apply_filters( 'ovabrw_new_dropoff_date_day_hour' , 'Y-m-d H:i' ), $pickoff_date ) ) : '';

        } elseif ( $rental_type == 'day' && $defined_one_day == 'hotel' ) {
            $pickup_date    = $pickup_date ? strtotime( date( 'Y-m-d', $pickup_date ) .' '.apply_filters( 'brw_real_pickup_time_hotel', '14:00' ) ) : '';
            $pickoff_date   = $pickoff_date ? strtotime( date( 'Y-m-d', $pickoff_date ) .' '.apply_filters( 'brw_real_dropoff_time_hotel', '11:00' ) ) : '';
        }

        //get dropoff in price type transportation
        if ( $rental_type === 'transportation' && $pick_up_loc != '' && $pick_off_loc != '' ) {
            $dropoff_date_by_setting = get_post_meta( $product_id, 'ovabrw_dropoff_date_by_setting', true );

            if ( $dropoff_date_by_setting === 'yes' ) {
                $pickoff_date = $pickoff_date ? strtotime( date( apply_filters( 'ovabrw_new_dropoff_date_location' , 'Y-m-d H:i' ), $pickoff_date ) ) : '';
            } else {
                $time_dropoff = ovabrw_get_time_by_pick_up_off_loc_transport( $product_id, $pick_up_loc, $pick_off_loc );
                $time_dropoff = 60 * $time_dropoff;
                $pickoff_date = intval( $pickup_date ) + $time_dropoff;
            }
        }

        if ( ! $pickoff_date ) {
            $pickoff_date = $pickup_date;
        }

        return array( 'pickup_date_new' => $pickup_date, 'pickoff_date_new' => $pickoff_date );
    }
}

/**
 * Check Unavilable time
 */
if ( ! function_exists( 'ovabrw_check_unavilable_time' ) ) {
    function ovabrw_check_unavilable_time( $product_id, $pickup_date, $pickoff_date ) {
        // Error: Unavilable time for renting
        $untime_startdate = get_post_meta( $product_id, 'ovabrw_untime_startdate', true );
        $untime_enddate   = get_post_meta( $product_id, 'ovabrw_untime_enddate', true );

        if ( $untime_startdate ) {
            foreach( $untime_startdate as $key => $value ) {
                if ( !( $pickoff_date < strtotime( $untime_startdate[$key] ) || strtotime( $untime_enddate[$key] ) < $pickup_date ) ) {
                    return true; 
                }
            }
        }

        // Error: Unavailable Date for booking in settings
        $disable_week_day           = get_option( 'ova_brw_calendar_disable_week_day', '' );
        $product_disable_week_day   = get_post_meta( $product_id, 'ovabrw_product_disable_week_day', true );
        if ( $product_disable_week_day ) {
            $disable_week_day = $product_disable_week_day;
        }
        
        $data_disable_week_day = $disable_week_day != '' ? explode( ',', $disable_week_day ) : '';

        if ( $data_disable_week_day && $pickup_date && $pickoff_date ) {
            if ( ovabrw_allow_boooking_incl_disable_week_day() ) {
                $pickup_date_of_week    = date('w', $pickup_date );
                $pickoff_date_of_week   = date('w', $pickoff_date );

                if ( in_array( $pickup_date_of_week, $data_disable_week_day ) || in_array( $pickoff_date_of_week, $data_disable_week_day ) ) {
                    return true;
                }
            } else {
                $datediff       = (int)$pickoff_date - (int)$pickup_date;
                $total_datediff = round( $datediff / (60 * 60 * 24), wc_get_price_decimals() ) + 1;

                // get number day
                $pickup_date_of_week   = date('w', $pickup_date );
                $pickup_date_timestamp = $pickup_date;
                
                $i = 0;
                while ( $i <= $total_datediff ) {
                    if ( in_array( $pickup_date_of_week, $data_disable_week_day ) ) {
                        return true;
                    }

                    $pickup_date_of_week    = date('w', $pickup_date_timestamp );
                    $pickup_date_timestamp  = strtotime('+1 day', $pickup_date_timestamp);
                    $i++;
                }
            }
        }

        return false;
    }
}

// Validate Booking Form
if ( ! function_exists( 'ovabrw_validate_data_booking' ) ) {
    function ovabrw_validate_data_booking( $product_id = false, $pickup_date = '', $dropoff_date = '' ) {
        if ( ! $product_id || ! $pickup_date || ! $dropoff_date ) return false;

        $rental_type = get_post_meta( $product_id, 'ovabrw_price_type', true );

        // Pickup Date
        if ( $pickup_date < current_time('timestamp') ) {
            return esc_html__( 'Pickup date must be greater than Current time', 'ova-brw' );
        }

        // Perparation Time
        $preparation_time = get_post_meta( $product_id, 'ovabrw_preparation_time', true );

        if ( $pickup_date && $preparation_time ) {
            $today = strtotime( date( 'Y-m-d', current_time( 'timestamp' ) ) );

            if ( $pickup_date < ( $today + $preparation_time*86400 ) ) {
                if ( absint( $preparation_time ) === 1 ) {
                    return sprintf( esc_html__( 'Book in advance %s day from the current date', 'ova-brw' ), $preparation_time );
                } else {
                    return sprintf( esc_html__( 'Book in advance %s days from the current date', 'ova-brw' ), $preparation_time );
                }
            }
        }

        if ( $rental_type !== 'transportation' ) {
            if ( $pickup_date > $dropoff_date ) {
                return esc_html__( 'Dropoff date must be greater than Pickup date', 'ova-brw' );
            }

            if ( $rental_type === 'day' ) {
                // Charged By
                $charged_by = defined_one_day( $product_id );

                // Rent day max
                $rent_day_max = (int)get_post_meta( $product_id, 'ovabrw_rent_day_max', true );

                // Rent day min
                $rent_day_min = (int)get_post_meta( $product_id, 'ovabrw_rent_day_min', true );

                if ( 'hotel' === $charged_by || 'hour' === $charged_by ) {
                    $hotel_pickup_date  = strtotime( date( 'Y-m-d', $pickup_date ) );
                    $hotel_pickoff_date = strtotime( date( 'Y-m-d', $dropoff_date ) );

                    if ( ! empty( $rent_day_max ) && ovabrw_val_day_max( $hotel_pickoff_date, $hotel_pickup_date, $rent_day_max ) ) {  
                        return sprintf( esc_html__( 'Max Rental Period: %d day', 'ova-brw' ), $rent_day_max );
                    }

                    if ( ovabrw_val_day_min( $hotel_pickoff_date, $hotel_pickup_date, $rent_day_min ) ) {
                        return sprintf( esc_html__( 'Min Rental Period: %d day', 'ova-brw' ), $rent_day_min );
                    }
                } else {
                    if ( ! empty( $rent_day_max ) && ovabrw_val_day_max( $dropoff_date, $pickup_date, $rent_day_max ) ) {
                        return sprintf( esc_html__( 'Max Rental Period: %d day', 'ova-brw' ), $rent_day_max );
                    }

                    if ( ovabrw_val_day_min( $dropoff_date, $pickup_date, $rent_day_min ) ) {
                        return sprintf( esc_html__( 'Min Rental Period: %d day', 'ova-brw' ), $rent_day_min );
                    }
                }
            }

            if ( $rental_type === 'hour' || $rental_type === 'mixed' ) {
                // Rent hour max
                $rent_hour_max = (int)get_post_meta( $product_id, 'ovabrw_rent_hour_max', true );

                // Rent hour min
                $rent_hour_min = (int)get_post_meta( $product_id, 'ovabrw_rent_hour_min', true );

                if ( ! empty( $rent_hour_max ) && ovabrw_val_hour_max( $dropoff_date, $pickup_date, $rent_hour_max ) ) { 
                    return sprintf( esc_html__( 'Max Rental Hours %d hour', 'ova-brw' ), $rent_hour_max );
                }

                if ( ovabrw_val_hour_min( $dropoff_date, $pickup_date, $rent_hour_min ) ) { 
                    return sprintf( esc_html__( 'Min Rental Hours %d hour', 'ova-brw' ), $rent_hour_min );
                }
            }
        }

        return false;
    }
}