<?php defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'OVABRW_Get_Data' ) ) {
    class OVABRW_Get_Data {
        protected static $_instance = null;
        protected $prefix = OVABRW_PREFIX;

        public function get_order_rent_time( $product_id = false, $order_status = array( 'wc-completed' ) ) {
            global $wpdb;

            $order_dates = $unavaiable_dates = $total_each_day = [];

            if ( ! $product_id ) return json_encode( $unavaiable_dates );

            // Rental type
            $rental_type = $this->get_meta_value( $product_id, 'price_type' );

            // Date format
            $date_format = ovabrw_get_date_format();

            // Get stock quantity of product
            $stock_qty = $this->get_stock_quantity( $product_id );

            // Calendar background
            $calendar_background = get_option( 'ova_brw_bg_calendar', '#c4c4c4' );

            if ( ! $calendar_background ) $calendar_background = '#c4c4c4';

            // Get product ids multi lang
            $product_ids = $this->get_product_ids_multi_lang( $product_id );

            // Get order ids
            $order_ids = $this->get_orders_by_product_id( $product_id, $order_status );

            if ( $this->is_array_exists( $order_ids ) ) {
                foreach ( $order_ids as $k => $order_id ) {
                    // Get Order
                    $order = wc_get_order( $order_id );

                    // Get order items
                    $order_items = $order->get_items( apply_filters( 'woocommerce_purchase_order_item_types', 'line_item' ) );

                    if ( $this->is_array_exists( $order_items ) ) {
                        foreach ( $order_items as $item_id => $item ) {
                            if ( $item && is_object( $item ) ) {
                                $p_id = $item->get_product_id();

                                if ( $p_id && ! in_array( $p_id , $product_ids ) ) continue;

                                $pickup_date    = strtotime( $item->get_meta( 'ovabrw_pickup_date_real' ) );
                                $dropoff_date   = strtotime( $item->get_meta( 'ovabrw_pickoff_date_real' ) );
                                $qty_booked     = intval( $item->get_meta( 'ovabrw_number_vehicle' ) );

                                if ( $dropoff_date >= current_time( 'timestamp' ) ) {
                                    for ( $i = 0; $i < $qty_booked; $i++ ) {
                                        if ( $rental_type === 'hotel' ) {
                                            $unavaiable = $this->get_unavailable_dates_by_hotel( $product_id, $pickup_date, $dropoff_date );
                                        } else {
                                            $unavaiable = $this->get_unavailable_dates( $product_id, $pickup_date, $dropoff_date );
                                        }

                                        if ( $this->is_array_exists( $unavaiable ) ) {
                                            $unavaiable_dates   = array_merge_recursive( $unavaiable_dates, $unavaiable['unavaiable_dates'] );
                                            $total_each_day     = array_merge_recursive( $total_each_day, $unavaiable['total_each_day'] );
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }

            // Check unavailable time
            $untime_startdate   = $this->get_meta_value( $product_id, 'untime_startdate' );
            $untime_enddate     = $this->get_meta_value( $product_id, 'untime_enddate' );

            if ( $this->is_array_exists( $untime_startdate ) && $this->is_array_exists( $untime_enddate ) ) {
                foreach ( $untime_startdate as $k => $start ) {
                    $end = isset( $untime_enddate[$k] ) ? $untime_enddate[$k] : '';

                    if ( strtotime( $start ) && strtotime( $end ) ) {
                        $unavaiable_time = [];

                        // Hotel
                        if ( $rental_type === 'hotel' ) {
                            $unavaiable_time = $this->get_unavailable_times_by_hotel( strtotime( $start ), strtotime( $end ) );
                        } else {
                            $unavaiable_time = $this->get_unavailable_times( strtotime( $start ), strtotime( $end ) );
                        }
                        

                        if ( $this->is_array_exists( $unavaiable_time ) ) {
                            $unavaiable_dates   = array_merge_recursive( $unavaiable_dates, $unavaiable_time['unavaiable_dates'] );
                            $total_each_day     = array_merge_recursive( $total_each_day, $unavaiable_time['total_each_day'] );

                            for ( $i = 1; $i < $stock_qty; $i++ ) {
                                $unavaiable_dates   = array_merge_recursive( $unavaiable_dates, $unavaiable_time['unavaiable_dates'] );
                                $total_each_day     = array_merge_recursive( $total_each_day, $unavaiable_time['total_each_day'] );
                            }
                        }
                    }
                }
            }

            // Vehicle IDs
            $manage_stock = $this->get_meta_value( $product_id, 'manage_store' );

            if ( $manage_stock === 'id_vehicle' ) {
                $vehicle_ids = $this->get_meta_value( $product_id, 'id_vehicles' );

                if ( $this->is_array_exists( $vehicle_ids ) ) {
                    foreach ( $vehicle_ids as $k => $vehicle_id ) {
                        $data_vehicle = $this->get_location_title_by_vehicle( $vehicle_id );

                        $vehicle_start_date = isset( $data_vehicle['untime']['startdate'] ) && $data_vehicle['untime']['startdate'] ? strtotime( $data_vehicle['untime']['startdate'] ) : '';
                        $vehicle_end_date   = isset( $data_vehicle['untime']['enddate'] ) && $data_vehicle['untime']['enddate'] ? strtotime( $data_vehicle['untime']['enddate'] ) : '';

                        if ( $vehicle_start_date && $vehicle_end_date ) {
                            $untime_vehicle = $this->get_unavailable_times( $vehicle_start_date, $vehicle_end_date );

                            if ( $this->is_array_exists( $untime_vehicle ) ) {
                                $unavaiable_dates   = array_merge_recursive( $unavaiable_dates, $untime_vehicle['unavaiable_dates'] );
                                $total_each_day     = array_merge_recursive( $total_each_day, $untime_vehicle['total_each_day'] );
                            }
                        }
                    }
                }
            }

            // Count total each day
            $count_unvailable = array_count_values( $total_each_day );

            // Rental: Day - Hotel
            if ( $rental_type === 'day' ) {
                $charged_by = $this->get_meta_value( $product_id, 'define_1_day' );

                if ( $charged_by === 'hotel' && $this->is_array_exists( $unavaiable_dates ) ) {
                    $compared_array = array();

                    foreach ( $unavaiable_dates as $k1 => $v1 ) {
                        $pickup_check  = apply_filters( 'brw_real_pickup_time_hotel', '14:00' ). '-24:00';
                        $dropoff_check = '00:00-' . apply_filters( 'brw_real_dropoff_time_hotel', '11:00' );

                        if ( trim( $v1['time'] ) === $pickup_check ) {
                            $start = date( 'Y-m-d', strtotime( $v1['start'] ) );
                            
                            if ( ! in_array( $start, $compared_array ) ) {
                                $k = 0;
                                array_push( $compared_array, $start );

                                foreach ( $unavaiable_dates as $k2 => $v2 ) {
                                    $start2 = date( 'Y-m-d', strtotime( $v2['start'] ) );

                                    if ( $start2 === $start && trim( $v2['time'] ) === $dropoff_check ) {
                                        $k++;
                                    }
                                }

                                if ( $k >= $stock_qty ) {
                                    $count_unvailable[$start] = $k;
                                }
                            }
                        }
                    }
                }
            }

            // Check available for rental: Period
            if ( $rental_type === 'period_time' ) {
                $args_unavailable = [];

                if ( ! empty( $unavaiable_dates ) && is_array( $unavaiable_dates ) ) {
                    foreach ( $unavaiable_dates as $items ) {
                        $start_date = isset( $items['start'] ) ? strtotime( $items['start'] ) : '';
                        $end_date   = isset( $items['end'] ) ? strtotime( $items['end'] ) : '';

                        if ( ! $start_date || ! $end_date ) continue;

                        $check_in   = $start_date ? strtotime( date( 'Y-m-d', $start_date ) ) : '';
                        $check_out  = $end_date ? strtotime( date( 'Y-m-d', $end_date ) ) : '';

                        if ( ! $check_in || ! $check_out || $check_in != $check_out ) continue;
                        if ( in_array( $check_in, $args_unavailable ) ) continue;

                        $check_vehicle = $this->check_available_package( $product_id, $check_in );

                        if ( ! $check_vehicle ) {
                            array_push( $args_unavailable, $check_in );

                            $unavaiable_dates[] = array(
                                'start'             => date( 'Y-m-d', $check_in ),
                                'end'               => date( 'Y-m-d', $check_in ),
                                'start_v2'          => date( $date_format, $check_in ),
                                'rendering'         => 'background',
                                'display'           => 'background',
                                'backgroundColor'   => $calendar_background,
                            );
                        }
                    }
                }
            }
        
            // Unavailable dates
            if ( $this->is_array_exists( $count_unvailable ) ) {
                foreach ( $count_unvailable as $date => $count ) {
                    if ( $count >= $stock_qty ) {
                        $item = array(  
                            'start'             => $date,
                            'end'               => $date,
                            'start_v2'          => date( $date_format, strtotime( $date ) ),
                            'rendering'         => 'background',
                            'display'           => 'background',
                            'backgroundColor'   => $calendar_background,
                            'overlap'           => false,
                            'title'             => '',
                        );

                        array_push( $unavaiable_dates, $item );
                    }
                }
            }

            return json_encode( $unavaiable_dates );
        }

        public function get_unavailable_dates( $product_id = false, $pickup_date = '', $dropoff_date = '' ) {
            if ( ! $product_id || ! $pickup_date || ! $dropoff_date ) return false;

            // Get Rental Type
            $rental_type = $this->get_meta_value( $product_id, 'price_type' );

            // Prepare time
            $prepare_time = 0;

            if ( ! in_array( $rental_type, array( 'day', 'transportation' ) ) ) {
                $prepare_time = intval( $this->get_meta_value( $product_id, 'prepare_vehicle' ) );
            } else {
                $prepare_time = intval( $this->get_meta_value( $product_id, 'prepare_vehicle_day' ) );
            }

            if ( $prepare_time ) $prepare_time = intval( $prepare_time ) * 60;

            $date_format    = 'Y-m-d';
            $time_format    = 'H:i';
            $dropoff_date   += $prepare_time;

            // Convert date
            $pickup_date_time   = date( $date_format.' '.$time_format, $pickup_date );
            $dropoff_date_time  = date( $date_format.' '.$time_format, $dropoff_date );
            $start_date         = date( $date_format, $pickup_date );
            $end_date           = date( $date_format, $dropoff_date );
            $start_time         = date( $time_format, $pickup_date );
            $end_time           = date( $time_format, $dropoff_date );

            if ( $end_time === '00:00' ) {
                $dropoff_date_time  = date( $date_format, $dropoff_date - 86400 ).' 24:00';
                $end_date           = date( $date_format, $dropoff_date - 86400 );
                $end_time           = '24:00';
            }

            // Hotel
            if ( $rental_type === 'day' ) {
                $charged_by = $this->get_meta_value( $product_id, 'define_1_day' );

                if ( $charged_by === 'hotel' ) {
                    $start_time = apply_filters( 'brw_real_pickup_time_hotel', '14:00' );
                    $end_time   = apply_filters( 'brw_real_dropoff_time_hotel', '11:00' );
                }
            }

            $unavaiable_dates   = $total_each_day = [];
            $between_days       = total_between_2_days( $start_date, $end_date );

            if ( $between_days == 0 ) {
                $item = array(
                    'start' => $pickup_date_time,
                    'end'   => $dropoff_date_time,
                    'title' => $start_time.'-'.$end_time,
                    'time'  => $start_time.'-'.$end_time
                );
                array_push( $unavaiable_dates, $item );

                if ( $start_time == '00:00' && $end_time == '24:00' ) {
                    array_push( $total_each_day, $start_date  );
                }
            } elseif ( $between_days == 1 ) {
                $item = array(
                    'start' => $pickup_date_time,
                    'end'   => $start_date.' 24:00',
                    'title' => $start_time.' '.esc_html__( '24:00', 'ova-brw' ),
                    'time'  => $start_time.'-24:00'
                );
                array_push( $unavaiable_dates, $item );

                if ( $start_time == '00:00' ) {
                    array_push( $total_each_day, $start_date );
                }

                $item = array(
                    'start' => $end_date,
                    'end'   => $dropoff_date_time,
                    'title' => esc_html__( '00:00', 'ova-brw' ).'-'.$end_time,
                    'time'  => '00:00-'.$end_time
                );
                array_push( $unavaiable_dates, $item ); 

                if ( $end_time == '24:00' ) {
                    array_push( $total_each_day, $end_date );
                }
            } else {
                $item = array(
                    'start' => $pickup_date_time,
                    'end'   => $pickup_date_time.' 24:00',
                    'title' => $start_time.'-'.esc_html__( '24:00', 'ova-brw' ),
                    'time'  => $start_time.'-24:00'
                );
                array_push( $unavaiable_dates, $item ); 

                if ( $start_time == '00:00' ) {
                    array_push( $total_each_day, $start_date );
                }

                $item = array(
                    'start' => $end_date.' 00:00',
                    'end'   => $dropoff_date_time,
                    'title' => esc_html__( '00:00', 'ova-brw' ).' '.$end_time,
                    'time'  => '00:00-'.$end_time
                );
                array_push( $unavaiable_dates, $item );

                if ( $end_time == '24:00' ) {
                    array_push( $total_each_day, $end_date );
                }
                
                $date_between = ovabrw_createDatefull( strtotime( $start_date ), strtotime( $end_date ), $date_format );

                // Remove first and last array
                array_shift( $date_between ); 
                array_pop( $date_between );

                foreach ( $date_between as $key => $value ) {
                    $item = array(
                        'start' => $value,
                        'end'   => $value,
                        'title' => esc_html__( '00:00-24:00 ', 'ova-brw' ),
                        'time'  => '00:00-24:00'
                    );
                    array_push( $unavaiable_dates, $item );
                    array_push( $total_each_day, $value );
                }
            }

            return apply_filters( 'get_unavailable_dates', [
                'unavaiable_dates'  => $unavaiable_dates,
                'total_each_day'    => $total_each_day
            ]);
        }

        public function get_unavailable_times( $pickup_date = '', $dropoff_date = '' ) {
            if ( ! $pickup_date || ! $dropoff_date ) return false;

            // Calendar background
            $calendar_background = get_option( 'ova_brw_bg_calendar', '#c4c4c4' );

            if ( ovabrw_global_typography() ) {
                $calendar_background = get_option( 'ovabrw_glb_primary_color', '#e56e00' );
            }

            if ( ! $calendar_background ) $calendar_background = '#c4c4c4';

            $date_format    = 'Y-m-d';
            $time_format    = 'H:i';

            // Convert date
            $pickup_date_time   = date( $date_format.' '.$time_format, $pickup_date );
            $dropoff_date_time  = date( $date_format.' '.$time_format, $dropoff_date );
            $start_date         = date( $date_format, $pickup_date );
            $end_date           = date( $date_format, $dropoff_date );
            $start_time         = date( $time_format, $pickup_date );
            $end_time           = date( $time_format, $dropoff_date );

            if ( $end_time === '00:00' ) {
                $pickup_date_time   = date( $date_format, $dropoff_date - 86400 ).' 24:00';
                $end_date           = date( $date_format, $dropoff_date - 86400 );
                $end_time           = '24:00';
            }

            $unavaiable_dates   = $total_each_day = [];
            $between_days       = total_between_2_days( $start_date, $end_date );

            if ( $between_days == 0 ) {
                $item = array(
                    'start'             => $pickup_date_time,
                    'end'               => $dropoff_date_time,
                    'title'             => $start_time.'-'.$end_time,
                    'time'              => $start_time.'-'.$end_time,
                    'backgroundColor'   => $calendar_background,
                    'borderColor'       => 'transparent'
                );
                array_push( $unavaiable_dates, $item );

                if ( $start_time == '00:00' && $end_time == '24:00' ) {
                    array_push( $total_each_day, $start_date  );
                }
            } elseif ( $between_days == 1 ) {
                $item = array(
                    'start'             => $pickup_date_time,
                    'end'               => $start_date.' 24:00',
                    'title'             => $start_time.'-'.esc_html__( '24:00','ova-brw' ),
                    'time'              => $start_time.'-24:00',
                    'backgroundColor'   => $calendar_background,
                    'borderColor'       => 'transparent'
                );
                array_push( $unavaiable_dates, $item );

                if ( $start_time == '00:00' ) {
                    array_push( $total_each_day, $start_date );
                }

                $item = array(
                    'start'             => $end_date,
                    'end'               => $dropoff_date_time,
                    'title'             => esc_html__( '00:00','ova-brw' ).'-'.$end_time,
                    'time'              => '00:00-'.$end_time,
                    'backgroundColor'   => $calendar_background,
                    'borderColor'       => 'transparent'
                );
                array_push( $unavaiable_dates, $item );

                if ( $end_time == '24:00' ) {
                    array_push( $total_each_day, $end_date );
                }
            } else {
                $item = array(
                    'start'             => $pickup_date_time,
                    'end'               => $start_date.' 24:00',
                    'title'             => $start_time.'-'.esc_html__( '24:00','ova-brw' ),
                    'time'              => $start_time.'-24:00',
                    'backgroundColor'   => $calendar_background,
                    'borderColor'       => 'transparent'
                );
                array_push( $unavaiable_dates, $item );

                if ( $start_time == '00:00' ) {
                    array_push( $total_each_day, $start_date );
                }

                $item = array(
                    'start'             => $end_date,
                    'end'               => $dropoff_date_time,
                    'title'             => esc_html__( '00:00','ova-brw' ).'-'.$end_time,
                    'time'              => '00:00-'.$end_time,
                    'backgroundColor'   => $calendar_background,
                    'borderColor'       => 'transparent'
                );
                array_push( $unavaiable_dates, $item );

                if ( $end_time == '24:00' ) {
                    array_push( $total_each_day, $end_date );
                }

                $date_between = ovabrw_createDatefull( strtotime( $start_date ), strtotime( $end_date ), $date_format );

                // Remove first and last array
                array_shift( $date_between ); 
                array_pop( $date_between );

                foreach ( $date_between as $key => $value ) {
                    $item = array(
                        'start'             => $value,
                        'end'               => $value,
                        'title'             => esc_html__( '00:00-24:00 ', 'ova-brw' ),
                        'time'              => '00:00-24:00',
                        'backgroundColor'   => $calendar_background,
                        'borderColor'       => 'transparent'
                    );
                    array_push( $unavaiable_dates, $item );
                    array_push( $total_each_day, $value );
                }
            }

            return apply_filters( 'get_unavailable_dates', [
                'unavaiable_dates'  => $unavaiable_dates,
                'total_each_day'    => $total_each_day
            ]);
        }

        public function get_unavailable_dates_by_hotel( $product_id = false, $pickup_date = '', $dropoff_date = '' ) {
            if ( ! $product_id || ! $pickup_date || ! $dropoff_date ) return false;

            // Get Rental Type
            $rental_type = $this->get_meta_value( $product_id, 'price_type' );
            $date_format = 'Y-m-d';

            // Convert date
            $start_date = date( $date_format, $pickup_date );
            $end_date   = date( $date_format, $dropoff_date );

            $unavaiable_dates   = $total_each_day = [];
            $between_days       = total_between_2_days( $start_date, $end_date );

            if ( $between_days == 0 ) {
                array_push( $total_each_day, $start_date );
            } elseif ( $between_days == 1 ) {
                array_push( $total_each_day, $start_date );
            } else {
                array_push( $total_each_day, $start_date );
                
                $date_between = ovabrw_createDatefull( strtotime( $start_date ), strtotime( $end_date ), $date_format );

                // Remove first and last array
                array_shift( $date_between ); 
                array_pop( $date_between );

                foreach ( $date_between as $key => $value ) {
                    array_push( $total_each_day, $value );
                }
            }

            return apply_filters( 'get_unavailable_dates', [
                'unavaiable_dates'  => $unavaiable_dates,
                'total_each_day'    => $total_each_day
            ]);
        }

        public function get_unavailable_times_by_hotel( $pickup_date = '', $dropoff_date = '' ) {
            if ( ! $pickup_date || ! $dropoff_date ) return false;

            // Calendar background
            $calendar_background = get_option( 'ova_brw_bg_calendar', '#c4c4c4' );

            if ( ovabrw_global_typography() ) {
                $calendar_background = get_option( 'ovabrw_glb_primary_color', '#e56e00' );
            }

            if ( ! $calendar_background ) $calendar_background = '#c4c4c4';

            $date_format = 'Y-m-d';

            // Convert date
            $start_date = date( $date_format, $pickup_date );
            $end_date   = date( $date_format, $dropoff_date );

            $unavaiable_dates   = $total_each_day = [];
            $between_days       = total_between_2_days( $start_date, $end_date );

            if ( $between_days == 0 ) {
                array_push( $total_each_day, $start_date );
            } elseif ( $between_days == 1 ) {
                array_push( $total_each_day, $start_date );
                array_push( $total_each_day, $end_date );
            } else {
                array_push( $total_each_day, $start_date );
                array_push( $total_each_day, $end_date );
                
                $date_between = ovabrw_createDatefull( strtotime( $start_date ), strtotime( $end_date ), $date_format );

                // Remove first and last array
                array_shift( $date_between ); 
                array_pop( $date_between );

                foreach ( $date_between as $key => $value ) {
                    array_push( $total_each_day, $value );
                }
            }

            return apply_filters( 'get_unavailable_dates', [
                'unavaiable_dates'  => $unavaiable_dates,
                'total_each_day'    => $total_each_day
            ]);
        }

        public function get_location_title_by_vehicle( $vehicle_id = false ) {
            if ( ! $vehicle_id ) return false;

            $vehicles = [];

            $args_query = [
                'post_type'         => 'vehicle',
                'post_status'       => 'publish',
                'posts_per_page'    => 1,
                'fields'            => 'ids',
                'meta_query'        => array(
                    array(
                        'key'     => 'ovabrw_id_vehicle',
                        'value'   => $vehicle_id,
                        'compare' => '=',
                    ),
                ),
            ];

            $vehicle_ids = get_posts( $args_query );

            if ( $this->is_array_exists( $vehicle_ids ) ) {
                foreach ( $vehicle_ids as $id ) {
                    $vehicles['location']   = $this->get_meta_value( $id, 'id_vehicle_location' );
                    $vehicles['required']   = $this->get_meta_value( $id, 'vehicle_require_location' );
                    $vehicles['untime']     = $this->get_meta_value( $id, 'id_vehicle_untime_from_day' );
                    $vehicles['vehicle_id'] = $this->get_meta_value( $id, 'id_vehicle' );
                    $vehicles['title']      = get_the_title( $id );
                }
            }

            return $vehicles;
        }

        public function get_vehicle_ids_available( $data ) {
            do_action( 'ovabrw_before_get_vehicle_available' );

            if ( ! $this->is_array_exists( $data ) ) return false;

            $product_name       = isset( $data['ovabrw_name_product'] ) ? sanitize_text_field( $data['ovabrw_name_product'] ) : '';
            $pickup_location    = isset( $data['ovabrw_pickup_loc'] ) ? sanitize_text_field( $data['ovabrw_pickup_loc'] ) : '';
            $dropoff_location   = isset( $data['ovabrw_pickoff_loc'] ) ? sanitize_text_field( $data['ovabrw_pickoff_loc'] ) : '';
            $pickup_date        = isset( $data['ovabrw_pickup_date'] ) ? $data['ovabrw_pickup_date'] : '';
            $dropoff_date       = isset( $data['ovabrw_pickoff_date'] ) ? $data['ovabrw_pickoff_date'] : '';
            $order              = isset( $data['order'] ) ? sanitize_text_field( $data['order'] ) : 'DESC';
            $order_by           = isset( $data['orderby'] ) ? sanitize_text_field( $data['orderby'] ) : 'ID';
            $attribute_name     = isset( $data['ovabrw_attribute'] ) ? sanitize_text_field( $data['ovabrw_attribute'] ) : '';
            $attribute_value    = isset( $data[$attribute_name] ) ? sanitize_text_field( $data[$attribute_name] ) : '';
            $category           = isset( $data['cat'] ) ? sanitize_text_field( $data['cat'] ) : '';
            $product_tag        = isset( $data['ovabrw_tag_product'] ) ? sanitize_text_field( $data['ovabrw_tag_product'] ) : '';
            $quantity           = isset( $data['quantity'] ) && $data['quantity'] ? intval( $data['quantity'] ) : 1;

            $adults          = isset( $data['ovabrw_adults'] )      ? sanitize_text_field( $data['ovabrw_adults'] )        : '';
            $children        = isset( $data['ovabrw_children'] )    ? sanitize_text_field( $data['ovabrw_children'] )      : '';
            $babies          = isset( $data['ovabrw_babies'] )      ? sanitize_text_field( $data['ovabrw_babies'] )        : '';

            // Taxi
            if ( isset( $data['pickup-date'] ) && $data['pickup-date'] ) {
                $pickup_date = $data['pickup-date'];

                if ( isset( $data['map-duration'] ) && $data['map-duration'] ) {
                    $dropoff_date = date( 'Y-m-d H:i', strtotime( $pickup_date ) + intval( $data['map-duration'] ) );
                }
            }

            // Number Seats
            $number_seats = isset( $data['number-seats'] ) ? intval( $data['number-seats'] ) : '';

            // Get list taxonomy
            $taxonomies     = [];
            $list_taxonomy  = ovabrw_create_type_taxonomies();
            
            if ( $this->is_array_exists( $list_taxonomy ) ) {
                foreach ( $list_taxonomy as $taxonomy ) {
                    $slug = isset( $taxonomy['slug'] ) ? $taxonomy['slug'] : '';

                    if ( $slug ) {
                        $taxo = isset( $data[$slug.'_name'] ) ? sanitize_text_field( $data[$slug.'_name'] ) : '';

                        if ( $taxo ) {
                            $taxonomies[] = [
                                'taxonomy'  => $slug,
                                'field'     => 'slug',
                                'terms'     => $taxo
                            ];
                        }
                    }
                }
            }

            $statuses   = brw_list_order_status();
            $error      = array();
            $item_ids   = $tax_query = array();

            // Base query
            $args_base = array(
                'post_type'         => 'product',
                'posts_per_page'    => '-1',
                'post_status'       => 'publish',
                'fields'            => 'ids',
                'tax_query'         => array(
                    'relation'      => 'AND',
                    array(
                        'taxonomy'  => 'product_type',
                        'field'     => 'slug',
                        'terms'     => 'ovabrw_car_rental'
                    )
                )
            );

            // Product name
            if ( $product_name ) {
                $args_base['s'] = preg_replace("/[^a-zA-Z]+/", " ", $product_name);
            }

            // Product category
            if ( $category ) {
                $taxonomies[] = [
                    'taxonomy'  => 'product_cat',
                    'field'     => 'slug',
                    'terms'     => $category
                ];
            }

            // Attribute
            if ( $attribute_name && $attribute_value ) {
                $taxonomies[] = [
                    'taxonomy'  => 'pa_' . $attribute_name,
                    'field'     => 'slug',
                    'terms'     => [$attribute_value],
                    'operator'  => 'IN',
                ];
            }

            // Product tag
            if ( $product_tag ) {
                $taxonomies[] = [
                    'taxonomy'  => 'product_tag',
                    'field'     => 'name',
                    'terms'     => $product_tag
                ];
            }

            // Taxonomy query
            if ( $this->is_array_exists( $taxonomies ) ) {
                $tax_query = [
                    'tax_query' => [
                        $taxonomies
                    ]
                ];
            }

            // Meta Query
            $args_meta_query_arr = $meta_query = [];

            // ==> Search by Guest
            if ( $adults != '' ) {
                $args_meta_query_arr[] = [
                    'key'     => 'ovabrw_max_adults',
                    'value'   => $adults,
                    'type'    => 'numeric',
                    'compare' => '>=',
                ];
            }

            if ( $children != '' ) {
                $args_meta_query_arr[] = [
                    'key'     => 'ovabrw_max_children',
                    'value'   => $children,
                    'type'    => 'numeric',
                    'compare' => '>=',
                ];
            }

            if ( $babies != '' ) {
                $args_meta_query_arr[] = [
                    'key'     => 'ovabrw_max_babies',
                    'value'   => $babies,
                    'type'    => 'numeric',
                    'compare' => '>=',
                ];
            }

            // Number seats
            if ( $number_seats ) {
                $args_meta_query_arr[] = [
                    'key'     => 'ovabrw_max_seats',
                    'value'   => $number_seats,
                    'type'    => 'numeric',
                    'compare' => '>=',
                ];
            }

            if ( ! empty( $args_meta_query_arr ) ) {
                $meta_query = array(
                    'meta_query' => array(
                        'relation'  => 'AND',
                        $args_meta_query_arr
                    )
                );
            }

            // Merge query
            $args_query = array_merge_recursive( $args_base, $tax_query, $meta_query );

            // Get product ids
            $product_ids = get_posts( $args_query );

            if ( $this->is_array_exists( $product_ids ) ) {
                foreach ( $product_ids as $product_id ) {
                    // Check location
                    if ( $pickup_location && $dropoff_location ) {
                        if ( ! ovabrw_check_location( $product_id, $pickup_location, $dropoff_location ) ) continue;
                    }

                    // Check dates
                    if ( strtotime( $pickup_date ) && strtotime( $dropoff_date ) ) {
                        $type = $this->get_meta_value( $product_id, 'price_type' );

                        // Object Rental Types
                        $rental_object = isset( OVABRW_Rental_Types::instance()->rental_types[$type] ) ? OVABRW_Rental_Types::instance()->rental_types[$type] : '';

                        if ( empty( $rental_object ) || ! is_object( $rental_object ) ) {
                            continue;
                        }

                        // Set Product ID
                        $rental_object->set_ID( $product_id );

                        $new_date = [
                            'pickup_date_new'   => '',
                            'dropoff_date_new'  => '',
                        ];

                        switch ( $type ) {
                            case 'day':
                                $new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), strtotime( $dropoff_date ) );
                                break;
                            case 'hour':
                                $new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), strtotime( $dropoff_date ) );
                                break;
                            case 'mixed':
                                $new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), strtotime( $dropoff_date ) );
                                break;
                            case 'period_time':
                                $new_date = [
                                    'pickup_date_new'   => strtotime( $pickup_date ),
                                    'dropoff_date_new'  => strtotime( $dropoff_date ),
                                ];
                                break;
                            case 'transportation':
                                $new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), strtotime( $dropoff_date ), $pickup_location, $dropoff_location );
                                break;
                            case 'taxi':
                                $new_date = [
                                    'pickup_date_new'   => strtotime( $pickup_date ),
                                    'dropoff_date_new'  => strtotime( $dropoff_date ),
                                ];
                                break;
                            default:
                                break;
                        }
                        
                        // Check Pick-up & Drop-off Date
                        $check_in    = $new_date['pickup_date_new'] ? $new_date['pickup_date_new'] : strtotime( $pickup_date );
                        $check_out   = $new_date['dropoff_date_new'] ? $new_date['dropoff_date_new'] : strtotime( $dropoff_date );

                        // Check available quantity
                        $data_available = $rental_object->get_qty_available( $check_in, $check_out, $pickup_location, $dropoff_location, 'search' );

                        if ( ! $data_available ) continue;

                        $qty_available  = intval( $data_available['qty_available'] );

                        if ( $qty_available && $qty_available >= $quantity ) {
                            array_push( $item_ids, $product_id );
                        }
                    } else {
                        array_push( $item_ids, $product_id );
                    }
                }
            }

            if ( $item_ids ) {
                $paged      = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;
                $per_page   = wc_get_default_products_per_row() * wc_get_default_product_rows_per_page();

                $args_query = array(
                    'post_type'         => 'product',
                    'posts_per_page'    => $per_page,
                    'paged'             => $paged,
                    'post_status'       => 'publish',
                    'post__in'          => $item_ids,
                    'order'             => $order,
                    'orderby'           => $order_by
                );

                $products = new WP_Query( $args_query );

                return $products;
            }

            do_action( 'ovabrw_after_get_vehicle_available' );

            return false;
        }
        
        public function get_stock_quantity( $product_id = false ) {
            if ( ! $product_id ) return 0;

            $manage_store   = $this->get_meta_value( $product_id, 'manage_store' );
            $stock_qty      = 0;

            if ( $manage_store === 'store' ) {
                $stock_qty = intval( $this->get_meta_value( $product_id, 'car_count' ) );
            } elseif ( $manage_store === 'id_vehicle' ) {
                $vehicle_ids    = $this->get_meta_value( $product_id, 'id_vehicles' );
                $stock_qty      = ! empty( $vehicle_ids ) ? count( $vehicle_ids ) : 0;
            }

            return $stock_qty;
        }

        public function get_product_ids_multi_lang( $product_id = false ) {
            if ( ! $product_id ) return [];

            $product_ids = [];

            if ( is_plugin_active( 'polylang/polylang.php' ) || is_plugin_active( 'polylang-pro/polylang.php' ) ) {
                $languages = pll_languages_list();

                if ( $this->is_array_exists( $languages ) ) {
                    foreach ( $languages as $lang ) {
                        $p_id = pll_get_post( $product_id, $lang );

                        if ( $p_id ) $product_ids[] = $p_id;
                    }
                }
            } elseif ( is_plugin_active( 'sitepress-multilingual-cms/sitepress.php' ) ) {
                global $sitepress;

                if ( $sitepress && is_object( $sitepress ) ) {
                    $trid           = $sitepress->get_element_trid( $product_id, 'post_product' );
                    $translations   = $sitepress->get_element_translations( $trid, 'product' );

                    if ( $this->is_array_exists( $translations ) ) {
                        foreach ( $translations as $lang => $translation ) {
                            $p_id = $translation->element_id;

                            if ( $p_id ) $product_ids[] = $p_id;
                        }
                    }
                }
            }

            if ( ! $this->is_array_exists( $product_ids ) ) {
                $product_ids[] = $product_id;
            }

            return $product_ids;
        }

        public function get_orders_by_product_id( $product_id = false, $order_status = array( 'wc-completed' ) ) {
            if ( ! $product_id ) return [];

            global $wpdb;
            $order_ids = array();

            // Get array product ids when use WPML
            $product_ids = $this->get_product_ids_multi_lang( $product_id );

            if ( ovabrw_wc_custom_orders_table_enabled() ) {
                $order_ids = $wpdb->get_col("
                    SELECT DISTINCT o.id
                    FROM {$wpdb->prefix}wc_orders AS o
                    LEFT JOIN {$wpdb->prefix}woocommerce_order_items AS oitems
                    ON o.id = oitems.order_id
                    LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta AS oitem_meta
                    ON oitems.order_item_id = oitem_meta.order_item_id
                    WHERE oitems.order_item_type = 'line_item'
                    AND oitem_meta.meta_key = '_product_id'
                    AND oitem_meta.meta_value IN ( ".implode( ',', $product_ids )." )
                    AND o.status IN ( '" . implode( "','", $order_status ) . "' )
                ");
            } else {
                $order_ids = $wpdb->get_col("
                    SELECT DISTINCT oitems.order_id
                    FROM {$wpdb->prefix}woocommerce_order_items AS oitems
                    LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta AS oitem_meta
                    ON oitems.order_item_id = oitems.order_item_id
                    LEFT JOIN {$wpdb->posts} AS posts ON oitems.order_id = posts.ID
                    WHERE posts.post_type = 'shop_order'
                    AND oitems.order_item_type = 'line_item'
                    AND oitem_meta.meta_key = '_product_id'
                    AND oitem_meta.meta_value IN ( ".implode( ',', $product_ids )." )
                    AND posts.post_status IN ( '" . implode( "','", $order_status ) . "' )
                ");
            }
            
            return $order_ids;
        }

        public function get_product_ids_by_rental_type( $type = '', $exclude_type = false ) {
            $args_query = array(
                'post_type'         => 'product',
                'posts_per_page'    => '-1',
                'post_status'       => 'publish',
                'fields'            => 'ids', 
                'tax_query'         => array(
                    array(
                        'taxonomy' => 'product_type',
                        'field'    => 'slug',
                        'terms'    => 'ovabrw_car_rental', 
                    ),
                ),
            );

            if ( $type ) {
                $args_query['meta_query'] = array(
                    array(
                        'key'     => 'ovabrw_price_type',
                        'value'   => $type,
                        'compare' => '=',
                    ),
                );

                if ( $exclude_type ) {
                    $args_query['meta_query'] = array(
                        array(
                            'key'     => 'ovabrw_price_type',
                            'value'   => $type,
                            'compare' => '!=',
                        ),
                    );
                }
            }

            $product_ids = get_posts( $args_query );

            return $product_ids;
        }

        public function get_all_location_ids() {
            $locations = get_posts(
                array(
                    'post_type'         => 'location',
                    'post_status'       => 'publish',
                    'posts_per_page'    => '-1',
                    'fields'            => 'ids'
                )
            );

            return $locations;
        }

        public function get_data_location() {
            $locations      = $this->get_all_location_ids();
            $data_location  = array();

            if ( $this->is_array_exists( $locations ) ) {
                foreach ( $locations as $location_id ) {
                    $data_location[trim( get_the_title( $location_id ) )] = trim( get_the_title( $location_id ) );
                }
            }
            
            return $data_location;
        }

        public function get_couple_location( $product_id = false ) {
            if ( ! $product_id ) return [];

            $pickup_location    = $this->get_meta_value( $product_id, 'st_pickup_loc' );
            $dropoff_location   = $this->get_meta_value( $product_id, 'st_dropoff_loc' );
            $couple_location    = [];

            if ( $this->is_array_exists( $pickup_location ) && $this->is_array_exists( $dropoff_location ) ) {
                foreach ( $pickup_location as $k => $pickup_loc ) {
                    $dropoff_loc = isset( $dropoff_location[$k] ) ? $dropoff_location[$k] : '';

                    if ( $pickup_loc && $dropoff_loc ) {
                        $couple_location[$pickup_loc][] = $dropoff_loc;
                        $couple_location[$pickup_loc]   = array_unique( $couple_location[$pickup_loc] );
                    }
                }
            }

            return $couple_location;
        }

        public function get_html_location( $name = '', $required = 'required', $selected = '', $product_id = false, $type = 'pickup', $show_other_location = false ) {
            if ( ! $name ) return '';

            // Get location ids
            $location_ids = $this->get_all_location_ids();

            if ( $product_id ) {
                if ( $type == 'pickup' ) {
                    $show_other_location = $this->get_meta_value( $product_id, 'show_other_location_pickup_product' );
                    $show_other_location = $show_other_location == 'no' ? false : true;
                } else {
                    $show_other_location = $this->get_meta_value( $product_id, 'show_other_location_dropoff_product' );
                    $show_other_location = $show_other_location == 'no' ? false : true;
                }
            }

            $html = '<select name="'.$name.'" class="'.$required.'">';
                $html .= '<option value="">'. esc_html__( 'Select Location', 'ova-brw' ).'</option>';

                // Loop locations
                if ( $this->is_array_exists( $location_ids ) ) {
                    foreach ( $location_ids as $location_id ) {
                        $title = get_the_title( $location_id );

                        if ( $title ) {
                            $active = ( trim( $title ) === trim( $selected ) ) ? 'selected="selected"' : '';
                            $html .= '<option value="'.$title.'" '.$active.'>'.$title.'</option>';
                        }
                    }
                }

                if ( $show_other_location ) {
                    $active = ( 'other_location' === trim( $selected ) ) ? 'selected="selected"' : '';
                    $html   .= '<option value="other_location" '.$active.'>'. esc_html__( 'Other Location', 'ova-brw' ).'</option>';
                }
            $html .= '</select>';

            return $html;
        }

        public function get_couple_location_transportation( $product_id = false ) {
            if ( ! $product_id ) return [];

            $pickup_location    = $this->get_meta_value( $product_id, 'pickup_location' );
            $dropoff_location   = $this->get_meta_value( $product_id, 'dropoff_location' );
            $couple_location    = [];

            if ( $this->is_array_exists( $pickup_location ) && $this->is_array_exists( $dropoff_location ) ) {
                foreach ( $pickup_location as $k => $pickup_loc ) {
                    $dropoff_loc = isset( $dropoff_location[$k] ) ? $dropoff_location[$k] : '';

                    if ( $pickup_loc && $dropoff_loc ) {
                        $couple_location[$pickup_loc][] = $dropoff_loc;
                        $couple_location[$pickup_loc]   = array_unique( $couple_location[$pickup_loc] );
                    }
                }
            }

            return $couple_location;
        }

        public function get_html_location_transportation( $name = '', $required = 'required', $selected = '', $product_id = false, $type = 'pickup' ) {
            if ( ! $name || ! $product_id ) return '';

            $couple_location = $this->get_couple_location_transportation( $product_id );
            $class = 'ovabrw-transport';

            if ( $required ) $class .= ' '.$required;

            $html = '<select name="'.$name.'" class="'.$class.'">';
                $html .= '<option value="">'.esc_html__( 'Select Location', 'ova-brw' ).'</option>';

                if ( $this->is_array_exists( $couple_location ) ) {
                    foreach ( $couple_location as $pickup_loc => $dropoff_loc ) {
                        $active = ( trim( $pickup_loc ) === trim( $selected ) ) ? 'selected="selected"' : '';
                        $html .= '<option data-item_loc="'.esc_attr(json_encode($dropoff_loc)).'" value="'.trim( $pickup_loc ).'" '.$active.'>'.trim( $pickup_loc ).'</option>';
                    }
                }
            $html .= '</select>';

            return $html;
        }

        public function get_html_couple_location( $name = '', $required = 'required', $selected = '', $product_id = false, $type = 'pickup', $validate = '' ) {
            if ( ! $name || ! $product_id ) return '';

            // Get couple location
            $couple_location = $this->get_couple_location( $product_id );

            // Show other location
            $show_other_location = true;

            if ( $type == 'pickup' ) {
                $show_other_location = $this->get_meta_value( $product_id, 'show_other_location_pickup_product' );
                $show_other_location = $show_other_location == 'no' ? false : true;
            } else {
                $show_other_location = $this->get_meta_value( $product_id, 'show_other_location_dropoff_product' );
                $show_other_location = $show_other_location == 'no' ? false : true;
            }

            // Required
            $class = 'ovabrw-transport';
            if ( $required ) $class .= ' '.$required;

            $html = '<select name="'.$name.'" class="'.$class.'">';
                $html .= '<option value="">'. esc_html__( 'Select Location', 'ova-brw' ).'</option>';

            if ( $type == 'pickup' ) {
                if ( $this->is_array_exists( $couple_location ) ) {
                    foreach ( $couple_location as $loc => $item_loc ) {
                        $active = ( trim( $loc ) === trim( $selected ) ) ? 'selected="selected"' : '';
                        $html .= '<option data-item_loc="'.esc_attr(json_encode($item_loc)).'" value="'.trim( $loc ).'" '.$active.'>'.trim( $loc ).'</option>';
                    }
                }
            }

            if ( $type == 'dropoff' ) {
                $html = '<select name="'.$name.'" class="'.$class.'">';
                $html .= '<option value="">'. esc_html__( 'Select Location', 'ova-brw' ).'</option>';

                if ( $this->is_array_exists( $couple_location ) ) {
                    foreach ( $couple_location as $loc => $item_loc ) {
                        if ( trim( $loc ) === trim( $validate ) && $this->is_array_exists( $item_loc ) ) {
                            foreach ( $item_loc as $dropoff_loc ) {
                                $active = ( trim( $dropoff_loc ) === trim( $selected ) ) ? 'selected="selected"' : '';
                                $html .= '<option value="'.trim( $dropoff_loc ).'" '.$active.'>'.trim( $dropoff_loc ).'</option>';
                            }
                        }
                    }
                }
            }

            if ( $show_other_location ) {
                $active = 'other_location' === trim( $selected ) ? 'selected="selected"' : '';
                $html .= '<option value="other_location" '.$active.'>'. esc_html__( 'Other Location', 'ova-brw' ).'</option>';
            }

            $html .= '</select>';

            return $html;
        }

        public function get_all_vehicle_ids() {
            $vehicle_ids = get_posts(
                array(
                    'post_type'         => 'vehicle',
                    'post_status'       => 'publish',
                    'posts_per_page'    => '-1',
                    'fields'            => 'ids'
                )
            );

            return $vehicle_ids;
        }

        public function get_data_vehicles() {
            $data_vehicle   = [];
            $vehicle_ids    = $this->get_all_vehicle_ids();

            if ( $this->is_array_exists( $vehicle_ids ) ) {
                foreach ( $vehicle_ids as $id ) {
                    $vehicle_id = $this->get_meta_value( $id, 'id_vehicle' );

                    if ( $vehicle_id ) {
                        $data_vehicle[$vehicle_id] = get_the_title( $id );
                    }
                }
            }

            return $data_vehicle;
        }

        public function get_html_dropdown_taxonomies( $selected = '', $required = '', $exclude_id = '', $slug = '', $name = '' ) {
            $args = [
                'show_option_all'    => '',
                'show_option_none'   => esc_html__( 'All ', 'ovabrw' ) . esc_html( $name ) ,
                'option_none_value'  => '',
                'orderby'            => 'ID',
                'order'              => 'ASC',
                'show_count'         => 0,
                'hide_empty'         => 0,
                'child_of'           => 0,
                'exclude'            => $exclude_id,
                'include'            => '',
                'echo'               => 0,
                'selected'           => $selected,
                'hierarchical'       => 1,
                'name'               => $slug.'_name',
                'id'                 => '',
                'class'              => 'postform '.$required,
                'depth'              => 0,
                'tab_index'          => 0,
                'taxonomy'           => $slug,
                'hide_if_empty'      => false,
                'value_field'        => 'slug',
            ];

            return wp_dropdown_categories($args);
        }

        public function get_html_dropdown_categories( $selected = '', $required = '', $exclude_id = '', $label = '', $include_id = '' ) {
            if ( ! $label ) {
                $label = esc_html__( 'Select Category', 'ova-brw' );
            }
            
            $args = array(
                'show_option_all'    => '',
                'show_option_none'   => $label,
                'option_none_value'  => '',
                'orderby'            => 'ID',
                'order'              => 'ASC',
                'show_count'         => 0,
                'hide_empty'         => 0,
                'child_of'           => 0,
                'exclude'            => $exclude_id,
                'include'            => $include_id,
                'echo'               => 0,
                'selected'           => $selected,
                'hierarchical'       => 1,
                'name'               => 'cat',
                'id'                 => '',
                'class'              => 'postform '.$required,
                'depth'              => 0,
                'tab_index'          => 0,
                'taxonomy'           => 'product_cat',
                'hide_if_empty'      => false,
                'value_field'        => 'slug',
            );

            return wp_dropdown_categories($args);
        }

        public function get_rental_info_period( $product_id = false, $start_date = '', $rental_type = '', $package_id = '' ) {
            $results = [
                'start_time'    => 0,
                'end_time'      => 0,
                'period_label'  => '',
                'period_price'  => '',
                'package_type'  => '',
            ];

            if ( ! $product_id || ! $start_date || ! $rental_type || ! $package_id ) return $results;
            
            $unfixed_time = $this->get_meta_value( $product_id, 'unfixed_time' );

            if ( $unfixed_time == 'yes' ) {
                $start_date = date( 'Y-m-d H:i', $start_date );
            } else {
                $start_date = date( 'Y-m-d', $start_date );
            }

            $start_time     = $end_time = 0;
            $period_price   = 0;
            $pickup_date    = strtotime( $start_date );

            if ( trim( $rental_type ) == 'period_time' ) {
                $petime_ids         = $this->get_meta_value( $product_id, 'petime_id' );
                $petime_prices      = $this->get_meta_value( $product_id, 'petime_price' );
                $petime_days        = $this->get_meta_value( $product_id, 'petime_days' );
                $petime_labels      = $this->get_meta_value( $product_id, 'petime_label' );
                $petime_discounts   = $this->get_meta_value( $product_id, 'petime_discount' );
                $package_types      = $this->get_meta_value( $product_id, 'package_type' );
                $pehour_unfixed     = $this->get_meta_value( $product_id, 'pehour_unfixed' );
                $pehour_start_times = $this->get_meta_value( $product_id, 'pehour_start_time' );
                $pehour_end_times   = $this->get_meta_value( $product_id, 'pehour_end_time' );

                if ( $this->is_array_exists( $petime_ids ) ) { 
                    foreach ( $petime_ids as $k => $petime_id ) {
                        if ( $petime_id == $package_id ) {
                            $package_type = isset( $package_types[$k] ) ? $package_types[$k] : '';

                            if ( $package_type == 'inday' ) {
                                $pehour_start_time  = isset( $pehour_start_times[$k] ) ? $pehour_start_times[$k] : '';
                                $pehour_end_time    = isset( $pehour_end_times[$k] ) ? $pehour_end_times[$k] : '';

                                $start_time = strtotime( $start_date.' '.$pehour_start_time );
                                $end_time   = strtotime( $start_date.' '.$pehour_end_time );

                                if ( $unfixed_time == 'yes' ) {
                                    $pehort_unfixed_time = isset( $pehour_unfixed[$k] ) ? floatval( $pehour_unfixed[$k] ) : 0;

                                    $start_time = $pickup_date;
                                    $end_time   = $pickup_date + $pehort_unfixed_time*3600;
                                }

                                $results['period_label'] = isset( $petime_labels[$k] ) ? $petime_labels[$k] : '';
                                $results['package_type'] = 'inday';

                                $period_price       = isset( $petime_prices[$k] ) ? floatval( $petime_prices[$k] ) : 0;
                                $petime_discount    = isset( $petime_discounts[$k] ) ? $petime_discounts[$k] : [];

                                if ( $this->is_array_exists( $petime_discount ) ) {
                                    $dsc_price  = isset( $petime_discount['price'] ) ? $petime_discount['price'] : [];
                                    $dsc_start  = isset( $petime_discount['start_time'] ) ? $petime_discount['start_time'] : [];
                                    $dsc_end    = isset( $petime_discount['end_time'] ) ? $petime_discount['end_time'] : [];

                                    if ( $this->is_array_exists( $dsc_price ) ) {
                                        foreach ( $dsc_price as $k_p => $price ) {
                                            $start  = isset( $dsc_start[$k] ) ? strtotime( $dsc_start[$k] ) : 0;
                                            $end    = isset( $dsc_end[$k] ) ? strtotime( $dsc_end[$k] ) : 0;

                                            if ( $start <= $pickup_date && $pickup_date <= $end ) {
                                                $period_price = floatval( $price );
                                                break;
                                            }
                                        }
                                    }
                                }
                            } elseif ( $package_type == 'other' ) {
                                $petime_day = isset( $petime_days[$k] ) ? intval( $petime_days[$k] ) : 0;

                                $start_time = $pickup_date;
                                $end_time   = $start_time + $petime_day*86400;

                                $results['period_label'] = isset( $petime_labels[$k] ) ? $petime_labels[$k] : '';
                                $results['package_type'] = 'other';

                                $period_price       = isset( $petime_prices[$k] ) ? floatval( $petime_prices[$k] ) : 0;
                                $petime_discount    = isset( $petime_discounts[$k] ) ? $petime_discounts[$k] : [];

                                if ( $this->is_array_exists( $petime_discount ) ) {
                                    $dsc_price  = isset( $petime_discount['price'] ) ? $petime_discount['price'] : [];
                                    $dsc_start  = isset( $petime_discount['start_time'] ) ? $petime_discount['start_time'] : [];
                                    $dsc_end    = isset( $petime_discount['end_time'] ) ? $petime_discount['end_time'] : [];

                                    if ( $this->is_array_exists( $dsc_price ) ) {
                                        foreach ( $dsc_price as $k_p => $price ) {
                                            $start  = isset( $dsc_start[$k] ) ? strtotime( $dsc_start[$k] ) : 0;
                                            $end    = isset( $dsc_end[$k] ) ? strtotime( $dsc_end[$k] ) : 0;

                                            if ( $start <= $pickup_date && $pickup_date <= $end ) {
                                                $period_price = floatval( $price );
                                                break;
                                            }
                                        }
                                    }
                                }
                            }

                            break;
                        }
                    }
                }
            }

            $results['start_time']      = $start_time;
            $results['end_time']        = $end_time;
            $results['period_price']    = $period_price;

            return $results;
        }

        public function get_real_data( $product_id = false, $rental_type = '', $pickup_date = '', $dropoff_date = '' ) {
            $real_data = [
                'real_quantity' => '',
                'real_price'    => ''
            ];

            if ( ! $product_id || ! $rental_type || ! $pickup_date || ! $dropoff_date ) return $real_data;

            $rental_object = isset( OVABRW_Rental_Types::instance()->rental_types[$rental_type] ) ? OVABRW_Rental_Types::instance()->rental_types[$rental_type] : '';

            if ( empty( $rental_object ) || ! is_object( $rental_object ) ) {
                return $real_data;
            }

            // Set Product ID
            $rental_object->set_ID( $product_id );

            $real_data = $rental_object->get_real_data( $pickup_date, $dropoff_date );

            return $real_data;
        }

        public function get_orders_feature() {
            global $wpdb;

            $order_ids      = [];
            $order_status   = brw_list_order_status();

            if ( ovabrw_wc_custom_orders_table_enabled() ) {
                $order_ids = $wpdb->get_col("
                    SELECT DISTINCT o.id
                    FROM {$wpdb->prefix}wc_orders AS o
                    WHERE o.status IN ( '" . implode( "','", $order_status ) . "' )
                ");
            } else {
                $order_ids = $wpdb->get_col("
                    SELECT DISTINCT oitems.order_id
                    FROM {$wpdb->prefix}woocommerce_order_items AS oitems
                    LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta AS oitem_meta
                    ON oitems.order_item_id = oitem_meta.order_item_id
                    LEFT JOIN {$wpdb->posts} AS posts
                    ON oitems.order_id = posts.ID
                    WHERE posts.post_type = 'shop_order'
                    AND posts.post_status IN ( '" . implode( "','", $order_status ) . "' )
                ");
            }

            return $order_ids;
        }

        public function get_orders_not_remaining_invoice() {
            global $wpdb;

            $order_ids      = [];
            $order_status   = brw_list_order_status();

            if ( ovabrw_wc_custom_orders_table_enabled() ) {
                $order_ids = $wpdb->get_col("
                    SELECT DISTINCT o.id
                    FROM {$wpdb->prefix}wc_orders AS o
                    LEFT JOIN {$wpdb->prefix}woocommerce_order_items AS oitems
                    ON o.id = oitems.order_id
                    LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta AS oitem_meta
                    ON oitems.order_item_id = oitem_meta.order_item_id
                    WHERE oitem_meta.meta_key = 'ovabrw_remaining_amount_product'
                    AND oitem_meta.meta_value != 0
                    AND o.status IN ( '" . implode( "','", $order_status ) . "' )
                ");
            } else {
                $order_ids = $wpdb->get_col("
                    SELECT DISTINCT oitems.order_id
                    FROM {$wpdb->prefix}woocommerce_order_items AS oitems
                    LEFT JOIN {$wpdb->prefix}woocommerce_order_itemmeta AS oitem_meta
                    ON oitems.order_item_id = oitem_meta.order_item_id
                    LEFT JOIN {$wpdb->posts} AS posts
                    ON oitems.order_id = posts.ID
                    WHERE posts.post_type = 'shop_order'
                    AND oitem_meta.meta_key = 'ovabrw_remaining_amount_product'
                    AND oitem_meta.meta_value != 0
                    AND posts.post_status IN ( '" . implode( "','", $order_status ) . "' )
                ");
            }

            return $order_ids;
        }

        public function get_price_include_tax( $product_id = false, $product_price = 0 ) {
            $display_price_cart = get_option( 'woocommerce_tax_display_cart', 'incl' );

            if ( wc_tax_enabled() && wc_prices_include_tax() && $product_price && $display_price_cart === 'excl' ) {
                $product_data   = wc_get_product( $product_id );
                $tax_rates_data = WC_Tax::get_rates( $product_data->get_tax_class() );
                $rate_data      = reset($tax_rates_data);

                if ( $rate_data && isset( $rate_data['rate'] ) ) {

                    $rate           = $rate_data['rate'];
                    $tax_price      = $product_price - ( $product_price / ( ( $rate / 100 ) + 1 ) );
                    $product_price  = $product_price - round( $tax_price, wc_get_price_decimals() );
                }
            }
            
            return apply_filters( 'ovabrw_get_price_include_tax', $product_price, $product_id );
        }

        public function get_html_resources( $product_id = false, $resources = [], $start_date = false, $end_date = false, $qty = 1, $order_id = false, $resources_qty = [] ) {

            $html = '';

            if ( get_option( 'ova_brw_booking_form_show_extra', 'no' ) == 'no' ) {
                return $html;
            }

            $currency = '';

            if ( $order_id ) {
                $order = wc_get_order( $order_id );

                if ( ! empty( $order ) && is_object( $order ) ) {
                    $currency = $order->get_currency();
                }
            }

            if ( ! empty( $resources ) && is_array( $resources ) ) {
                foreach ( $resources as $key => $value ) {
                    $rs_data   = [];
                    $rs_data   = [
                        $key => $value
                    ];
                    $rs_price   = ovabrw_convert_price_in_admin( ovabrw_get_total_resources( $product_id, $start_date, $end_date, $rs_data ), $currency );

                    $res_qty = isset( $resources_qty[$key] ) && absint( $resources_qty[$key] ) ? ' (x'.absint( $resources_qty[$key] ).')' : '';
                    $html   .=  '<dt>' . $value . esc_html__( ': ', 'ova-brw' ) . '</dt><dd>' . ovabrw_wc_price( $rs_price * $qty, ['currency' => $currency] ) . $res_qty . '</dd>';
                }
            }

            return apply_filters( 'ovabrw_get_html_resources', $html, $product_id );
        }

        public function get_html_services( $product_id = false, $services = [], $start_date = false, $end_date = false, $qty = 1, $order_id = false, $services_qty = [] ) {
            $html = '';

            if ( get_option( 'ova_brw_booking_form_show_extra', 'no' ) == 'no' ) {
                return $html;
            }

            $currency = '';

            if ( $order_id ) {
                $order = wc_get_order( $order_id );

                if ( ! empty( $order ) && is_object( $order ) ) {
                    $currency = $order->get_currency();
                }
            }

            $service_id             = $this->get_meta_value( $product_id, 'service_id' );
            $service_name           = $this->get_meta_value( $product_id, 'service_name' );
            $service_price          = $this->get_meta_value( $product_id, 'service_price' );
            $service_duration_type  = $this->get_meta_value( $product_id, 'service_duration_type' );

            if ( ! empty( $services ) && is_array( $services ) ) {
                foreach ( $services as $value ) {
                    if ( ! empty( $value ) ) {
                        $sv_data = [];
                        array_push( $sv_data, $value );
                        foreach ( $service_id as $sv_key => $sv_value ) {
                            if ( in_array( $value, $sv_value ) ) {
                                foreach ( $sv_value as $id_key => $id_value ) {
                                    if ( $value == $id_value ) {
                                        $sv_price = ovabrw_convert_price_in_admin( ovabrw_get_total_services( $product_id, $start_date, $end_date, $sv_data ), $currency );
                                        $sv_qty = isset( $services_qty[$value] ) && absint( $services_qty[$value] ) ? ' (x'.absint( $services_qty[$value] ).')' : '';

                                        $html .= '<dt>' . $service_name[$sv_key][$id_key] . esc_html__( ': ', 'ova-brw' ) . '</dt><dd>' . ovabrw_wc_price( $sv_price * $qty, ['currency' => $currency] ) . $sv_qty . '</dd>';
                                    }
                                }
                            }
                        }
                    }
                }
            }

            return apply_filters( 'ovabrw_get_html_services', $html, $product_id );
        }

        public function get_html_ckf( $custom_ckf = [] , $qty = 1, $order_id = false, $custom_ckf_qty = [] ) {
            $html = '';

            $currency = '';

            if ( $order_id ) {
                $order = wc_get_order( $order_id );

                if ( ! empty( $order ) && is_object( $order ) ) {
                    $currency = $order->get_currency();
                }
            }

            if ( ! empty( $custom_ckf ) && is_array( $custom_ckf ) ) {
                $list_fields = get_option( 'ovabrw_booking_form', array() );

                foreach ( $custom_ckf as $k => $val ) {
                    if ( isset( $list_fields[$k] ) && ! empty( $list_fields[$k] ) ) {
                        $type = $list_fields[$k]['type'];

                        if ( $type === 'radio' ) {
                            $val_key = array_search( $val, $list_fields[$k]['ova_values'] );
                            $val_qty = isset( $custom_ckf_qty[$k] ) && absint( $custom_ckf_qty[$k] ) ? absint( $custom_ckf_qty[$k] ) : '';

                            if ( ! is_bool( $val_key ) ) {
                                $price = ovabrw_convert_price_in_admin( $list_fields[$k]['ova_prices'][$val_key], $currency );

                                if ( $price ) {
                                    if ( $val_qty ) {
                                        $html .= '<dt>' . $val . esc_html__( ': ', 'ova-brw' ) . '</dt><dd>' . ovabrw_wc_price( $price * $qty, ['currency' => $currency] ) . ' (x'.$val_qty.')</dd>';
                                    } else {
                                        $html .= '<dt>' . $val . esc_html__( ': ', 'ova-brw' ) . '</dt><dd>' . ovabrw_wc_price( $price * $qty, ['currency' => $currency] ) . '</dd>';
                                    }
                                }
                            }
                        }

                        if ( $type === 'checkbox' ) {
                            if ( ! empty( $val ) && is_array( $val ) ) {
                                foreach ( $val as $val_cb ) {
                                    $val_key = array_search( $val_cb, $list_fields[$k]['ova_checkbox_key'] );
                                    $val_qty = isset( $custom_ckf_qty[$val_cb] ) && absint( $custom_ckf_qty[$val_cb] ) ? absint( $custom_ckf_qty[$val_cb] ) : '';

                                    if ( ! is_bool( $val_key ) ) {
                                        $label = $list_fields[$k]['ova_checkbox_text'][$val_key];
                                        $price = ovabrw_convert_price_in_admin( $list_fields[$k]['ova_checkbox_price'][$val_key], $currency );

                                        if ( $price ) {
                                            if ( $val_qty ) {
                                                $html .= '<dt>' . $label . esc_html__( ': ', 'ova-brw' ) . '</dt><dd>' . ovabrw_wc_price( $price * $qty, ['currency' => $currency] ) . ' (x'.$val_qty.')</dd>';
                                            } else {
                                                $html .= '<dt>' . $label . esc_html__( ': ', 'ova-brw' ) . '</dt><dd>' . ovabrw_wc_price( $price * $qty, ['currency' => $currency] ) . '</dd>';
                                            }
                                        }
                                    }
                                }
                            }
                        }

                        if ( $type === 'select' ) {
                            $val_key = array_search( $val, $list_fields[$k]['ova_options_key'] );
                            $val_qty = isset( $custom_ckf_qty[$val] ) && absint( $custom_ckf_qty[$val] ) ? absint( $custom_ckf_qty[$val] ) : '';

                            if ( ! is_bool( $val_key ) ) {
                                $label = $list_fields[$k]['ova_options_text'][$val_key];
                                $price = ovabrw_convert_price_in_admin( $list_fields[$k]['ova_options_price'][$val_key], $currency );

                                if ( $price ) {
                                    if ( $val_qty ) {
                                        $html .= '<dt>' . $label . esc_html__( ': ', 'ova-brw' ) . '</dt><dd>' . ovabrw_wc_price( $price * $qty, ['currency' => $currency] ) . ' (x'.$val_qty.')</dd>';
                                    } else {
                                        $html .= '<dt>' . $label . esc_html__( ': ', 'ova-brw' ) . '</dt><dd>' . ovabrw_wc_price( $price * $qty, ['currency' => $currency] ) . '</dd>';
                                    }
                                }
                            }
                        }
                    }
                }
            }

            return apply_filters( 'ovabrw_get_html_ckf', $html, $custom_ckf );
        }

        public function get_html_extra( $resource_html = '', $service_html = '', $ckf_html = '' ) {
            $html = '';

            if ( ! empty( $resource_html ) || ! empty( $service_html ) || ! empty( $ckf_html ) ) {
                $html .= '<dl class="variation ovabrw_extra_item">';
                $html .= $ckf_html;
                $html .= $resource_html;
                $html .= $service_html;
                $html .= '</dl>';
            }

            return apply_filters( 'ovabrw_get_html_extra', $html );
        }

        public function get_html_total_pay( $total = 0, $cart_item = [] ) {
            if ( ! $total || ! $this->is_array_exists( $cart_item ) ) return '';

            $product_id = isset( $cart_item['product_id'] ) ? $cart_item['product_id'] : '';

            if ( ! $product_id ) return '';

            $product    = wc_get_product( $product_id );
            $tax_rates  = WC_Tax::get_rates( $product->get_tax_class() );

            if ( wc_tax_enabled() ) {
                if ( wc_prices_include_tax() ) {
                    if ( ! WC()->cart->display_prices_including_tax() ) {
                        $incl_tax = WC_Tax::calc_inclusive_tax( $total, $tax_rates );
                        $total   -= array_sum( $incl_tax );
                    }
                } else {
                    if ( WC()->cart->display_prices_including_tax() ) {
                        $excl_tax = WC_Tax::calc_exclusive_tax( $total, $tax_rates );
                        $total   += array_sum( $excl_tax ); 
                    }
                }
            }
            $html = '<br/><small>' . sprintf( __( '%s payable in total', 'ova-brw' ), ovabrw_wc_price( $total, [], false ) ) . '</small>';

            return apply_filters( 'ovabrw_get_html_total_pay', $html, $product_id );
        }

        public function get_html_ckf_order( $product_id = false ) {
            if ( ! $product_id ) return '';

            $list_ckf_output    = ovabrw_get_list_field_checkout( $product_id );
            $special_fields     = [ 'textarea', 'select', 'radio', 'checkbox', 'file', 'number', 'date' ];

            ob_start();
            if ( ! empty( $list_ckf_output ) && is_array( $list_ckf_output ) ):
                foreach ( $list_ckf_output as $key => $field ):
                    if ( array_key_exists( 'enabled', $field ) && $field['enabled'] == 'on' ):
                        if ( array_key_exists('required', $field) && $field['required'] == 'on' ) {
                            $class_required = 'required';
                        } else {
                            $class_required = '';
                        }
            ?>
                <div class="ovabrw-ckf ovabrw-ckf-<?php echo esc_attr( $key ); ?>">
                    <label><?php echo esc_html( $field['label'] ); ?></label>
                    <?php if ( $field['type'] === 'checkbox' ): ?>
                        <span class="ovabrw-ckf-span ovabrw-ckf-checkbox <?php echo 'ovabrw-'.esc_attr( $class_required ); ?>">
                    <?php else: ?>
                        <span class="ovabrw-ckf-span">
                    <?php endif; ?>
                        <?php if ( ! in_array( $field['type'], $special_fields ) ): ?>
                            <input 
                                type="<?php echo esc_attr( $field['type'] ); ?>" 
                                name="<?php echo esc_attr( $key ).'['.$product_id.']'; ?>" 
                                class="<?php echo esc_attr( $field['class'] ); ?>" 
                                placeholder="<?php echo esc_attr( $field['placeholder'] ); ?>" 
                                value="<?php echo esc_attr( $field['default'] ); ?>" 
                                <?php echo esc_attr( $class_required ); ?>
                            />
                        <?php endif; ?>
                        <?php if ( $field['type'] === 'textarea' ): ?>
                            <textarea name="<?php echo esc_attr( $key.'['.$product_id.']' ) ;?>" class="<?php echo esc_attr( $field['class'] ); ?>" placeholder="<?php echo esc_attr( $field['placeholder'] ); ?>" value="<?php echo $field['default']; ?>" cols="10" rows="5" <?php echo esc_attr( $class_required ); ?>></textarea>
                        <?php endif; ?>
                        <?php if ( $field['type'] === 'select' ):
                            $ova_options_key = $ova_options_text = $ova_options_qty = [];

                            if ( array_key_exists( 'ova_options_key', $field ) ) {
                                $ova_options_key = $field['ova_options_key'];
                            }

                            if ( array_key_exists( 'ova_options_text', $field ) ) {
                                $ova_options_text = $field['ova_options_text'];
                            }

                            if ( array_key_exists( 'ova_options_qty', $field ) ) {
                                $ova_options_qty = $field['ova_options_qty'];
                            }
                        ?>
                            <div class="ovabrw-select">
                                <select 
                                    name="<?php echo esc_attr( $key ).'['.$product_id.']'; ?>" 
                                    class="ovabrw-ckf-price <?php echo esc_attr( $field['class'] ); ?>" 
                                    <?php echo esc_attr( $class_required ); ?>
                                    data-key="<?php echo esc_attr( $key ); ?>"
                                    data-product-id="<?php echo esc_attr( $product_id ); ?>">
                                    <?php 
                                    if ( ! empty( $ova_options_text ) && is_array( $ova_options_text ) ):
                                        if ( $field['required'] != 'on' ): ?>
                                            <option value="">
                                                <?php printf( esc_html__( 'Select %s', 'ova_brw' ), $field['label'] ); ?>
                                            </option>
                                        <?php
                                        endif;
                                        foreach ( $ova_options_text as $k => $value ):
                                            ?>
                                            <option value="<?php echo esc_attr( $ova_options_key[$k] ); ?>"<?php selected( $field['default'], $ova_options_key[$k] ); ?>>
                                                <?php echo esc_html( $value ); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    <?php endif; ?>
                                </select>
                                <?php if ( ! empty( $ova_options_key ) && is_array( $ova_options_key ) ): ?>
                                    <?php foreach ( $ova_options_key as $k => $v ): ?>
                                        <?php if ( isset( $ova_options_qty[$k] ) && absint( $ova_options_qty[$k] ) ): ?>
                                            <div class="ovabrw-qty-control">
                                                <div class="ovabrw-qty-input">
                                                    <input
                                                        type="number"
                                                        name="<?php echo esc_attr( $key ).'_qty['.$product_id.']['.$v.']'; ?>"
                                                        class="qty-input"
                                                        value="1"
                                                        min="1"
                                                        max="<?php echo esc_attr( absint( $ova_options_qty[$k] ) ); ?>"
                                                        readonly
                                                    />
                                                    <span class="dashicons dashicons-arrow-down-alt2"></span>
                                                </div>
                                                <div class="ovabrw-qty-dropdown">
                                                    <div class="qty-btn minus">
                                                        <span class="dashicons dashicons-minus"></span>
                                                    </div>
                                                    <span class="qty">1</span>
                                                    <div class="qty-btn plus">
                                                        <span class="dashicons dashicons-plus"></span>
                                                    </div>
                                                </div>
                                            </div>
                                        <?php endif; ?>
                                    <?php endforeach; ?>
                                <?php endif; ?>
                            </div>
                        <?php endif; ?>
                        <?php if ( $field['type'] === 'radio' ):
                            $values     = isset( $field['ova_values'] ) ? $field['ova_values'] : '';
                            $qtys       = isset( $field['ova_qtys'] ) ? $field['ova_qtys'] : '';
                            $default    = isset( $field['default'] ) ? $field['default'] : '';

                            if ( ! empty( $values ) && is_array( $values ) ):
                                foreach ( $values as $k => $value ):
                                    $checked = '';

                                    if ( ! $default && $field['required'] === 'on' ) $default = $values[0];

                                    if ( $default === $value ) $checked = 'checked';
                        ?>          
                                <div class="ovabrw-radio ovabrw-ckf-price">
                                    <input 
                                        type="radio" 
                                        id="<?php echo 'ovabrw-radio'.esc_attr( $k ); ?>" 
                                        name="<?php echo esc_attr( $key ).'['.$product_id.']'; ?>" 
                                        value="<?php echo esc_attr( $value ); ?>" <?php echo esc_html( $checked ); ?>/>
                                    <label for="<?php echo 'ovabrw-radio'.esc_attr( $k ); ?>"><?php echo esc_html( $value ); ?></label>
                                    <?php if ( isset( $qtys[$k] ) && absint( $qtys[$k] ) ): ?>
                                        <div class="ovabrw-qty-control">
                                            <div class="ovabrw-qty-input">
                                                <input
                                                    type="number"
                                                    name="<?php echo esc_attr( $key ).'_qty['.$product_id.']['.$value.']'; ?>"
                                                    class="qty-input"
                                                    value="1"
                                                    min="1"
                                                    max="<?php echo esc_attr( absint( $qtys[$k] ) ); ?>"
                                                    readonly
                                                />
                                                <span class="dashicons dashicons-arrow-down-alt2"></span>
                                            </div>
                                            <div class="ovabrw-qty-dropdown">
                                                <div class="qty-btn minus">
                                                    <span class="dashicons dashicons-minus"></span>
                                                </div>
                                                <span class="qty">1</span>
                                                <div class="qty-btn plus">
                                                    <span class="dashicons dashicons-plus"></span>
                                                </div>
                                            </div>
                                        </div>
                                    <?php endif; ?>
                                </div>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        <?php endif; ?>
                        <?php if ( $field['type'] === 'checkbox' ):
                            $default        = isset( $field['default'] ) ? $field['default'] : '';
                            $checkbox_key   = isset( $field['ova_checkbox_key'] ) ? $field['ova_checkbox_key'] : [];
                            $checkbox_text  = isset( $field['ova_checkbox_text'] ) ? $field['ova_checkbox_text'] : [];
                            $checkbox_price = isset( $field['ova_checkbox_price'] ) ? $field['ova_checkbox_price'] : [];
                            $checkbox_qty   = isset( $field['ova_checkbox_qty'] ) ? $field['ova_checkbox_qty'] : [];

                            if ( ! empty( $checkbox_key ) && is_array( $checkbox_key ) ):
                                foreach ( $checkbox_key as $k => $val ):
                                    $checked = '';

                                    if ( ! $default && $field['required'] === 'on' ) $default = $val;

                                    if ( $default === $val ) $checked = 'checked';
                        ?>
                            <div class="ovabrw-checkbox ovabrw-ckf-price">
                                <input 
                                    type="checkbox" 
                                    id="<?php echo 'ovabrw-checkbox-'.esc_attr( $val ).'['.$product_id.']'; ?>" 
                                    class="" 
                                    name="<?php echo esc_attr( $key ).'['.$product_id.'][]'; ?>" 
                                    value="<?php echo esc_attr( $val ); ?>" <?php echo esc_html( $checked ); ?>/>
                                <label for="<?php echo 'ovabrw-checkbox-'.esc_attr( $val ).'['.$product_id.']'; ?>">
                                    <?php echo isset( $checkbox_text[$k] ) ? esc_html( $checkbox_text[$k] ) : ''; ?>
                                </label>
                                <?php if ( isset( $checkbox_qty[$k] ) && absint( $checkbox_qty[$k] ) ): ?>
                                    <div class="ovabrw-qty-control">
                                        <div class="ovabrw-qty-input">
                                            <input
                                                type="number"
                                                name="<?php echo esc_attr( $key ).'_qty['.$product_id.']['.$val.']'; ?>"
                                                class="qty-input"
                                                value="1"
                                                min="1"
                                                max="<?php echo esc_attr( absint( $checkbox_qty[$k] ) ); ?>"
                                                readonly
                                            />
                                            <span class="dashicons dashicons-arrow-down-alt2"></span>
                                        </div>
                                        <div class="ovabrw-qty-dropdown">
                                            <div class="qty-btn minus">
                                                <span class="dashicons dashicons-minus"></span>
                                            </div>
                                            <span class="qty">1</span>
                                            <div class="qty-btn plus">
                                                <span class="dashicons dashicons-plus"></span>
                                            </div>
                                        </div>
                                    </div>
                                <?php endif; ?>
                            </div>
                            <?php endforeach;?>
                            <span class="ovabrw-checkbox-error">
                                <?php printf( esc_html__( '%s field is required', 'ova-brw' ), $field['label'] ); ?>
                            </span>
                        <?php endif; endif; ?>
                        <?php if ( $field['type'] === 'file' ):
                            $mimes = apply_filters( 'ovabrw_ft_file_mimes', [
                                'jpg'   => 'image/jpeg',
                                'jpeg'  => 'image/pjpeg',
                                'png'   => 'image/png',
                                'pdf'   => 'application/pdf',
                                'doc'   => 'application/msword',
                            ]);
                        ?>
                            <div class="ovabrw-file">
                                <label for="<?php echo 'ovabrw-file-'.esc_attr( $key ); ?>">
                                    <span class="ovabrw-file-chosen">
                                        <?php esc_html_e( 'Choose File', 'ova-brw' ); ?>
                                    </span>
                                    <span class="ovabrw-file-name"></span>
                                </label>
                                <input 
                                    type="<?php echo esc_attr( $field['type'] ); ?>" 
                                    id="<?php echo 'ovabrw-file-'.esc_attr( $key ); ?>" 
                                    name="<?php echo esc_attr( $key ).'['.$product_id.']'; ?>" 
                                    class="<?php echo esc_attr( $field['class'] ); ?>" 
                                    data-max-file-size="<?php echo esc_attr( $field['max_file_size'] ); ?>" 
                                    data-file-mimes="<?php echo esc_attr( json_encode( $mimes ) ); ?>" 
                                    data-max-file-size-msg="<?php printf( esc_html__( 'Max file size: %sMB', 'ova-brw' ), $field['max_file_size'] ); ?>" 
                                    data-formats="<?php esc_attr_e( 'Supported formats: .jpg, .jpeg, .png, .pdf, .doc', 'ova-brw' ); ?>" <?php echo esc_attr( $class_required ); ?> 
                                    data-required="<?php esc_attr_e( 'This field is required', 'ova-brw' ); ?>"/>
                            </div>
                        <?php endif; ?>
                        <?php if ( $field['type'] === 'number' ):
                            $min = isset( $field['min'] ) && $field['min'] ? intval( $field['min'] ) : '';
                            $max = isset( $field['max'] ) && $field['max'] ? intval( $field['max'] ) : '';
                        ?>
                            <input
                                type="<?php echo esc_attr( $field['type'] ); ?>"
                                name="<?php echo esc_attr( $key ).'['.$product_id.']'; ?>"
                                class="<?php echo esc_attr( $field['class'] ); ?>"
                                value="<?php echo esc_attr( $field['default'] ); ?>"
                                min="<?php echo esc_attr( $min ); ?>"
                                max="<?php echo esc_attr( $max ); ?>"
                                placeholder="<?php echo esc_attr( $field['placeholder'] ); ?>"
                                autocomplete="off"
                                <?php echo esc_attr( $class_required ); ?>
                            />
                        <?php endif; ?>
                        <?php if ( $field['type'] === 'date' ):
                            $default    = isset( $field['default_date'] ) ? $field['default_date'] : '';
                            $min_date   = isset( $field['min_date'] ) ? $field['min_date'] : '';
                            $max_date   = isset( $field['max_date'] ) ? $field['max_date'] : '';
                            $class      = 'ovabrw-datepicker';

                            if ( $field['class'] ) {
                                $class .= ' '.$field['class'];
                            }
                        ?>
                            <input
                                type="text"
                                name="<?php echo esc_attr( $key ).'['.$product_id.']'; ?>"
                                class="<?php echo esc_attr( $class ); ?>"
                                value="<?php echo esc_attr( $default ); ?>"
                                data-min-date="<?php echo esc_attr( $min_date ); ?>"
                                data-max-date="<?php echo esc_attr( $max_date ); ?>"
                                placeholder="<?php echo esc_attr( $field['placeholder'] ); ?>"
                                onfocus="blur();"
                                <?php echo esc_attr( $class_required ); ?>
                            />
                        <?php endif; ?>
                    </span>
                </div>
            <?php
                    endif;
                endforeach;
            ?>
                <input 
                    type="hidden" 
                    name="data_custom_ckf" 
                    data-ckf="<?php echo esc_attr( json_encode( $list_ckf_output ) ); ?>" />
            <?php
            endif;

            $html = ob_get_contents(); 
            ob_end_clean();

            return apply_filters( 'ovabrw_get_html_ckf_order', $html, $product_id );
        }

        public function get_html_resources_order( $product_id = false, $currency = '' ) {
            if ( ! $product_id ) return '';

            $html       = '';
            $resources  = $this->get_meta_value( $product_id, 'resource_name' );

            if ( $this->is_array_exists( $resources ) ) {
                $resources_ids      = $this->get_meta_value( $product_id, 'resource_id' );
                $resources_prices   = $this->get_meta_value( $product_id, 'resource_price' );
                $duration_values    = $this->get_meta_value( $product_id, 'resource_duration_val' );
                $duration_types     = $this->get_meta_value( $product_id, 'resource_duration_type' );
                $resources_qtys     = $this->get_meta_value( $product_id, 'resource_quantity' );

                $html .= '<div class="resources_order">';
                    foreach ( $resources as $k => $rs_name ) {
                        $rs_id              = isset( $resources_ids[$k] ) ? $resources_ids[$k] : 0;
                        $rs_price           = isset( $resources_prices[$k] ) ? $resources_prices[$k] : 0;
                        $rs_duration_val    = isset( $duration_values[$k] ) ? $duration_values[$k] : '';
                        $rs_duration_type   = isset( $duration_types[$k] ) ? $duration_types[$k] : '';
                        $qty                = isset( $resources_qtys[$k] ) ? $resources_qtys[$k] : '';

                        switch ( $rs_duration_type ) {
                            case 'hours':
                                $rs_duration_type_text = esc_html__( 'Hour', 'ova-brw' );
                                break;
                            case 'days':
                                $rs_duration_type_text = esc_html__( 'Day', 'ova-brw' );
                                break;
                            case 'total':
                                $rs_duration_type_text = esc_html__( 'Total', 'ova-brw' );
                                break;
                            default:
                                $rs_duration_type_text = esc_html__( 'Total', 'ova-brw' );
                                break;
                        }

                        $html .= '<div class="res-item">';
                            $html .= '<div class="left">';
                                $html .= '<input 
                                            type="checkbox" 
                                            id="ovabrw_resource_checkboxs_bk_'. esc_html( $k ) .'" 
                                            data-resource_key="'. $rs_id .'" 
                                            name="ovabrw_resource_checkboxs['. $product_id .'][]" 
                                            value="'. esc_attr( $rs_id ) .'" 
                                            class="ovabrw_resource_checkboxs" />';
                                $html .= '<label for="ovabrw_resource_checkboxs_bk_'. esc_html( $k ) .'">'. $rs_name .'</label>';
                            $html .= '</div>';
                            $html .= '<div class="right">';
                                $html .= '<div class="unit">';
                                    $html .= '<span class="dur_price">'. ovabrw_wc_price( $rs_price, ['currency' => $currency] ) .'</span>';
                                    $html .= '<span class="slash">/</span>';

                                    if ( $rs_duration_val != '' ) {
                                        $html .= '<span class="dur_val">'. $rs_duration_val .'</span>';
                                    }

                                    $html .= '<span class="dur_type">'. $rs_duration_type_text .'</span>';
                                $html .= '</div>';

                                if ( absint( $qty ) ) {
                                    $html .= '<div class="res-qty ovabrw-qty-control">';
                                        $html .= '<div class="ovabrw-qty-input">';
                                            $html .= '<input
                                                type="number"
                                                class="qty-input"
                                                name="ovabrw_resource_quantity['. $product_id .']['.$rs_id.']"
                                                value="1"
                                                min="1"
                                                max="'.absint( $qty ).'"
                                                readonly />';
                                            $html .= '<span class="dashicons dashicons-arrow-down-alt2"></span>';
                                        $html .= '</div>';
                                        $html .= '<div class="ovabrw-qty-dropdown">';
                                            $html .= '<div class="qty-btn minus">';
                                                $html .= '<span class="dashicons dashicons-minus"></span>';
                                            $html .= '</div>';
                                            $html .= '<span class="qty">1</span>';
                                            $html .= '<div class="qty-btn plus">';
                                                $html .= '<span class="dashicons dashicons-plus"></span>';
                                            $html .= '</div>';
                                        $html .= '</div>';
                                    $html .= '</div>';
                                }

                            $html .= '</div>';
                        $html .= '</div>';
                    }
                $html .= '</div>';
            }

            return apply_filters( 'ovabrw_get_html_resources_order', $html, $product_id );
        }

        public function get_html_services_order( $product_id = false ) {
            if ( ! $product_id ) return '';

            $html       = '';
            $services   = $this->get_meta_value( $product_id, 'label_service' );

            if ( $this->is_array_exists( $services ) ) {
                $services_id            = $this->get_meta_value( $product_id, 'service_id' );
                $services_name          = $this->get_meta_value( $product_id, 'service_name' );
                $services_price         = $this->get_meta_value( $product_id, 'service_price' );
                $services_qty           = $this->get_meta_value( $product_id, 'service_qty' );
                $services_required      = $this->get_meta_value( $product_id, 'service_required' );
                $services_duration_type = $this->get_meta_value( $product_id, 'service_duration_type' );

                $html .= '<div class="services_order">';
                    for ( $i = 0; $i < count( $services ); $i++ ) {
                        $sv_ids             = isset( $services_id[$i] ) ? $services_id[$i] : [];
                        $sv_name            = isset( $services_name[$i] ) ? $services_name[$i] : [];
                        $sv_price           = isset( $services_price[$i] ) ? $services_price[$i] : [];
                        $sv_qty             = isset( $services_qty[$i] ) ? $services_qty[$i] : [];
                        $sv_required        = isset( $services_required[$i] ) ? $services_required[$i] : '';
                        $sv_duration_type   = isset( $services_duration_type[$i] ) ? $services_duration_type[$i] : '';

                        if ( $sv_required == 'yes' ) {
                            $requires = ' class="required"';
                        } else {
                            $requires = '';
                        }

                        $html .= '<div class="service-item">';
                            $html .= '<div class="error_item"><label>'. esc_html__( 'This field is required', 'ova-brw' ) .'</label></div>';

                            $html .= '<div class="ovabrw-select">';
                                $html .= '<select name="ovabrw_service['. $product_id .'][]"'. $requires .' data-product-id="'.esc_attr( $product_id ).'">';
                                    $html .= '<option value="">'. sprintf( esc_html__( 'Select %s', 'ova-brw' ), $services[$i] ) .'</option>';

                                    if ( ! empty( $sv_ids ) && is_array( $sv_ids ) ) {
                                        foreach( $sv_ids as $key => $value ) {
                                            $html .= '<option value="'. esc_attr( $value ) .'">'. esc_html( $sv_name[$key] ) .'</option>';
                                        }
                                    }
                                $html .= '</select>';
                                if ( ! empty( $sv_ids ) && is_array( $sv_ids ) ) {
                                    foreach ( $sv_ids as $k => $v ) {
                                        if ( isset( $sv_qty[$k] ) && absint( $sv_qty[$k] ) ) {
                                            $html .= '<div class="ovabrw-qty-control">';
                                                $html .= '<div class="ovabrw-qty-input">';
                                                    $html .= '<input
                                                        type="number"
                                                        name="ovabrw_service_quantity['. $product_id .']['.$v.']"
                                                        class="qty-input"
                                                        value="1"
                                                        min="1"
                                                        max="'.absint( $sv_qty[$k] ).'"
                                                        readonly
                                                    />';
                                                    $html .= '<span class="dashicons dashicons-arrow-down-alt2"></span>';
                                                $html .= '</div>';
                                                $html .= '<div class="ovabrw-qty-dropdown">';
                                                    $html .= '<div class="qty-btn minus">';
                                                        $html .= '<span class="dashicons dashicons-minus"></span>';
                                                    $html .= '</div>';
                                                    $html .= '<span class="qty">1</span>';
                                                    $html .= '<div class="qty-btn plus">';
                                                        $html .= '<span class="dashicons dashicons-plus"></span>';
                                                    $html .= '</div>';
                                                $html .= '</div>';
                                            $html .= '</div>';
                                        }
                                    }
                                }
                            $html .= '</div>';
                        $html .= '</div>';
                    }
                $html .= '</div>';
            }

            return apply_filters( 'ovabrw_get_html_services_order', $html, $product_id );
        }

        public function get_price_tax( $price = 0, $cart_item = [] ) {
            if ( ! $price || ! $this->is_array_exists( $cart_item ) ) return 0;

            $product_id = $cart_item['product_id'];

            if ( ! $product_id ) return 0;

            $product    = wc_get_product( $product_id );
            $tax_rates  = WC_Tax::get_rates( $product->get_tax_class() );

            if ( wc_tax_enabled() ) {
                if ( wc_prices_include_tax() ) {
                    if ( ! WC()->cart->display_prices_including_tax() ) {
                        $incl_tax = WC_Tax::calc_inclusive_tax( $price, $tax_rates );
                        $price   -= round( array_sum( $incl_tax ), wc_get_price_decimals() ); 
                    }
                } else {
                    if ( WC()->cart->display_prices_including_tax() ) {
                        $excl_tax = WC_Tax::calc_exclusive_tax( $price, $tax_rates );
                        $price   += round( array_sum( $excl_tax ), wc_get_price_decimals() ); 
                    }
                }
            }

            return apply_filters( 'ovabrw_get_price_tax', $price, $product_id );
        }

        public function get_taxes_by_price( $price = 0, $product_id = false, $prices_incl_tax = '' ) {
            if ( ! $price || ! $product_id || ! $prices_incl_tax ) return 0;

            $product    = wc_get_product( $product_id );
            $tax_rates  = WC_Tax::get_rates( $product->get_tax_class() );

            if ( wc_tax_enabled() ) {
                if ( $prices_incl_tax == 'yes' ) {
                    $incl_tax = WC_Tax::calc_inclusive_tax( $price, $tax_rates );
                    $taxes    = round( array_sum( $incl_tax ), wc_get_price_decimals() );
                } else {
                    $excl_tax = WC_Tax::calc_exclusive_tax( $price, $tax_rates );
                    $taxes    = round( array_sum( $excl_tax ), wc_get_price_decimals() );
                }
            }

            return apply_filters( 'ovabrw_get_taxes_by_price', $taxes, $product_id );
        }

        public function get_tax_amount_by_tax_rates( $price = 0, $tax_rates = 0, $prices_incl_tax = '' ) {
            if ( ! $price || ! $prices_incl_tax ) return 0;

            if ( wc_tax_enabled() ) {
                if ( $prices_incl_tax == 'yes' ) {
                    $tax_amount = round( $price - ( $price / ( ( $tax_rates / 100 ) + 1 ) ), wc_get_price_decimals() );
                } else {
                    $tax_amount = round( $price * ( $tax_rates / 100 ), wc_get_price_decimals() );
                }
            }

            return apply_filters( 'ovabrw_get_tax_amount_by_tax_rates', $tax_amount );
        }

        public function get_html_dropdown_attributes( $label = '' ) {
            if ( ! $label ) $label = esc_html__( 'Select Attribute', 'ova-brw' );

            $args       = array(); 
            $html       = $html_attr_value = '';
            $attributes = wc_get_attribute_taxonomies();

            if ( $this->is_array_exists( $attributes ) ) {
                $html .= '<select name="ovabrw_attribute" class="ovabrw_attribute"><option value="">'.$label.'</option>';

                foreach ( $attributes as $obj_attr ) {
                    if ( taxonomy_exists( wc_attribute_taxonomy_name( $obj_attr->attribute_name ) ) ) {
                        $html .= "<option value='".$obj_attr->attribute_name."'>".$obj_attr->attribute_label."</option>";

                        $term_attributes = get_terms( wc_attribute_taxonomy_name( $obj_attr->attribute_name ), 'orderby=name&hide_empty=0' );
                        if ( ! empty( $term_attributes ) ) {
                            $html_attr_value .= '<div class="label_search s_field ovabrw-value-attribute" id="'.$obj_attr->attribute_name.'"><select name="ovabrw_attribute_value" >';

                            foreach ( $term_attributes as $obj_attr_value ) {
                                $html_attr_value .= '<option value="'.$obj_attr_value->slug.'">'.$obj_attr_value->name.'</option>';
                            }

                            $html_attr_value .= '</select></div>';
                        }
                    }
                }
                $html .= '</select>';
            }

            $args['html_attr']         = $html;
            $args['html_attr_value']   = $html_attr_value;

            return apply_filters( 'ovabrw_get_html_dropdown_attributes', $args );
        }

        public function get_html_dropdown_taxonomies_search( $slug = '', $name = '', $selected = '' ) {
            $args = array(
                'show_option_all'    => '',
                'show_option_none'   => esc_html__( 'Select ', 'ovabrw' ) . esc_html( $name ) ,
                'option_none_value'  => '',
                'orderby'            => 'ID',
                'order'              => 'ASC',
                'show_count'         => 0,
                'hide_empty'         => 0,
                'child_of'           => 0,
                'exclude'            => '',
                'include'            => '',
                'echo'               => 0,
                'selected'           => $selected,
                'hierarchical'       => 1,
                'name'               => $slug.'_name',
                'id'                 => '',
                'class'              => 'custom_taxonomy',
                'depth'              => 0,
                'tab_index'          => 0,
                'taxonomy'           => $slug,
                'hide_if_empty'      => false,
                'value_field'        => 'slug',
            );

            return apply_filters( 'ovabrw_get_html_dropdown_taxonomies_search', wp_dropdown_categories( $args ), $slug, $name );
        }

        public function get_products_search( $data = [] ) {
            $number     = isset( $data['posts_per_page'] ) ? $data['posts_per_page'] : 12;
            $orderby    = isset( $data['orderby'] ) ? $data['orderby'] : 'date';
            $order      = isset( $data['order'] ) ? $data['order'] : 'DESC';

            $args = array(
                'post_type'         => 'product',
                'post_status'       => 'publish',
                'posts_per_page'    => $number,
                'orderby'           => $orderby,
                'order'             => $order,
            );

            $products = new WP_Query( $args );

            return apply_filters( 'ovabrw_get_products_search', $products, $data );
        }

        public function get_html_pagination_ajax( $total, $limit, $current ) {
            $html   = '';
            $pages  = ceil( $total / $limit );

            if ( $pages > 1 ) {
                $html .= '<ul>';

                if ( $current > 1 ) {
                    $html .= '<li><span data-paged="'.( $current - 1 ).'" class="prev page-numbers" >'.esc_html__( 'Previous', 'ova-brw' ).'</span></li>';
                }

                for ( $i = 1; $i <= $pages; $i++ ) {
                    if ( $current == $i ) {
                        $html .='<li><span data-paged="'.$i.'" class="prev page-numbers current" >'.esc_html( $i ).'</span></li>';
                    } else {
                        $html .= '<li><span data-paged="'.$i.'" class="prev page-numbers" >'.esc_html( $i ).'</span></li>';
                    }
                }

                if ( $current < $pages ) {
                    $html .= '<li><span data-paged="'. ( $current + 1 ) .'" class="next page-numbers" >'.esc_html__( 'Next', 'ova-brw' ).'</span></li>';
                }
            }

            return apply_filters( 'ovabrw_get_pagination_ajax', $html );
        }

        public function get_html_price( $product_id = false ) {
            if ( ! $product_id ) return '';

            $html   = '';
            $min    = $max = 0;

            $rental_type    = $this->get_meta_value( $product_id, 'price_type', 'day' );
            $price_hour     = floatval( $this->get_meta_value( $product_id, 'regul_price_hour' ) );
            $price_day      = floatval( $this->get_meta_value( $product_id, 'regular_price_day' ) );

            if ( ! $price_day ) $price_day = floatval( get_post_meta( $product_id, '_regular_price', true ) );

            // Get price
            $petime_price   = $this->get_meta_value( $product_id, 'petime_price' );
            $price_location = $this->get_meta_value( $product_id, 'price_location' );

            if ( $rental_type == 'period_time' && $petime_price && is_array( $petime_price ) ) {
                $min = min( $petime_price );
                $max = max( $petime_price );
            }

            if ( $rental_type == 'transportation' && $price_location && is_array( $price_location ) ) {
                $min = min( $price_location );
                $max = max( $price_location );
            }

            if ( $rental_type == 'period_time' || $rental_type == 'transportation' ) {
                if ( $min && $max && $min == $max ) {
                    $html .= '<div class="amount">'. ovabrw_wc_price( $min ) .'</div>';
                } elseif ( $min && $max ) {
                    $html .= '<div class="amount">'. ovabrw_wc_price( $min ) .' - '. ovabrw_wc_price( $max ) .'</div>';
                } else {
                    $html .= '';
                }
            } elseif ( $rental_type == 'hour' ) {
                $html .= '<div class="amount">'. ovabrw_wc_price( $price_hour ) .'</div>';
            } elseif ( $rental_type == 'day' ) {
                $html .= '<div class="amount">'. ovabrw_wc_price( $price_day, [], false ) .'</div>';
            } elseif ( $rental_type == 'mixed' ) {
                $html .= '<div class="amount">'. ovabrw_wc_price( $price_hour ) . esc_html__('/hour - ', 'ova-brw') . ovabrw_wc_price( $price_day, [], false ) . esc_html__('/day', 'ova-brw') .'</div>';
            } else {
                $html = '';
            }

            return apply_filters( 'ovabrw_get_html_price', $html, $product_id );
        }

        public function check_available_package( $product_id = false, $check_in = false ) {
            if ( ! $product_id || ! $check_in ) return false;

            $package_ids = get_post_meta( $product_id, 'ovabrw_petime_id', true );

            if ( ! empty( $package_ids ) && is_array( $package_ids ) ) {
                foreach ( $package_ids as $k => $package_id ) {
                    $new_input_date     = ovabrw_new_input_date( $product_id, $check_in, '', $package_id, '', '' );
                    $pickup_date_new    = $new_input_date['pickup_date_new'];
                    $pickoff_date_new   = $new_input_date['pickoff_date_new'];
                    $check_vehicle      = ova_validate_manage_store( $product_id, $pickup_date_new, $pickoff_date_new, '', '', false, 'search', 1 );
                
                    if ( $check_vehicle && $check_vehicle['status'] && ( $check_vehicle['vehicle_availables'] || $check_vehicle['number_vehicle_available'] ) ) {
                        return true;
                    }
                }
            }

            return false;
        }

        public function check_table_price_by_hour( $product_id = false ) {
            if ( ! $product_id ) return false;

            $flag = false;

            $gd_duration_val_min = $this->get_meta_value( $product_id, 'global_discount_duration_val_min' );
            $gd_duration_val_max = $this->get_meta_value( $product_id, 'global_discount_duration_val_max' );

            if ( $gd_duration_val_min ) asort( $gd_duration_val_min );
            if ( $gd_duration_val_max ) asort( $gd_duration_val_max );

            if ( $this->is_array_exists( $gd_duration_val_min ) || $this->is_array_exists( $gd_duration_val_max ) ) $flag = true;

            $rt_price_hour = $this->get_meta_value( $product_id, 'rt_price_hour' );

            if ( $this->is_array_exists( $rt_price_hour ) ) $flag = true;

            return apply_filters( 'ovabrw_check_table_price_by_hour', $flag, $product_id );
        }

        public function check_table_price_by_day( $product_id = false ) {
            if ( ! $product_id ) return false;

            $flag   = false;
            $daily  = ovabrw_p_weekdays( $product_id );

            if ( ! empty( $daily ) ) { 
                $flag = true;
            }

            $gd_duration_val_min = $this->get_meta_value( $product_id, 'global_discount_duration_val_min' );
            $gd_duration_val_max = $this->get_meta_value( $product_id, 'global_discount_duration_val_max' );

            if ( $gd_duration_val_min ) asort( $gd_duration_val_min );
            if ( $gd_duration_val_max ) asort( $gd_duration_val_max );

            if ( $this->is_array_exists( $gd_duration_val_min ) || $this->is_array_exists( $gd_duration_val_max ) ) $flag = true;

            $rt_price = $this->get_meta_value( $product_id, 'rt_price' );

            if ( $this->is_array_exists( $rt_price ) ) $flag = true;

            return apply_filters( 'ovabrw_check_table_price_by_day', $flag, $product_id );
        }

        public function check_table_price_by_period_time( $product_id = false ) {
            $flag = false;

            $petime_label = $this->get_meta_value( $product_id, 'petime_label' );

            if ( $this->is_array_exists( $petime_label ) ) $flag = true;

            return apply_filters( 'ovabrw_check_table_price_by_period_time', $flag, $product_id );
        }

        public function get_products_rental() {
            $args = array(
                'post_type'         => 'product',
                'fields'            => 'ids', 
                'post_status'       => 'publish',
                'posts_per_page'    => '-1',
                'orderby'           => 'ID',
                'order'             => 'ASC',
                'tax_query' => array(
                    array(
                        'taxonomy' => 'product_type',
                        'field'    => 'slug',
                        'terms'    => 'ovabrw_car_rental', 
                    ),
                ),
            );

            $products = get_posts( $args );

            return apply_filters( 'ovabrw_get_products_rental', $products );
        }

        public function get_products_gallery_ids( $product_id = false ) {
            if ( ! $product_id ) return false;

            $product = wc_get_product( $product_id );

            if ( ! empty( $product ) && is_object( $product ) ) {
                $image_ids = array();

                $product_image_id = $product->get_image_id();

                if ( $product_image_id ) {
                    array_push( $image_ids, $product_image_id );
                }

                $product_gallery_ids = $product->get_gallery_image_ids();

                if ( $product_gallery_ids && is_array( $product_gallery_ids ) ) {
                    $image_ids = array_merge( $image_ids, $product_gallery_ids );
                }

                return apply_filters( 'ovabrw_get_products_gallery_ids', $image_ids, $product_id );
            }

            return false;
        }

        public function get_label_pickup_date( $product_id = false ) {
            $label = esc_html__( 'Pick-up Date', 'ova-brw' );

            if ( ! $product_id ) return $label;

            $rental_type = get_post_meta( $product_id, 'ovabrw_price_type', true );

            if ( $rental_type === 'hotel' ) $label = esc_html__( 'Check in', 'ova-brw' );

            $global_lable = $this->get_meta_value( $product_id, 'label_pickup_date_product' );

            if ( $global_lable == 'new' ) {
                $label = $this->get_meta_value( $product_id, 'new_pickup_date_product' );
            } elseif ( $global_lable == 'category' ) {
                $terms = wp_get_post_terms( $product_id, 'product_cat', array( 'fields'=>'ids' ));

                if ( $terms && is_array( $terms ) ) {
                    $term_id = reset($terms);
                }

                $label = isset( $term_id ) ? get_term_meta( $term_id, 'ovabrw_lable_pickup_date', true ) : '';
            } else {
                $label = esc_html__( 'Pick-up Date', 'ova-brw' );
            }

            if ( $label == '' ) {
                $label = esc_html__( 'Pick-up Date', 'ova-brw' );

                if ( $rental_type === 'hotel' ) $label = esc_html__( 'Check in', 'ova-brw' );
            }

            return apply_filters( 'ovabrw_get_label_pickup_date', $label, $product_id );
        }

        public function get_label_pickoff_date( $product_id = false ) {
            $label = esc_html__( 'Drop-off Date', 'ova-brw' );

            if ( ! $product_id ) return $label;

            $rental_type = get_post_meta( $product_id, 'ovabrw_price_type', true );

            if ( $rental_type === 'hotel' ) $label = esc_html__( 'Check out', 'ova-brw' );

            $global_lable = $this->get_meta_value( $product_id, 'label_dropoff_date_product' );

            if ( $global_lable == 'new' ) {
                $label = $this->get_meta_value( $product_id, 'new_dropoff_date_product' );
            } elseif ( $global_lable == 'category' ) {
                $terms = wp_get_post_terms( $product_id, 'product_cat', array( 'fields'=>'ids' ));

                if ( $terms && is_array( $terms ) ) {
                    $term_id = reset($terms);
                }
                
                $label = isset( $term_id ) ? get_term_meta( $term_id, 'ovabrw_lable_dropoff_date', true ) : '';
            } else {
                $label = esc_html__( 'Drop-off Date', 'ova-brw');
            }

            if ( $label == '' ) {
                $label = esc_html__( 'Drop-off Date', 'ova-brw' );

                if ( $rental_type === 'hotel' ) $label = esc_html__( 'Check out', 'ova-brw' );
            }

            return apply_filters( 'ovabrw_get_label_pickoff_date', $label, $product_id );
        }

        public function get_average_product_review_by_cagegory( $category_id = false ) {
            if ( ! $category_id ) return;

            $average = $count = $total_rating = 0;

            $args = [
                'post_type'         => 'product',
                'post_status'       => 'publish',
                'posts_per_page'    => -1,
                'orderby'           => 'date',
                'order'             => 'DESC',
                'fields'            => 'ids',
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'term_id',
                        'terms'     => $category_id,
                        'operator'  => 'IN',
                    ),
                )
            ];

            $product_ids = get_posts( $args );

            if ( ! empty( $product_ids ) && is_array( $product_ids ) ) {
                foreach ( $product_ids as $product_id ) {
                    $product    = wc_get_product( $product_id );
                    $rating     = $product->get_average_rating();

                    if ( $rating ) {
                        $total_rating += floatval( $rating );
                        $count += 1;
                    }
                }
            }

            if ( floatval( $total_rating ) > 0 && absint( $count ) > 0 ) {
                $average = number_format( $total_rating / $count, 1, '.', ',' );
            }
            
            return apply_filters( 'ovabrw_get_average_product_review_by_cagegory', $average, $category_id );
        }

        public function get_product_ajax_filter( $args = [] ) {
            if ( ! $this->is_array_exists( $args ) ) return;

            $base_query = [
                'post_type'         => 'product',
                'post_status'       => 'publish',
                'paged'             => $args['paged'],
                'posts_per_page'    => $args['posts_per_page'],
                'orderby'           => $args['orderby'],
                'order'             => $args['order'],
                'tax_query'         => array(
                    array(
                        'taxonomy' => 'product_type',
                        'field'    => 'slug',
                        'terms'    => 'ovabrw_car_rental', 
                    ),
                ),
            ];

            // Term ID
            if ( isset( $args['term_id'] ) && $args['term_id'] ) {
                $args_taxonomy['tax_query'] = [
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'term_id',
                        'terms'     => $args['term_id'],
                        'operator'  => 'IN',
                    )
                ];

                $base_query = array_merge_recursive( $base_query, $args_taxonomy );
            }

            // Term Slug
            if ( isset( $args['term_slug'] ) && $args['term_slug'] ) {
                $args_taxonomy['tax_query'] = [
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'slug',
                        'terms'     => $args['term_slug'],
                        'operator'  => 'IN',
                    )
                ];

                $base_query = array_merge_recursive( $base_query, $args_taxonomy );
            }

            $products = new WP_Query( $base_query );
            
            return apply_filters( 'ovabrw_get_product_ajax_filter', $products, $args );
        }

        public function get_product_search_taxi_ajax( $args = [] ) {
            if ( ! $this->is_array_exists( $args ) ) return;

            $base_query = [
                'post_type'         => 'product',
                'post_status'       => 'publish',
                'paged'             => $args['paged'],
                'posts_per_page'    => $args['posts_per_page'],
                'orderby'           => $args['orderby'],
                'order'             => $args['order'],
                'tax_query'         => array(
                    array(
                        'taxonomy' => 'product_type',
                        'field'    => 'slug',
                        'terms'    => 'ovabrw_car_rental', 
                    ),
                ),
            ];

            // Term ID
            if ( isset( $args['term_id'] ) && $args['term_id'] ) {
                $args_taxonomy['tax_query'] = [
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'term_id',
                        'terms'     => $args['term_id'],
                        'operator'  => 'IN',
                    )
                ];

                $base_query = array_merge_recursive( $base_query, $args_taxonomy );
            }

            // Term Slug
            if ( isset( $args['term_slug'] ) && $args['term_slug'] ) {
                $args_taxonomy['tax_query'] = [
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'slug',
                        'terms'     => $args['term_slug'],
                        'operator'  => 'IN',
                    )
                ];

                $base_query = array_merge_recursive( $base_query, $args_taxonomy );
            }

            $products = new WP_Query( $base_query );
            
            return apply_filters( 'ovabrw_get_product_search_taxi_ajax', $products, $args );
        }

        public function get_product_filter( $args = [] ) {
            if ( ! $this->is_array_exists( $args ) ) return;

            $base_query = [
                'post_type'         => 'product',
                'post_status'       => 'publish',
                'posts_per_page'    => $args['posts_per_page'],
                'orderby'           => $args['orderby'],
                'order'             => $args['order'],
                'tax_query'         => array(
                    array(
                        'taxonomy' => 'product_type',
                        'field'    => 'slug',
                        'terms'    => 'ovabrw_car_rental', 
                    ),
                ),
            ];

            if ( ! empty( $args['categories'] ) && is_array( $args['categories'] ) ) {
                $args_taxonomy['tax_query'] = [
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'term_id',
                        'terms'     => $args['categories'],
                        'operator'  => 'IN',
                    )
                ];

                $base_query = array_merge_recursive( $base_query, $args_taxonomy );
            }

            $products = new WP_Query( $base_query );
            
            return apply_filters( 'ovabrw_get_product_filter', $products, $args );
        }

        public function get_pickup_time_picker( $product_id = false ) {
            if ( ! $product_id ) return false;

            $rental_type = $this->get_meta_value( $product_id, 'price_type' );

            if ( $rental_type === 'day' ) {
                $charged_by = $this->get_meta_value( $product_id, 'define_1_day' );

                if ( $charged_by != 'hotel' ) {
                    $group_time = $this->get_meta_value( $product_id, 'manage_time_book_start' );

                    if ( $group_time === 'in_setting' ) {
                        $times = get_option( 'ova_brw_calendar_time_to_book', '07:00, 07:30, 08:00, 08:30, 09:00, 09:30, 10:00, 10:30, 11:00, 11:30, 12:00, 12:30, 13:00, 13:30, 14:00, 14:30, 15:00, 15:30, 16:00, 16:30, 17:00, 17:30, 18:00' );

                        if ( $times ) {
                            return true;
                        }
                    } elseif ( $group_time === 'new_time' ) {
                        $times = $this->get_meta_value( $product_id, 'product_time_to_book_start' );

                        if ( $times ) {
                            return true;
                        }
                    }
                }
            } elseif ( $rental_type === 'hour' || $rental_type === 'mixed' || $rental_type === 'transportation' ) {
                $group_time = $this->get_meta_value( $product_id, 'manage_time_book_start' );

                if ( $group_time === 'in_setting' ) {
                    $times = get_option( 'ova_brw_calendar_time_to_book', '07:00, 07:30, 08:00, 08:30, 09:00, 09:30, 10:00, 10:30, 11:00, 11:30, 12:00, 12:30, 13:00, 13:30, 14:00, 14:30, 15:00, 15:30, 16:00, 16:30, 17:00, 17:30, 18:00' );

                    if ( $times ) {
                        return true;
                    }
                } elseif ( $group_time === 'new_time' ) {
                    $times = $this->get_meta_value( $product_id, 'product_time_to_book_start' );

                    if ( $times ) {
                        return true;
                    }
                }
            } elseif ( $rental_type === 'period_time' ) {
                $unfixed_time = $this->get_meta_value( $product_id, 'unfixed_time' );

                if ( $unfixed_time === 'yes' ) {
                    $group_time = $this->get_meta_value( $product_id, 'manage_time_book_start' );

                    if ( $group_time === 'in_setting' ) {
                        $times = get_option( 'ova_brw_calendar_time_to_book', '07:00, 07:30, 08:00, 08:30, 09:00, 09:30, 10:00, 10:30, 11:00, 11:30, 12:00, 12:30, 13:00, 13:30, 14:00, 14:30, 15:00, 15:30, 16:00, 16:30, 17:00, 17:30, 18:00' );

                        if ( $times ) {
                            return true;
                        }
                    } elseif ( $group_time === 'new_time' ) {
                        $times = $this->get_meta_value( $product_id, 'product_time_to_book_start' );

                        if ( $times ) {
                            return true;
                        }
                    }
                }
            }

            return false;
        }

        public function get_dropoff_time_picker( $product_id = false ) {
            if ( ! $product_id ) return false;

            $rental_type = $this->get_meta_value( $product_id, 'price_type' );

            if ( $rental_type === 'day' ) {
                $charged_by = $this->get_meta_value( $product_id, 'define_1_day' );

                if ( $charged_by != 'hotel' ) {
                    $group_time = $this->get_meta_value( $product_id, 'manage_time_book_end' );

                    if ( $group_time === 'in_setting' ) {
                        $times = get_option( 'ova_brw_calendar_time_to_book_for_end_date', '07:00, 07:30, 08:00, 08:30, 09:00, 09:30, 10:00, 10:30, 11:00, 11:30, 12:00, 12:30, 13:00, 13:30, 14:00, 14:30, 15:00, 15:30, 16:00, 16:30, 17:00, 17:30, 18:00' );

                        if ( $times ) {
                            return true;
                        }
                    } elseif ( $group_time === 'new_time' ) {
                        $times = $this->get_meta_value( $product_id, 'product_time_to_book_end' );

                        if ( $times ) {
                            return true;
                        }
                    }
                }
            } elseif ( $rental_type === 'hour' || $rental_type === 'mixed' || $rental_type === 'transportation' ) {
                $group_time = $this->get_meta_value( $product_id, 'manage_time_book_end' );

                if ( $group_time === 'in_setting' ) {
                    $times = get_option( 'ova_brw_calendar_time_to_book_for_end_date', '07:00, 07:30, 08:00, 08:30, 09:00, 09:30, 10:00, 10:30, 11:00, 11:30, 12:00, 12:30, 13:00, 13:30, 14:00, 14:30, 15:00, 15:30, 16:00, 16:30, 17:00, 17:30, 18:00' );

                    if ( $times ) {
                        return true;
                    }
                } elseif ( $group_time === 'new_time' ) {
                    $times = $this->get_meta_value( $product_id, 'product_time_to_book_end' );

                    if ( $times ) {
                        return true;
                    }
                }
            } elseif ( $rental_type === 'period_time' ) {
                $unfixed_time = $this->get_meta_value( $product_id, 'unfixed_time' );

                if ( $unfixed_time === 'yes' ) {
                    $group_time = $this->get_meta_value( $product_id, 'manage_time_book_start' );

                    if ( $group_time === 'in_setting' ) {
                        $times = get_option( 'ova_brw_calendar_time_to_book_for_end_date', '07:00, 07:30, 08:00, 08:30, 09:00, 09:30, 10:00, 10:30, 11:00, 11:30, 12:00, 12:30, 13:00, 13:30, 14:00, 14:30, 15:00, 15:30, 16:00, 16:30, 17:00, 17:30, 18:00' );

                        if ( $times ) {
                            return true;
                        }
                    } elseif ( $group_time === 'new_time' ) {
                        $times = $this->get_meta_value( $product_id, 'product_time_to_book_end' );

                        if ( $times ) {
                            return true;
                        }
                    }
                }
            }

            return false;
        }

        public function get_parameter_from_url( $product_id = false, $url = '', $data = [] ) {
            if ( ! $product_id || ! $url ) return '';

            // Rental type
            $rental_type = $this->get_meta_value( $product_id, 'price_type' );

            // Time Picker
            $time_picker = isset( $data['timepicker'] ) ? $data['timepicker'] : '';

            // Pickup Location
            $pickup_location = isset( $data['ovabrw_pickup_loc'] ) ? $data['ovabrw_pickup_loc'] : '';

            if ( ! $pickup_location ) $pickup_location = isset( $data['pickup_loc'] ) ? $data['pickup_loc'] : '';
            if ( ! $pickup_location ) $pickup_location = isset( $data['pickup-location'] ) ? $data['pickup-location'] : '';
            if ( ! $pickup_location ) $pickup_location = isset( $data['pickup_location'] ) ? $data['pickup_location'] : '';
            if ( $pickup_location ) $url = add_query_arg( 'pickup_loc', $pickup_location, $url );

            // Origin location
            $origin_location = isset( $data['origin-location'] ) ? stripslashes( stripslashes( $data['origin-location'] ) ) : '';
            if ( ! $origin_location ) $origin_location = isset( $data['origin_location'] ) ? stripslashes( stripslashes( $data['origin_location'] ) ) : '';
            if ( $origin_location ) {
                $url = add_query_arg( 'origin_location', $origin_location, $url );
            }

            // Dropoff Location
            $dropoff_location = isset( $data['ovabrw_pickoff_loc'] ) ? $data['ovabrw_pickoff_loc'] : '';

            if ( ! $dropoff_location ) $dropoff_location = isset( $data['dropoff_loc'] ) ? $data['dropoff_loc'] : '';
            if ( ! $dropoff_location ) $dropoff_location = isset( $data['dropoff-location'] ) ? $data['dropoff-location'] : '';
            if ( ! $dropoff_location ) $dropoff_location = isset( $data['dropoff_location'] ) ? $data['dropoff_location'] : '';
            if ( $dropoff_location ) $url = add_query_arg( 'pickoff_loc', $dropoff_location, $url );

            // Destination location
            $destination_location = isset( $data['destination-location'] ) ? stripslashes( stripslashes( $data['destination-location'] ) ) : '';
            if ( ! $destination_location ) $destination_location = isset( $data['destination_location'] ) ? stripslashes( stripslashes( $data['destination_location'] ) ) : '';
            if ( $destination_location ) {
                $url = add_query_arg( 'destination_location', $destination_location, $url );
            }

            // Pickup Date
            $pickup_date = isset( $data['ovabrw_pickup_date'] ) ? $data['ovabrw_pickup_date'] : '';

            if ( ! $pickup_date ) $pickup_date = isset( $data['start_date'] ) ? $data['start_date'] : '';
            if ( ! $pickup_date ) $pickup_date = isset( $data['pickup-date'] ) ? $data['pickup-date'] : '';
            if ( ! $pickup_date ) $pickup_date = isset( $data['pickup_date'] ) ? $data['pickup_date'] : '';
            if ( $pickup_date ) {
                if ( $time_picker === 'false' && $this->get_pickup_time_picker( $product_id ) ) {
                    $pickup_hour = ovabrw_get_default_time( $product_id, 'start' );

                    $url = add_query_arg( 'pickup_date', $pickup_date.' '.$pickup_hour, $url );
                } else {
                    $url = add_query_arg( 'pickup_date', $pickup_date, $url );
                }

                if ( $rental_type === 'taxi' && strtotime( $pickup_date ) ) {
                    $timeformat     = ovabrw_get_time_format_php();
                    $pickup_time    = date( $timeformat, strtotime( $pickup_date ) );

                    if ( $pickup_time != '00:00' ) {
                        $url = add_query_arg( 'pickup_time', $pickup_time, $url );
                    }
                }
            }

            // Dropoff Date
            $dropoff_date = isset( $data['ovabrw_pickoff_date'] ) ? $data['ovabrw_pickoff_date'] : '';

            if ( ! $dropoff_date ) $dropoff_date = isset( $data['end_date'] ) ? $data['end_date'] : '';
            if ( $dropoff_date ) {
                if ( $time_picker === 'false' && $this->get_dropoff_time_picker( $product_id ) ) {
                    $dropoff_hour = ovabrw_get_default_time( $product_id, 'end' );

                    $url = add_query_arg( 'dropoff_date', $dropoff_date.' '.$dropoff_hour, $url );
                } else {
                    $url = add_query_arg( 'dropoff_date', $dropoff_date, $url );
                }
            }

            // Duration
            $duration = isset( $data['map-duration'] ) ? intval( $data['map-duration'] ) : '';
            if ( ! $duration ) $duration = isset( $data['duration'] ) ? $data['duration'] : '';
            if ( $duration ) {
                $url = add_query_arg( 'duration', $duration, $url );
            }

            // Distance
            $distance = isset( $data['map-distance'] ) ? intval( $data['map-distance'] ) : '';
            if ( ! $distance ) $distance = isset( $data['distance'] ) ? $data['distance'] : '';
            if ( $distance ) {
                $url = add_query_arg( 'distance', $distance, $url );
            }

            // Quantity
            $quantity = isset( $data['quantity'] ) ? intval( $data['quantity'] ) : '';
            if ( $quantity ) {
                $url = add_query_arg( 'ovabrw_quantity', $quantity, $url );
            }

            // Package
            $package = isset( $data['ovabrw_package'] ) ? $data['ovabrw_package'] : '';
            if ( $package ) {
                $url = add_query_arg( 'ovabrw_package', $package, $url );
            }

            return apply_filters( 'ovabrw_get_parameter_from_url', $url, $data );
        }

        public function get_package_id_by_durations( $product_id = false, $durations = '' ) {
            if ( ! $product_id || ! $durations ) return false;

            $unfixed_time   = $this->get_meta_value( $product_id, 'unfixed_time' );
            $petime_ids     = $this->get_meta_value( $product_id, 'petime_id' );
            $petime_types   = $this->get_meta_value( $product_id, 'package_type' );
            $petime_days    = $this->get_meta_value( $product_id, 'petime_days' );
            $petime_hours   = $this->get_meta_value( $product_id, 'pehour_unfixed' );
            $petime_start   = $this->get_meta_value( $product_id, 'pehour_start_time' );
            $petime_end     = $this->get_meta_value( $product_id, 'pehour_end_time' );

            foreach ( $petime_ids as $k => $package_id ) {
                $type = isset( $petime_types[$k] ) ? $petime_types[$k] : '';

                if ( $type === 'other' ) {
                    $number_day     = isset( $petime_days[$k] ) ? $petime_days[$k] : '';
                    $number_second  = $number_day ? $number_day*86400 : '';

                    if ( $number_second === $durations ) return $package_id;
                } else {
                    if ( $unfixed_time === 'yes' ) {
                        $number_hour    = isset( $petime_hours[$k] ) ? $petime_hours[$k] : '';
                        $number_second  = $number_hour ? $number_hour*3600 : '';

                        if ( $number_second === $durations ) return $package_id;
                    } else {
                        $start_time = isset( $petime_start[$k] ) ? strtotime( $petime_start[$k] ) : '';
                        $end_time   = isset( $petime_end[$k] ) ? strtotime( $petime_end[$k] ) : '';
                        
                        if ( $start_time && $end_time ) {
                            $number_second = $end_time - $start_time;

                            if ( $number_second === $durations ) return $package_id;
                        }
                    }
                }
            }

            return false;
        }

        public function is_array_exists( $arr = [] ) {
            if ( ! empty( $arr ) && is_array( $arr ) ) {
                return true;
            }

            return false;
        }

        public function get_meta_value( $id = false, $key = '', $default = '' ) {
            if ( ! $id ) return $default;
            
            $value = get_post_meta( $id, $this->prefix . $key, true );

            if ( $value == '' && $default != '' ) {
                $value = $default;
            }

            return $value;
        }

        public static function instance() {
            if ( is_null( self::$_instance ) ) {
                self::$_instance = new self();
            }

            return self::$_instance;
        }
    }

    new OVABRW_Get_Data();
}