<?php defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'OVABRW_Ajax' ) ) {
	class OVABRW_Ajax {
		public function __construct() {
			$this->init();
		}

		public function init() {
			$arr_ajax = array(
				'load_name_product',
				'load_tag_product',
				'get_package_by_time',
				'calculate_total',
				'get_tax_in_cat',
				'search_map',
				'product_ajax_filter',
				'search_taxi_ajax',
				'verify_reCAPTCHA'
			);

			foreach ( $arr_ajax as $name ) {
				add_action( 'wp_ajax_'.OVABRW_PREFIX.$name, array( $this, OVABRW_PREFIX.$name ) );
				add_action( 'wp_ajax_nopriv_'.OVABRW_PREFIX.$name, array( $this, OVABRW_PREFIX.$name ) );
			}
		}

		public function ovabrw_load_name_product() {
			$keyword 	= isset($_POST['keyword']) ? sanitize_text_field( $_POST['keyword'] ) : '';
			$the_query 	= new WP_Query( array( 'post_type' => 'product' , 's' => preg_replace("/[^a-zA-Z]+/", " ", $keyword), 'posts_per_page'=> '10') );
			$title 		= [];

			if ( $the_query->have_posts() ) :
				while ( $the_query->have_posts() ): $the_query->the_post();
					$title[] = html_entity_decode( get_the_title() );
				endwhile;
				wp_reset_postdata();  
			endif;

			echo json_encode( $title );
			wp_die();
		}

		public function ovabrw_load_tag_product() {
			$keyword = isset($_POST['keyword']) ? sanitize_text_field( $_POST['keyword'] ) : '';
			$args = array(
		        'taxonomy'               => 'product_tag',
		        'search' => $keyword
		    );

		    $the_query = new WP_Term_Query($args);

		    $title = [];
		    if ( $the_query->terms ) {
		        foreach( $the_query->terms as $term ) {
		            $title[] =  $term->name;
		        }
		        wp_reset_postdata();  
		    }

			echo json_encode($title);
			wp_die();
		}

		public function ovabrw_get_package_by_time() {
			$id 		= isset($_POST['post_id']) ? sanitize_text_field( $_POST['post_id'] ) : '';
			$start_date = isset($_POST['startdate']) ? strtotime( $_POST['startdate'] ) : '';

		    // Get list package of period time
			$ovabrw_petime_id		= get_post_meta( $id, 'ovabrw_petime_id', true );
			$ovabrw_petime_label 	= get_post_meta( $id, 'ovabrw_petime_label', true );

			// Package available
		    $package_available 	= array( '0' => esc_html__( 'Select Package', 'ova-brw' ) );

			if ( ! empty( $ovabrw_petime_id ) && is_array( $ovabrw_petime_id ) ) {
				foreach ( $ovabrw_petime_id as $k => $petime_id ) {
					$new_input_date = ovabrw_new_input_date( $id, $start_date, '', $petime_id, '', '' );

					$pickup_date_new    = $new_input_date['pickup_date_new'];
	        		$pickoff_date_new   = $new_input_date['pickoff_date_new'];
	        		$check_vehicle 		= ova_validate_manage_store( $id, $pickup_date_new, $pickoff_date_new, '', '', false, 'search', 1 );
				
					if ( $check_vehicle && $check_vehicle['status'] && ( $check_vehicle['vehicle_availables'] || $check_vehicle['number_vehicle_available'] ) ) {
						$package_available[$petime_id] = $ovabrw_petime_label[$k];
					}
				}
			}

			if ( empty( $package_available ) || count( $package_available ) <= 1 ) {
				$package_available = array( esc_html__( 'There are no packages', 'ova-brw' ) );
			}
			
			echo json_encode( $package_available );
			wp_die();
		}

		public function ovabrw_calculate_total() {
			$id 			= isset( $_POST['id'] ) ? sanitize_text_field( $_POST['id'] ) : '';
			$pickup_loc 	= isset( $_POST['pickup_loc'] ) ? sanitize_text_field( $_POST['pickup_loc'] ) : '';
			$dropoff_loc 	= isset( $_POST['dropoff_loc'] ) ? sanitize_text_field( $_POST['dropoff_loc'] ) : '';
			$pickup_date 	= isset( $_POST['pickup_date'] ) ? sanitize_text_field( $_POST['pickup_date'] ) : '';
			$dropoff_date 	= isset( $_POST['dropoff_date'] ) ? sanitize_text_field( $_POST['dropoff_date'] ) : '';
			$package_id 	= isset( $_POST['package_id'] ) ? sanitize_text_field( $_POST['package_id'] ) : '';
			$quantity 		= isset( $_POST['quantity'] ) ? sanitize_text_field( $_POST['quantity'] ) : 1;
			$deposit 		= isset( $_POST['deposit'] ) ? sanitize_text_field( $_POST['deposit'] ) : '';
			$resources 		= isset( $_POST['resources'] ) ? str_replace( '\\', '', $_POST['resources'] ) : '';
			$resources_qty 	= isset( $_POST['resources_qty'] ) ? str_replace( '\\', '', $_POST['resources_qty'] ) : '';
			$services 		= isset( $_POST['services'] ) ? str_replace( '\\', '', $_POST['services'] ) : '';
			$services_qty 	= isset( $_POST['services_qty'] ) ? str_replace( '\\', '', $_POST['services_qty'] ) : '';
			$custom_ckf 	= isset( $_POST['custom_ckf'] ) ? str_replace( '\\', '', $_POST['custom_ckf'] ) : '';
			$custom_ckf_qty = isset( $_POST['custom_ckf_qty'] ) ? str_replace( '\\', '', $_POST['custom_ckf_qty'] ) : '';
			$custom_ckf 	= (array) json_decode( $custom_ckf );
			$custom_ckf_qty = (array) json_decode( $custom_ckf_qty );
			$services 		= (array) json_decode( $services );
			$services_qty 	= (array) json_decode( $services_qty );
			$resources 		= (array) json_decode( $resources );
			$resources_qty 	= (array) json_decode( $resources_qty );

			// Taxi
			$duration_map 	= isset( $_POST['duration_map'] ) ? sanitize_text_field( $_POST['duration_map'] ) : '';
			$duration 		= isset( $_POST['duration'] ) ? sanitize_text_field( $_POST['duration'] ) : 0;
			$distance 		= isset( $_POST['distance'] ) ? sanitize_text_field( $_POST['distance'] ) : '';
			$pickup_time 	= isset( $_POST['pickup_time'] ) ? sanitize_text_field( $_POST['pickup_time'] ) : '';
			$extra_time 	= isset( $_POST['extra_time'] ) ? sanitize_text_field( $_POST['extra_time'] ) : '';

			// Rental Type
			$rental_type = get_post_meta( $id, 'ovabrw_price_type', true );

			// Object Rental Types
        	$rental_object = isset( OVABRW_Rental_Types::instance()->rental_types[$rental_type] ) ? OVABRW_Rental_Types::instance()->rental_types[$rental_type] : '';

        	if ( empty( $rental_object ) || ! is_object( $rental_object ) ) {
        		echo 0;
				wp_die();
        	}

        	// Set Product ID
        	$rental_object->set_ID( $id );

        	$new_date = [
        		'pickup_date_new' 	=> '',
        		'dropoff_date_new' 	=> '',
        	];

        	switch ( $rental_type ) {
        		case 'day':
        			$new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), strtotime( $dropoff_date ) );
        			break;
        		case 'hour':
        			$new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), strtotime( $dropoff_date ) );
        			break;
        		case 'mixed':
        			$new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), strtotime( $dropoff_date ) );
        			break;
        		case 'period_time':
        			$new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), $package_id );
        			break;
        		case 'transportation':
        			$new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), strtotime( $dropoff_date ), $pickup_loc, $dropoff_loc );
        			break;
        		case 'taxi':
        			$new_date = $rental_object->get_strtotime_input_date( $pickup_date, $pickup_time, $duration );
        			break;
        		case 'hotel':
        			$new_date = $rental_object->get_strtotime_input_date( strtotime( $pickup_date ), strtotime( $dropoff_date ) );
        			break;
        		default:
        			break;
        	}

			// Ajax Validation Booking
			$validation_booking = $rental_object->ovabrw_ajax_validation_booking( $new_date['pickup_date_new'], $new_date['dropoff_date_new'], $_POST );

			if ( $validation_booking ) {
				$total['error'] = $validation_booking;
				echo json_encode( $total ); wp_die();
			}

			// Check available quantity
	        $data_available = $rental_object->get_qty_available( $new_date['pickup_date_new'], $new_date['dropoff_date_new'], $pickup_loc, $dropoff_loc, 'cart' );
	        $qty_available 	= $data_available['qty_available'];

	        if ( $quantity > $qty_available ) {
	        	if ( $qty_available > 0 ) {
	        		$total['error'] = sprintf( esc_html__( 'Available vehicle is %s', 'ova-brw'  ), $qty_available );
	        	} else {
	        		$total['error'] = esc_html__( 'Out stock!', 'ova-brw' );
	        	}

                echo json_encode( $total ); wp_die();
	        }

	        // Qty available
		    $total['number_vehicle_available'] = $qty_available;

	        // Add Cart item
	        $cart_item = [
	        	'ovabrw_checkin' 			=> $new_date['pickup_date_new'],
	        	'ovabrw_checkout' 			=> $new_date['dropoff_date_new'],
	        	'ovabrw_pickup_loc' 		=> $pickup_loc,
	        	'ovabrw_pickoff_loc' 		=> $dropoff_loc,
	        	'package_id' 				=> $package_id,
	        	'ovabrw_number_vehicle' 	=> $quantity,
	        	'custom_ckf' 				=> $custom_ckf,
	        	'custom_ckf_qty' 			=> $custom_ckf_qty,
	        	'resources' 				=> $resources,
	        	'resources_qty' 			=> $resources_qty,
	        	'ovabrw_service' 			=> $services,
	        	'ovabrw_service_qty' 		=> $services_qty,
	        	'ova_type_deposit' 			=> $deposit,
	        	'ovabrw_amount_insurance' 	=> $quantity * floatval( $rental_object->get_value( 'amount_insurance' ) ),
	        	'duration_map' 				=> $duration_map,
	        	'duration' 					=> $duration,
	        	'distance' 					=> $distance,
	        	'extra_time' 				=> $extra_time,
	        ];

			$line_total = $rental_object->get_total( $cart_item );
			$insurance 	= floatval( $cart_item['ovabrw_amount_insurance'] );

			// Multi Currency
        	if ( is_plugin_active( 'woocommerce-multilingual/wpml-woocommerce.php' ) ) {
                $line_total = ovabrw_convert_price( $line_total );
                $insurance 	= ovabrw_convert_price( $insurance );
            }

            // Insurance Amount
            $total['amount_insurance'] = floatval( $insurance ) ? ovabrw_wc_price( apply_filters( 'ovabrw_ajax_insurance_amount', $insurance, $id ) ) : '';

            // Deposit
            if ( $deposit === 'deposit' ) {
            	$sub_deposit 	= $sub_remaining = 0;
            	$deposit_type 	= $rental_object->get_value( 'type_deposit' );
            	$deposit_value 	= floatval( $rental_object->get_value( 'amount_deposit' ) );

            	// Percent
            	if ( $deposit_type === 'percent' ) {
            		$line_total = floatval( ( $line_total * $deposit_value ) / 100 );
            	}

            	// Fixed
            	if ( $deposit_type === 'value' ) {
            		$line_total = floatval( $deposit_value );
            	}
            }
			
			if ( $line_total <= 0 && apply_filters( 'ovabrw_required_total', false ) ) {
				echo 0;	
			} else {
				$total['line_total'] = ovabrw_wc_price( apply_filters( 'ovabrw_ajax_total_filter', $line_total, $id ) );
				echo json_encode($total);
			}

			wp_die();
		}

		public function ovabrw_get_tax_in_cat(){
			$cat_val 			= isset( $_POST['cat_val'] ) ?  $_POST['cat_val'] : '';
			$list_tax_values 	= array();
			$get_term 			= get_term_by( 'slug', $cat_val, 'product_cat' );
			$term_id 			= $get_term->term_id;
			$ovabrw_custom_tax 	= get_term_meta($term_id, 'ovabrw_custom_tax', true);
					
			if ( $ovabrw_custom_tax ) {
				foreach( $ovabrw_custom_tax as $key => $value ) {
					if ( !in_array( $value, $list_tax_values ) ) {
						if ( $value ) {
							array_push( $list_tax_values, $value);		
						}
					}
				}
			}

			echo implode(",", $list_tax_values ); 
			wp_die();
		}

		public function ovabrw_search_map() {
			$data = $_POST;
			$map_lat 	= isset( $data['map_lat'] ) ? floatval( $data['map_lat'] ) 	: '';
			$map_lng 	= isset( $data['map_lng'] ) ? floatval( $data['map_lng'] ) 	: '';
			$radius 	= isset( $data['radius'] ) 	? floatval( $data['radius'] ) 	: '50';

			// Get post in
			$post_in 		= $arr_distance = array();
			$product_ids 	= OVABRW_Get_Data::instance()->get_products_rental();

			if ( $map_lat != '' || $map_lng != '' ) {
				foreach ( $product_ids as $product_id ) {
					/* Latitude Longitude Search */
					$lat_search = deg2rad($map_lat);
					$lng_search = deg2rad($map_lng);

					/* Latitude Longitude Post */
					$lat_post = deg2rad( get_post_meta( $product_id, 'ovabrw_latitude', true ));
					$lng_post = deg2rad( get_post_meta( $product_id, 'ovabrw_longitude', true ));

					$lat_delta = $lat_post - $lat_search;
					$lon_delta = $lng_post - $lng_search;

					// $angle = 2 * asin(sqrt(pow(sin($lat_delta / 2), 2) + cos($lat_search) * cos($lat_post) * pow(sin($lon_delta / 2), 2)));
					$angle = acos(sin($lat_search) * sin($lat_post) + cos($lat_search) * cos($lat_post) * cos($lng_search - $lng_post));

					/* 6371 = the earth's radius in km */
					/* 3959 = the earth's radius in mi */
					$distance =  6371 * $angle;

					if ( $distance <= $radius || !$map_lat ) {
						array_push( $arr_distance, $distance );
						array_push( $post_in, $product_id );
					}
				}

				wp_reset_postdata();
				array_multisort($arr_distance, $post_in);
			} else {
				foreach ( $product_ids as $product_id )  {
					array_push( $post_in, $product_id );
				}
			}

			if ( $map_lat && ! $post_in ) {
				$post_in = array('');
			}
			/***** End Query Radius *****/

			$sort 			= isset( $data['sort'] ) 		? sanitize_text_field( $data['sort'] ) 			: '';
			$order 			= isset( $data['order'] ) 		? sanitize_text_field( $data['order'] ) 		: '';
			$orderby 		= isset( $data['orderby'] ) 	? sanitize_text_field( $data['orderby'] ) 		: '';
			$per_page 		= isset( $data['per_page'] ) 	? sanitize_text_field( $data['per_page'] ) 		: '';
			$paged 			= isset( $data['paged'] ) 		? (int)$data['paged']  							: 1;
			$name 			= isset( $data['name'] ) 		? sanitize_text_field( $data['name'] ) 			: '';
		    $pickup_loc 	= isset( $data['pickup_loc'] ) 	? sanitize_text_field( $data['pickup_loc'] ) 	: '';
		    $pickoff_loc 	= isset( $data['dropoff_loc'] ) ? sanitize_text_field( $data['dropoff_loc'] ) 	: '';
		    $pickup_date 	= isset( $data['start_date'] )  ? strtotime( $data['start_date'] ) 				: '';
		    $pickoff_date 	= isset( $data['end_date'] ) 	? strtotime( $data['end_date'] ) 				: '';
		    $package_duration = isset( $data['ovabrw_package'] ) ? sanitize_text_field( $data['ovabrw_package'] ) : '';
		    $category 		= isset( $data['cat'] ) 		? sanitize_text_field( $data['cat'] ) 			: '';
		    $card 			= isset( $data['card'] ) 		? sanitize_text_field( $data['card'] ) 			: '';
		    $column 		= isset( $data['column'] ) 		? sanitize_text_field( $data['column'] ) 		: '';
		    $attribute 		= isset( $data['attribute'] ) 	? sanitize_text_field( $data['attribute'] ) 	: '';
		    $attr_value 	= isset( $data['attr_value'] ) 	? sanitize_text_field( $data['attr_value'] ) 	: '';
		    $tags 			= isset( $data['tags'] ) 		? sanitize_text_field( $data['tags'] ) 			: '';
		    $taxonomies 	= isset( $data['taxonomies'] ) 	? sanitize_text_field( $data['taxonomies'] )	: '';

		    $quantity       = isset( $data['quantity'] )    ? absint( sanitize_text_field( $data['quantity'] ) )  : '';
		    $adults         = isset( $data['adults'] )      ? sanitize_text_field( $data['adults'] )      : '';
            $children       = isset( $data['children'] )    ? sanitize_text_field( $data['children'] )    : '';
            $babies         = isset( $data['babies'] )      ? sanitize_text_field( $data['babies'] )      : '';

		    $taxonomies 	= str_replace( '\\', '',  $taxonomies);
			if ( $taxonomies ) {
				$taxonomies = json_decode( $taxonomies, true );
			}

		    $args_base = array(
				'post_type'      => 'product',
				'post_status'    => 'publish',
				'posts_per_page' => -1
			);

		    // sort
		    $args_order 	= ! empty( $order ) 	? array( 'order' => $order ) 		: array( 'order' => 'DESC' );
		    $args_orderby 	= ! empty( $orderby ) 	? array( 'orderby' => $orderby ) 	: array( 'orderby' => 'title' );

		    switch ( $sort ) {
				case 'date-desc':
				$args_orderby =  array( 'orderby' => 'date' );
				break;

				case 'date-asc':
				$args_orderby 	= array( 'orderby' => 'date' );
				$args_order 	= array( 'order' => 'ASC' );
				break;

				case 'near':
				$args_orderby 	= array( 'orderby' => 'post__in');
				$args_order 	= array( 'order' => 'ASC' );
				break;

				case 'a-z':
				$args_orderby 	= array( 'orderby' => 'title');
				$args_order 	= array( 'order' => 'ASC' );
				break;

				case 'z-a':
				$args_orderby 	= array( 'orderby' => 'title');
				break;

				default:
				break;
			}

			$args_basic 	= array_merge_recursive( $args_base, $args_order, $args_orderby );
			$args_radius 	= $args_name = $args_taxonomy = $args_tax_attr = $item_ids = array();

			// Query Result
			if ( $post_in ) {
				$args_radius = array( 'post__in' => $post_in );
			}

			// Query Name
			if ( $name ) {
				$args_name = array( 's' => preg_replace("/[^a-zA-Z]+/", " ", $name) );
			}

			// Query Categories
			if ( $category ){
				$args_tax_attr[] = [
		            'taxonomy' 	=> 'product_cat',
		            'field' 	=> 'slug',
		            'terms' 	=> $category
		        ];
			}

			// Query Attribute
			if ( $attribute ) {
		        $args_tax_attr[] = [
		            'taxonomy' 	=> 'pa_' . $attribute,
		            'field' 	=> 'slug',
		            'terms' 	=> [$attr_value],
		            'operator'  => 'IN',
		        ];
		    }

		    // Query Tags
			if ( $tags ) {
				$args_tax_attr[] = [
		            'taxonomy' 	=> 'product_tag',
		            'field' 	=> 'name',
		            'terms' 	=> $tags
		        ];
			}

			// Query taxonomy custom
		    if ( $taxonomies && is_array( $taxonomies ) ) {
		    	foreach ( $taxonomies as $slug => $value) {
		    		$taxo_name = isset( $data[$slug] ) ? sanitize_text_field( $data[$slug] ) : '';
		    		if ( $taxo_name ) {
		    			$args_tax_attr[] = [
				            'taxonomy' 	=> $slug,
				            'field' 	=> 'slug',
				            'terms' 	=> $taxo_name
				        ];
		    		}
		    	}
		    }

			// Query taxonomy
			if ( ! empty( $args_tax_attr )) {
		        $args_taxonomy = array(
		            'tax_query' => array(
		                'relation'  => 'AND',
		                $args_tax_attr
		            )
		        );
		    }

		     // Meta Query
            $args_meta_query_arr = $meta_query = [];

            // ==> Search by Guest
            if ( $adults != '' ) {
                $args_meta_query_arr[] = [
                    'key'     => 'ovabrw_max_adults',
                    'value'   => $adults,
                    'type'    => 'numeric',
                    'compare' => '>=',
                ];
            }

            if ( $children != '' ) {
                $args_meta_query_arr[] = [
                    'key'     => 'ovabrw_max_children',
                    'value'   => $children,
                    'type'    => 'numeric',
                    'compare' => '>=',
                ];
            }

            if ( $babies != '' ) {
                $args_meta_query_arr[] = [
                    'key'     => 'ovabrw_max_babies',
                    'value'   => $babies,
                    'type'    => 'numeric',
                    'compare' => '>=',
                ];
            }

            if ( !empty( $args_meta_query_arr ) ) {
                $meta_query = array(
                    'meta_query' => array(
                        'relation'  => 'AND',
                        $args_meta_query_arr
                    )
                );
            }

			$args = array_merge_recursive( $args_basic, $args_radius, $args_name, $args_taxonomy, $meta_query );

			// Get All products
		    $items = new WP_Query( apply_filters( 'ovabrw_ft_items_query_search_map', $args, $data ));

		    if ( $items->have_posts() ) : while ( $items->have_posts() ) : $items->the_post();
		        // Product ID
		        $id = get_the_id();

		        // Set Pick-up, Drop-off Date again
		        $new_input_date 	= ovabrw_new_input_date( $id, $pickup_date, $pickoff_date, '', $pickup_loc, $pickoff_loc );
		        $pickup_date_new 	= $new_input_date['pickup_date_new'];
		        $pickoff_date_new 	= $new_input_date['pickoff_date_new'];

		        if ( $package_duration && $pickup_date_new ) {
		        	$pickoff_date_new = $pickoff_date_new + $package_duration;
		        }

		        $ova_validate_manage_store = ova_validate_manage_store( $id, $pickup_date_new, $pickoff_date_new, $pickup_loc, $pickoff_loc, $passed = false, $validate = 'search' ) ;
		        
		        if ( $ova_validate_manage_store && $ova_validate_manage_store['status'] ) {
		        	if ( $quantity ) {
		        		$number_available = intval( $ova_validate_manage_store['number_vehicle_available'] );

		        		if ( $number_available >= $quantity ) {
		        			array_push( $item_ids, $id );
		        		}
		        	} else {
		        		array_push( $item_ids, $id );
		        	}
		        }
		    endwhile; else :
		        $result = '<div class="not_found_product">'. esc_html( 'No product found', 'ova-brw' ) .'</div>';
		    	$results_found = '<div class="results_found"><span>'. esc_html__( '0 Result Found', 'ova-brw' ) .'</span></div>';
		    endif; wp_reset_postdata();

		    if ( $item_ids ) {
		        $args_product = array(
		            'post_type' 		=> 'product',
		            'posts_per_page' 	=> $per_page,
		            'paged' 			=> $paged,
		            'post_status' 		=> 'publish',
		            'post__in' 			=> $item_ids,
		            'orderby' 			=> 'post__in',
		            'order' 			=> $order ? $order : 'DESC',
		        );

		        $products = new WP_Query( apply_filters( 'ovabrw_ft_query_search_map', $args_product, $data ));

		        // Card
		        if ( $card === 'card5' || $card === 'card6' ) $column = 'one-column';

		        ob_start();
		        ?>
		        <div class="ovabrw_product_archive <?php echo esc_attr( $column ); ?>">
					<?php
						woocommerce_product_loop_start();
						if ( $products->have_posts() ) : while ( $products->have_posts() ) : $products->the_post();
							$id 			= get_the_id();
							$product 		= wc_get_product( $id );
							$html_price 	= OVABRW_Get_Data::instance()->get_html_price( $id );

							if ( $html_price ) {
								$data_html_price = htmlentities( $html_price );
							} else {
								$data_html_price = '';
							}

							$lat_product 	= get_post_meta( $id, 'ovabrw_latitude', true );
							$lng_product 	= get_post_meta( $id, 'ovabrw_longitude', true );

							if ( $card ) {
								$thumbnail_type = get_option( 'ovabrw_glb_'.$card.'_thumbnail_type', 'slider' );

								ovabrw_get_template( 'modern/products/cards/ovabrw-'.$card.'.php', [ 'product_id' => $id, 'thumbnail_type' => $thumbnail_type ] );
							} else {
								wc_get_template_part( 'content', 'product' );
							}
							?>
							<input
								type="hidden"
								class="data_product"
								data-link_product="<?php echo esc_attr( get_the_permalink() ); ?>"
								data-title_product="<?php echo esc_attr( get_the_title() ); ?>"
								data-average_rating="<?php echo $product->get_average_rating(); ?>"
								data-number_comment="<?php echo get_comments_number( $id ); ?>"
								data-map_lat_product="<?php echo $lat_product; ?>"
								data-map_lng_product="<?php echo $lng_product; ?>"
								data-thumbnail_product="<?php echo wp_get_attachment_image_url( get_post_thumbnail_id() , 'thumbnail' ); ?>"
								data-html_price="<?php echo $data_html_price; ?>"
							/>
							<?php
						endwhile; else :
						?>
							<div class="not_found_product"><?php esc_html_e( 'Product not found', 'ova-brw' ); ?></div>
						<?php
						endif; wp_reset_postdata();
						woocommerce_product_loop_end();
					?>
				</div>
		        <?php
		        $total = $products->max_num_pages;

				if (  $total > 1 ): ?>
					<div class="ovabrw_pagination_ajax">
					<?php
						echo OVABRW_Get_Data::instance()->get_html_pagination_ajax( $products->found_posts, $products->query_vars['posts_per_page'], $paged );
					?>
					</div>
					<?php
				endif;

				$result = ob_get_contents(); 
				ob_end_clean();

				ob_start();
				?>
					<div class="results_found">
						<?php if ( $products->found_posts == 1 ): ?>
						<span>
							<?php echo sprintf( esc_html__( '%s Result Found', 'ova-brw' ), esc_html( $products->found_posts ) ); ?>
						</span>
						<?php else: ?>
						<span>
							<?php echo sprintf( esc_html__( '%s Results Found', 'ova-brw' ), esc_html( $products->found_posts ) ); ?>
						</span>
						<?php endif; ?>

						<?php if ( 1 == ceil( $products->found_posts/ $products->query_vars['posts_per_page']) && $products->have_posts() ): ?>
							<span>
								<?php echo sprintf( esc_html__( '(Showing 1-%s)', 'ova-brw' ), esc_html( $products->found_posts ) ); ?>
							</span>
						<?php elseif ( !$products->have_posts() ): ?>
							<span></span>
						<?php else: ?>
							<span>
								<?php echo sprintf( esc_html__( '(Showing 1-%s)', 'ova-brw' ), esc_html( $products->query_vars['posts_per_page'] ) ); ?>
							</span>
						<?php endif; ?>
					</div>

				<?php
				$results_found = ob_get_contents();
				ob_end_clean();

				echo json_encode( array( "result" => $result, "results_found" => $results_found ));
				wp_die();
		    } else {
		    	$result = '<div class="not_found_product">'. esc_html( 'No product found', 'ova-brw' ) .'</div>';
		    	$results_found = '<div class="results_found"><span>'. esc_html__( '0 Result Found', 'ova-brw' ) .'</span></div>';
		    	echo json_encode( array( "result" => $result, "results_found" => $results_found ));
		    	wp_die();
		    }
		}

		public function ovabrw_product_ajax_filter() {
			$term_id 		= isset( $_POST['term_id'] ) ? $_POST['term_id'] : '';
			$template 		= isset( $_POST['template'] ) ? $_POST['template'] : 'card1';
			$posts_per_page = isset( $_POST['posts_per_page'] ) ? $_POST['posts_per_page'] : 6;
			$orderby 		= isset( $_POST['orderby'] ) ? $_POST['orderby'] : 'ID';
			$order 			= isset( $_POST['order'] ) ? $_POST['order'] : 'DESC';
			$pagination 	= isset( $_POST['pagination'] ) ? $_POST['pagination'] : '';
			$paged 			= isset( $_POST['paged'] ) ? $_POST['paged'] : 1;

			$products = OVABRW_Get_Data::instance()->get_product_ajax_filter( array(
				'paged' 			=> $paged,
				'posts_per_page' 	=> $posts_per_page,
				'orderby' 			=> $orderby,
				'order' 			=> $order,
				'term_id' 			=> $term_id,
			));

			ob_start();
			if ( $products->have_posts() ) : while ( $products->have_posts() ) : $products->the_post();
				if ( $template ) {
					?>
					<li class="item">
						<?php ovabrw_get_template( 'modern/products/cards/ovabrw-'.$template.'.php' ); ?>
					</li>
					<?php
				} else {
					wc_get_template_part( 'content', 'product' );
				}
			endwhile; else :
			?>
				<div class="not-found">
					<?php esc_html_e( 'Product not found', 'ova-brw' ); ?>
				</div>
			<?php
			endif; wp_reset_postdata();

			$result = ob_get_contents();
			ob_end_clean();

			ob_start();
			if ( 'yes' === $pagination ) {
				$pages 		= $products->max_num_pages;
				$limit 		= $products->query_vars['posts_per_page'];
				$current 	= $paged;

				if ( $pages > 1 ):
					for ( $i = 1; $i <= $pages; $i++ ): ?>
					<li>
						<span
							class="page-numbers<?php echo $i == $current ? ' current' : ''; ?>"
							data-paged="<?php echo esc_attr( $i ); ?>">
							<?php echo esc_html( $i ); ?>
						</span>
					</li>
				<?php endfor; endif;
			}

			$pagination = ob_get_contents();
			ob_end_clean();

			echo json_encode( array( 'result' => $result, 'pagination' => $pagination ) );
			wp_die();
		}

		public function ovabrw_search_taxi_ajax() {
			$origin 		= isset( $_POST['origin_locaiton'] ) ? $_POST['origin_locaiton'] : '';
			$destination 	= isset( $_POST['destination_location'] ) ? $_POST['destination_location'] : '';
			$duration 		= isset( $_POST['duration'] ) ? $_POST['duration'] : '';
			$distance 		= isset( $_POST['distance'] ) ? $_POST['distance'] : '';
			$pickup_date 	= isset( $_POST['pickup_date'] ) ? $_POST['pickup_date'] : '';
			$dropoff_date 	= '';
			$category 		= isset( $_POST['category'] ) ? $_POST['category'] : '';
			$number_seats 	= isset( $_POST['number_seats'] ) ? $_POST['number_seats'] : '';
			$quantity 		= isset( $_POST['quantity'] ) ? $_POST['quantity'] : '';
			$taxonomies 	= isset( $_POST['taxonomies'] ) ? $_POST['taxonomies'] : '';
			$card 			= isset( $_POST['card'] ) ? $_POST['card'] : 'card1';
			$posts_per_page = isset( $_POST['posts_per_page'] ) ? $_POST['posts_per_page'] : 6;
			$column 		= isset( $_POST['column'] ) ? $_POST['column'] : 'three-column';
			$term 			= isset( $_POST['term'] ) ? $_POST['term'] : '';
			$orderby 		= isset( $_POST['orderby'] ) ? $_POST['orderby'] : 'date';
			$order 			= isset( $_POST['order'] ) ? $_POST['order'] : 'DESC';
			$pagination 	= isset( $_POST['pagination'] ) ? $_POST['pagination'] : '';
			$paged 			= isset( $_POST['paged'] ) ? $_POST['paged'] : 1;

			// Taxonomies
			$taxonomies 	= str_replace( '\\', '',  $taxonomies);
			if ( $taxonomies ) {
				$taxonomies = json_decode( $taxonomies, true );
			}

			// Init
			$item_ids = $tax_query = $taxonomies_query = array();

			// Base query
            $args_base = array(
                'post_type'         => 'product',
                'posts_per_page'    => '-1',
                'post_status'       => 'publish',
                'fields'            => 'ids',
                'tax_query'         => array(
                    'relation'      => 'AND',
                    array(
                        'taxonomy'  => 'product_type',
                        'field'     => 'slug',
                        'terms'     => 'ovabrw_car_rental'
                    )
                )
            );

            // Product category
            if ( $category ) {
                $taxonomies_query[] = [
                    'taxonomy'  => 'product_cat',
                    'field'     => 'slug',
                    'terms'     => $category
                ];
            } else {
            	if ( $term ) {
            		$taxonomies_query[] = [
	                    'taxonomy'  => 'product_cat',
	                    'field'     => 'slug',
	                    'terms'     => $term
	                ];
            	}
            }

            // Query taxonomy custom
		    if ( $taxonomies && is_array( $taxonomies ) ) {
		    	foreach ( $taxonomies as $slug => $value) {
		    		$taxonomy_name = isset( $_POST[$slug] ) ? $_POST[$slug] : '';

		    		if ( $taxonomy_name ) {
		    			$taxonomies_query[] = [
				            'taxonomy' 	=> $slug,
				            'field' 	=> 'slug',
				            'terms' 	=> $taxonomy_name
				        ];
		    		}
		    	}
		    }

            if ( ! empty( $taxonomies_query ) && is_array( $taxonomies_query ) ) {
            	$tax_query = [
                    'tax_query' => [
                        $taxonomies_query
                    ]
                ];
            }

            // Meta Query
            $args_meta_query_arr = $meta_query = [];

            // Number seats
            if ( $number_seats ) {
                $args_meta_query_arr[] = [
                    'key'     => 'ovabrw_max_seats',
                    'value'   => $number_seats,
                    'type'    => 'numeric',
                    'compare' => '>=',
                ];
            }

            if ( ! empty( $args_meta_query_arr ) ) {
                $meta_query = array(
                    'meta_query' => array(
                        'relation'  => 'AND',
                        $args_meta_query_arr
                    )
                );
            }

            // Merge query
            $args_query = array_merge_recursive( $args_base, $tax_query, $meta_query );

            // Get product ids
            $product_ids = get_posts( $args_query );

            // Taxi
            if ( $pickup_date ) {
            	if ( $duration ) {
            		$dropoff_date = date( 'Y-m-d H:i', strtotime( $pickup_date ) + intval( $duration ) );
            	} else {
            		$dropoff_date = $pickup_date;
            	}
            }

            if ( ! empty( $product_ids ) && is_array( $product_ids ) ) {
                foreach ( $product_ids as $product_id ) {
                    // Check dates
                    if ( strtotime( $pickup_date ) && strtotime( $dropoff_date ) ) {
                        $type = get_post_meta( $product_id, 'ovabrw_price_type', true );

                        // Object Rental Types
                        $rental_object = isset( OVABRW_Rental_Types::instance()->rental_types[$type] ) ? OVABRW_Rental_Types::instance()->rental_types[$type] : '';

                        if ( empty( $rental_object ) || ! is_object( $rental_object ) ) {
                            continue;
                        }

                        // Set Product ID
                        $rental_object->set_ID( $product_id );

                        // Check available quantity
                        $data_available = $rental_object->get_qty_available( strtotime( $pickup_date ), strtotime( $dropoff_date ), '', '', 'search' );

                        if ( ! $data_available ) continue;

                        $qty_available  = intval( $data_available['qty_available'] );

                        if ( $qty_available && $qty_available >= $quantity ) {
                            array_push( $item_ids, $product_id );
                        }
                    } else {
                        array_push( $item_ids, $product_id );
                    }
                }
            }

            $products = '';
            // Get Products
            if ( $item_ids ) {
                $args_query = array(
                    'post_type'         => 'product',
                    'posts_per_page'    => $posts_per_page,
                    'paged'             => $paged,
                    'post_status'       => 'publish',
                    'post__in'          => $item_ids,
                    'order'             => $order,
                    'orderby'           => $orderby
                );

                $products = new WP_Query( $args_query );
            }

            ob_start();
			if ( $products && $products->have_posts() ) : while ( $products->have_posts() ) : $products->the_post();
				if ( $card ) {
					?>
					<li class="item">
						<?php ovabrw_get_template( 'modern/products/cards/ovabrw-'.$card.'.php' ); ?>
					</li>
					<?php
				} else {
					wc_get_template_part( 'content', 'product' );
				}
			endwhile; else :
			?>
				<div class="not-found">
					<?php esc_html_e( 'Product not found', 'ova-brw' ); ?>
				</div>
			<?php
			endif; wp_reset_postdata();

			$result = ob_get_contents();
			ob_end_clean();

			ob_start();
			if ( 'yes' === $pagination && $products ) {
				$pages 		= $products->max_num_pages;
				$limit 		= $products->query_vars['posts_per_page'];
				$current 	= $paged;

				if ( $pages > 1 ):
					for ( $i = 1; $i <= $pages; $i++ ): ?>
					<li>
						<span
							class="page-numbers<?php echo $i == $current ? ' current' : ''; ?>"
							data-paged="<?php echo esc_attr( $i ); ?>">
							<?php echo esc_html( $i ); ?>
						</span>
					</li>
				<?php endfor; endif;
			}

			$pagination = ob_get_contents();
			ob_end_clean();

			echo json_encode( array( 'result' => $result, 'pagination' => $pagination ) );
			wp_die();
		}

		public function ovabrw_verify_reCAPTCHA() {
			$mess = esc_html__( 'reCAPTCHA response error, please try again later', 'ova-brw' );

			if ( ! isset( $_POST ) && empty( $_POST ) ) {
				echo $mess;
				wp_die();
			}

			$token = isset( $_POST['token'] ) ? $_POST['token'] : '';

			if ( ! $token ) {
				echo $mess;
				wp_die();
			} else {
				$secret_key = ovabrw_get_recaptcha_secret_key();

				// Remote IP address of the user
				$remote_ip = $_SERVER['REMOTE_ADDR'];

				$url 	= curl_init('https://www.google.com/recaptcha/api/siteverify');
				$data 	= [
				    'secret' 	=> $secret_key,
				    'response' 	=> $token,
				    'remoteip' 	=> $remote_ip
				];

				curl_setopt( $url, CURLOPT_RETURNTRANSFER, true );
				curl_setopt( $url, CURLOPT_POST, true );
				curl_setopt( $url, CURLOPT_POSTFIELDS, http_build_query($data) );

				// Execute the request and get the response
				$response = curl_exec($url);
				curl_close($url);

				$result = json_decode($response);

				if ( $result && isset($result->success) && $result->success === true ) {
				    $mess = '';
				} else {
				    // reCAPTCHA verification failed
				    $mess = esc_html__( 'reCAPTCHA verification failed!', 'ova-brw' );
				}
			}

			echo $mess;
			wp_die();
		}
	}

	new OVABRW_Ajax();
}