<?php if ( !defined( 'ABSPATH' ) ) exit();

/* Load Template */
add_filter( 'template_include', 'ovabrw_template_loader', 99 );
if ( ! function_exists( 'ovabrw_template_loader' ) ) {
    function ovabrw_template_loader( $template ) {
        $search             = isset( $_REQUEST['ovabrw_search'] ) ? esc_html( $_REQUEST['ovabrw_search'] ) : '';
        $request_booking    = isset( $_REQUEST['request_booking'] ) ? esc_html( $_REQUEST['request_booking'] ) : '';

        // Get product template
        $product_template = get_option( 'ova_brw_template_elementor_template', 'default' );

        // Single Product
        if ( is_product() ) {
            $product_id = get_the_id();
            $product    = wc_get_product( $product_id );

            if ( $product->is_type('ovabrw_car_rental') ) {
                if ( $product_template === 'default' ) {
                    $template_by_category = ovabrw_get_product_template( $product_id );

                    if ( $template_by_category && $template_by_category !== 'default' ) {
                        $template = ovabrw_get_template( 'ovabrw_single_product.php' );
                    }
                } elseif ( ovabrw_global_typography() && $product_template === 'modern' ) {
                    $template_by_category = ovabrw_get_product_template( $product_id );

                    if ( $template_by_category && $template_by_category !== 'modern' ) {
                        $template = ovabrw_get_template( 'ovabrw_single_product.php' );
                    } else {
                        $template = ovabrw_get_template( 'modern/single/ovabrw-single-product.php' );
                    }
                } else {
                    $template = ovabrw_get_template( 'ovabrw_single_product.php' );
                }
            }
        }

        // Archive Product
        if ( ovabrw_is_archive_product() && $search === '' ) {
            ovabrw_get_template( 'modern/products/ovabrw-archive-product.php' );

            return false;
        }
        
        // Search Form
        if ( $search != '' ) {
            return ovabrw_get_template( 'search_result.php' );
        }
        
        // Request Booking Form
        if ( $request_booking != '') {
            if ( OVABRW_Mail::instance()->mail_request_booking( $_REQUEST ) ) {
                $thank_page = get_option( 'ova_brw_request_booking_form_thank_page' );
                if ( ! $thank_page ) $thank_page = home_url();

                $object_id  = '';

                // Multi language
                if ( is_plugin_active( 'sitepress-multilingual-cms/sitepress.php' ) ) {
                    $thank_page_id  = url_to_postid( $thank_page );
                    $object_id      = apply_filters( 'wpml_object_id', $thank_page_id, 'page', TRUE  );
                } elseif ( is_plugin_active( 'polylang/polylang.php' ) || is_plugin_active( 'polylang-pro/polylang.php' ) ) {
                    $thank_page_id  = url_to_postid( $thank_page );
                    $object_id      = pll_get_post( $thank_page_id );
                }

                if ( $object_id ) {
                    $thank_page = get_permalink( $object_id );
                }

                wp_redirect( $thank_page );
            } else {
                $error_page = get_option( 'ova_brw_request_booking_form_error_page' );
                if ( ! $error_page ) $error_page = home_url();

                $object_id  = '';

                // Multi language
                if ( is_plugin_active( 'sitepress-multilingual-cms/sitepress.php' ) ) {
                    $error_page_id  = url_to_postid( $error_page );
                    $object_id      = apply_filters( 'wpml_object_id', $error_page_id, 'page', TRUE  );
                } elseif ( is_plugin_active( 'polylang/polylang.php' ) || is_plugin_active( 'polylang-pro/polylang.php' ) ) {
                    $error_page_id  = url_to_postid( $error_page );
                    $object_id      = pll_get_post( $error_page_id );
                }

                if ( $object_id ) {
                    $error_page = get_permalink( $object_id );
                }
                
                wp_redirect( $error_page );
            }

            exit();
        }

        return $template;
    }
}

// ADD A PRODUCT TYPE **************************************/
add_filter( 'product_type_selector', 'ovabrw_add_custom_product_type', 10, 1 );
add_action( 'init', 'ovabrw_create_custom_product_type' );
if ( ! function_exists( 'ovabrw_add_custom_product_type' ) ) {
    function ovabrw_add_custom_product_type( $types ) {
        $types['ovabrw_car_rental'] = esc_html__( 'Rental', 'ova-brw' );

        return $types;
    }
}

if ( ! function_exists( 'ovabrw_create_custom_product_type' ) ) {
    function ovabrw_create_custom_product_type(){
        // declare the product class
        class WC_Product_Ovabrw_Car_Rental extends WC_Product {
            public function __construct( $product ) {
               parent::__construct( $product );
            }

            public function get_type() {
                return 'ovabrw_car_rental';
            }
        }
    }
}

// Support Apple and Google Pay Button
add_filter( 'wcpay_payment_request_supported_types', function( $product_types ) {
    if ( ! empty( $product_types ) && is_array( $product_types ) ) {
        array_push( $product_types , 'ovabrw_car_rental' );
    }

    return $product_types;
});

/* Add new product default show rental type */
add_filter( 'woocommerce_product_type_query', function( $product_type, $product_id ) {
    global $pagenow, $post_type;

    if ( $pagenow === 'post-new.php' && $post_type === 'product' ) {
        return 'ovabrw_car_rental';
    }

    return $product_type;
}, 10, 2 );

// Add javascript to head
add_action('admin_head', 'ovabrw_hook_javascript');
add_action('wp_head', 'ovabrw_hook_javascript');
if ( ! function_exists( 'ovabrw_hook_javascript' ) ) {
    function ovabrw_hook_javascript() {
        $lang_general_calendar = ovabrw_get_setting( get_option( 'ova_brw_calendar_language_general', 'en' ) );

        // WPML
        $current_lang = apply_filters( 'wpml_current_language', NULL );

        if ( $current_lang ) {
            $lang_general_calendar = $current_lang;
        }

        // Polylang
        if ( function_exists('pll_current_language') ) {
            $lang_general_calendar = pll_current_language();
        }

        $time_to_book_general_calendar          = ovabrw_group_time_pickup_date_global_setting();
        $time_to_book_general_calendar_endate   = ovabrw_group_time_dropoff_date_global_setting();

        $date_format = ovabrw_get_date_format();
        $time_format = ovabrw_get_time_format();

        $data_step          = ovabrw_get_setting( get_option( 'ova_brw_booking_form_step_time', '30' ) );
        $year_start         = ovabrw_get_setting( get_option( 'ova_brw_booking_form_year_start', '' ) );
        $year_end           = ovabrw_get_setting( get_option( 'ova_brw_booking_form_year_end', '' ) );
        $disable_week_day   = ovabrw_get_setting( get_option( 'ova_brw_calendar_disable_week_day', '' ) );

        if ( $time_format == 12 ) {
            $format_time = "h:mm A";
        } else {
            $format_time = "HH:mm";
        }

        // Get first day in week
        $first_day = get_option( 'ova_brw_calendar_first_day', '0' );

        if ( empty( $first_day ) ) {
            $first_day = 0;
        }

        $hour_default_start = ovabrw_get_default_time( get_the_id(), 'start' );
        $hour_default_end   = ovabrw_get_default_time(  get_the_id(), 'end' );

        // Defined label for custom checkout field
        $label_option_value =  esc_html__( 'text', 'ova-brw' );
        $label_option_text  =  esc_html__( 'text', 'ova-brw' );
        $label_add_new_opt  = esc_html__( 'Add new option', 'ova-brw' );
        $label_remove_opt   = esc_html__( 'Remove option', 'ova-brw' );
        $label_are_you_sure = esc_html__( 'Are you sure ?', 'ova-brw' );

        // Defined label for Discount
        $label_per_day          = esc_html__( '/Day', 'ova-brw' );
        $label_regular_per_day  = esc_html__( 'Regular Price / Day', 'ova-brw' );
        $label_price            = esc_html__( 'Price', 'ova-brw' );
        $notifi_disable_day     = esc_html__( 'You cannot book on this day!', 'ova-brw' );

        // Global color
        $light_color    = get_option( 'ovabrw_glb_light_color', '#C3C3C3' );
        $text_color     = get_option( 'ovabrw_glb_text_color', '#555555' );
        ?>
            <script type="text/javascript">
                var brw_data_step   = '<?php echo $data_step; ?>';
                var brw_year_start  = '<?php echo $year_start; ?>';
                var brw_year_end    = '<?php echo $year_end; ?>';
                var brw_date_format = '<?php echo $date_format; ?>';
                var brw_time_format = '<?php echo $time_format; ?>';
                var brw_format_time = '<?php echo $format_time; ?>';
                var first_day       = '<?php echo $first_day; ?>'

                var brw_lang_general_calendar                   = '<?php echo $lang_general_calendar; ?>';
                var brw_time_to_book_general_calendar           = '<?php echo $time_to_book_general_calendar; ?>';
                var brw_time_to_book_general_calendar_endate    = '<?php echo $time_to_book_general_calendar_endate; ?>';
                var brw_disable_week_day    = '<?php echo $disable_week_day; ?>';
                var brw_hour_default_start  = '<?php echo $hour_default_start; ?>';
                var brw_hour_default_end    = '<?php echo $hour_default_end; ?>';
                var label_option_value      = '<?php echo $label_option_value; ?>';
                var label_option_text       = '<?php echo $label_option_text; ?>';
                var label_add_new_opt       = '<?php echo $label_add_new_opt; ?>';
                var label_remove_opt        = '<?php echo $label_remove_opt; ?>';
                var label_are_you_sure      = '<?php echo $label_are_you_sure; ?>';
                var label_per_day           = '<?php echo $label_per_day; ?>';
                var label_regular_per_day   = '<?php echo $label_regular_per_day; ?>';
                var label_price             = '<?php echo $label_price; ?>';

                // init notificate disable day calendar
                var notifi_disable_day = '<?php echo $notifi_disable_day; ?>';

                // Global Color
                var ovabrwLightColor = '<?php echo $light_color; ?>';
                var ovabrwTextColor = '<?php echo $text_color; ?>';
            </script>
        <?php
    }
}

/**
 * Hook: woocommerce_product_tabs
 * @hooked: ovabrw_woo_new_product_tab - 10
 */
add_filter( 'woocommerce_product_tabs', 'ovabrw_woo_new_product_tab', 10 );

/**
 * Hook: woocommerce_after_shop_loop_item_title.
 *
 * @hooked ovabrw_product_price - 9
 */
add_action( 'woocommerce_after_shop_loop_item_title', 'ovabrw_product_price', 9 );
if ( ! function_exists( 'ovabrw_product_price' ) ) {
    function ovabrw_product_price() {
        return ovabrw_get_template( 'loop/price.php' );
    }
}

/**
 * Hook: woocommerce_after_shop_loop_item.
 *
 * @hooked ovabrw_loop_featured - 9
 */
add_action( 'woocommerce_after_shop_loop_item', 'ovabrw_loop_featured', 9 );
if ( ! function_exists( 'ovabrw_loop_featured' ) ) {
    function ovabrw_loop_featured() {
        if ( ovabrw_get_setting( get_option( 'ova_brw_archive_product_show_features', 'yes' ) ) == 'yes' ) {
            return ovabrw_get_template( 'loop/featured.php' );
        }
    }
}

/**
 * Hook: woocommerce_after_shop_loop_item.
 *
 * @hooked ovabrw_loop_taxonomy - 9
 */
add_action( 'woocommerce_after_shop_loop_item', 'ovabrw_loop_taxonomy', 9 );
if ( ! function_exists( 'ovabrw_loop_taxonomy' ) ) {
    function ovabrw_loop_taxonomy() {
        return ovabrw_get_template( 'loop/taxonomy.php' );
    }
}

/**
 * Hook: woocommerce_after_shop_loop_item.
 *
 * @hooked ovabrw_loop_attributes - 8
 */
add_action( 'woocommerce_after_shop_loop_item', 'ovabrw_loop_attributes', 8 );
if ( ! function_exists( 'ovabrw_loop_attributes' ) ) {
    function ovabrw_loop_attributes() {
        if ( ovabrw_get_setting( get_option( 'ova_brw_archive_product_show_attribute', 'yes' ) ) == 'yes' ) {
            return ovabrw_get_template( 'loop/attributes.php' );
        }
    }
}

/**
 * Hook: woocommerce_single_product_summary
 * @hooked ovabrw_woocommerce_template_single_price - 10
 */
add_action( 'woocommerce_single_product_summary', 'ovabrw_woocommerce_template_single_price', 10 );
if ( ! function_exists( 'ovabrw_woocommerce_template_single_price' ) ) {
    function ovabrw_woocommerce_template_single_price() {
        return ovabrw_get_template( 'single/price.php' );
    }
}

/**
 * Hook: woocommerce_single_product_summary
 * @hooked ovabrw_woocommerce_template_single_cus_tax - 65
 */
add_action( 'woocommerce_single_product_summary', 'ovabrw_woocommerce_template_single_cus_tax', 65 );
if ( ! function_exists( 'ovabrw_woocommerce_template_single_cus_tax' ) ) {
    function ovabrw_woocommerce_template_single_cus_tax() {
        if ( ovabrw_get_setting( get_option( 'ova_brw_template_show_cus_tax', 'yes' ) ) === 'yes' ) {
            return ovabrw_get_template( 'single/custom_taxonomy.php' );
        }
    }
}

/**
 * Hook: woocommerce_single_product_summary
 * @hooked ovabrw_woocommerce_template_single_specifications - 70
 */
add_action( 'woocommerce_single_product_summary', 'ovabrw_woocommerce_template_single_specifications', 70 );
if ( ! function_exists( 'ovabrw_woocommerce_template_single_specifications' ) ) {
    function ovabrw_woocommerce_template_single_specifications() {
        if ( ovabrw_get_setting( get_option( 'ova_brw_template_show_specifications', 'yes' ) ) === 'yes' ) {
            return ovabrw_get_template( 'single/specifications.php' );
        }
    }
}

/**
 * Hook: woocommerce_single_product_summary
 * @hooked ovabrw_woocommerce_template_single_featured - 70
 */
add_action( 'woocommerce_single_product_summary', 'ovabrw_woocommerce_template_single_featured', 70 );
if ( ! function_exists( 'ovabrw_woocommerce_template_single_featured' ) ) {
    function ovabrw_woocommerce_template_single_featured() {
        if ( ovabrw_get_setting( get_option( 'ova_brw_template_show_feature', 'yes' ) ) === 'yes' ) {
            return ovabrw_get_template( 'single/features.php' );
        }
    }
}

/**
 * Hook: woocommerce_single_product_summary
 * @hooked ovabrw_woocommerce_template_single_table_price - 71
 */
add_action( 'woocommerce_single_product_summary', 'ovabrw_woocommerce_template_single_table_price', 71 );
if ( ! function_exists( 'ovabrw_woocommerce_template_single_table_price' ) ) {
    function ovabrw_woocommerce_template_single_table_price() {
        if ( ovabrw_get_setting( get_option( 'ova_brw_template_show_table_price', 'yes' ) ) === 'yes' ) {
            return ovabrw_get_template( 'single/table_price.php' );
        }
    }
}

/**
 * Hook: woocommerce_single_product_summary
 * @hooked ovabrw_woocommerce_template_single_untime - 72
 */
add_action( 'woocommerce_single_product_summary', 'ovabrw_woocommerce_template_single_untime', 72 );
if ( ! function_exists( 'ovabrw_woocommerce_template_single_untime' ) ) {
    function ovabrw_woocommerce_template_single_untime() {
        if ( ovabrw_get_setting( get_option( 'ova_brw_template_show_maintenance', 'yes' ) ) === 'yes' ) {
            return ovabrw_get_template( 'single/unavailable_time.php' );
        }
    }
}

/**
 * Hook: woocommerce_single_product_summary
 * @hooked ovabrw_woocommerce_template_single_calendar - 73
 */
add_action( 'woocommerce_single_product_summary', 'ovabrw_woocommerce_template_single_calendar', 73 );
if ( ! function_exists( 'ovabrw_woocommerce_template_single_calendar' ) ) {
    function ovabrw_woocommerce_template_single_calendar() {
        if ( ovabrw_get_setting( get_option( 'ova_brw_template_show_calendar', 'yes' ) ) === 'yes' ) { 
            return ovabrw_get_template( 'single/calendar.php' );
        }
    }
}

/**
 * Hook: woocommerce_single_product_summary
 * @hooked ovabrw_woocommerce_template_single_booking_form - 74
 */
add_action( 'woocommerce_single_product_summary', 'ovabrw_woocommerce_template_single_booking_form', 74 );
if ( ! function_exists( 'ovabrw_woocommerce_template_single_booking_form' ) ) {
    function ovabrw_woocommerce_template_single_booking_form() {
        if ( ovabrw_get_setting( get_option( 'ova_brw_template_show_booking_form', 'yes' ) ) === 'yes' ) { 
            return ovabrw_get_template( 'single/booking-form.php' );
        }
    }
}

/**
 * Hook: ovabrw_booking_form
 * @hooked: ovabrw_booking_form_fields - 5
 */
add_action( 'ovabrw_booking_form', 'ovabrw_booking_form_fields', 5, 1 );
if ( ! function_exists( 'ovabrw_booking_form_fields' ) ) {
    function ovabrw_booking_form_fields( $product_id ) {
        return ovabrw_get_template( 'single/booking-form/fields.php', array( 'product_id' => $product_id ) );
    }
}

/**
 * Hook: ovabrw_booking_form
 * @hooked: ovabrw_booking_form_extra_fields - 10
 */
add_action( 'ovabrw_booking_form', 'ovabrw_booking_form_extra_fields', 10, 1 );
if ( ! function_exists( 'ovabrw_booking_form_extra_fields' ) ) {
    function ovabrw_booking_form_extra_fields( $product_id ) {
        return ovabrw_get_template( 'single/booking-form/extra_fields.php', array(  'product_id' => $product_id ) );  
    }
}

/**
 * Hook: ovabrw_booking_form
 * @hooked: ovabrw_booking_form_resource - 15
 */
add_action( 'ovabrw_booking_form', 'ovabrw_booking_form_resource', 15, 1 );
if ( ! function_exists( 'ovabrw_booking_form_resource' ) ) {
    function ovabrw_booking_form_resource( $product_id ) {
        if ( ovabrw_get_setting( get_option( 'ova_brw_booking_form_show_extra_resource', 'yes' ) ) == 'yes' ){
            return ovabrw_get_template( 'single/booking-form/resource.php', array(  'product_id' => $product_id ) );
        }
    }
}

/**
 * Hook: ovabrw_booking_form
 * @hooked: ovabrw_booking_form_services - 20
 */
add_action( 'ovabrw_booking_form', 'ovabrw_booking_form_services', 20, 1 );
if ( ! function_exists( 'ovabrw_booking_form_services' ) ) {
    function ovabrw_booking_form_services( $product_id ) {
        if ( ovabrw_get_setting( get_option( 'ova_brw_booking_form_show_extra_service', 'yes' ) ) == 'yes' ) {
            return ovabrw_get_template( 'single/booking-form/services.php', array(  'product_id' => $product_id ) );
        }
    }
}

/**
 * Hook: ovabrw_booking_form
 * @hooked: ovabrw_booking_form_deposit - 25
 */
add_action( 'ovabrw_booking_form', 'ovabrw_booking_form_deposit', 25, 1 );
if ( ! function_exists( 'ovabrw_booking_form_deposit' ) ) {
    function ovabrw_booking_form_deposit( $product_id ) {
        $deposit_enable = get_post_meta ( $product_id, 'ovabrw_enable_deposit', true );

        if ( $deposit_enable === 'yes' ) {
           return ovabrw_get_template( 'single/booking-form/deposit.php', array(  'product_id' => $product_id ) );
        }
        
        return;
    }
}

/**
 * Hook: ovabrw_booking_form
 * @hooked: ovabrw_booking_form_ajax_total - 30
 */
add_action( 'ovabrw_booking_form', 'ovabrw_booking_form_ajax_total', 30, 1 );
if ( ! function_exists( 'ovabrw_booking_form_ajax_total' ) ) {
    function ovabrw_booking_form_ajax_total( $product_id ) {
        return ovabrw_get_template( 'single/booking-form/ajax_total.php', array(  'product_id' => $product_id ) );
    }
}

/**
 * Hook: ovabrw_table_price_weekdays
 * @hooked: ovabrw_table_price_weekdays - 10
 */
add_action( 'ovabrw_table_price_weekdays', 'ovabrw_table_price_weekdays', 10, 1 );
if ( ! function_exists( 'ovabrw_table_price_weekdays' ) ) {
    function ovabrw_table_price_weekdays( $product_id ) {
        $price_type = get_post_meta( $product_id, 'ovabrw_price_type', true );
        $monday     = get_post_meta( $product_id, 'ovabrw_daily_monday', true );
        $tuesday    = get_post_meta( $product_id, 'ovabrw_daily_tuesday', true );
        $wednesday  = get_post_meta( $product_id, 'ovabrw_daily_wednesday', true );
        $thursday   = get_post_meta( $product_id, 'ovabrw_daily_thursday', true );
        $friday     = get_post_meta( $product_id, 'ovabrw_daily_friday', true );
        $saturday   = get_post_meta( $product_id, 'ovabrw_daily_saturday', true );
        $sunday     = get_post_meta( $product_id, 'ovabrw_daily_sunday', true );

        if ( ( $price_type == 'day' || $price_type == 'mixed' ) && $monday && $tuesday && $wednesday && $thursday && $friday && $saturday && $sunday ) { 
            return ovabrw_get_template( 'single/table-price/weekdays.php', array(  'product_id' => $product_id ) );
        }
    }
}

/**
 * Hook: ovabrw_table_price_global_discount_day
 * @hooked: ovabrw_table_price_global_discount_day - 10
 */
add_action( 'ovabrw_table_price_global_discount_day', 'ovabrw_table_price_global_discount_day', 10, 1 );
if ( ! function_exists( 'ovabrw_table_price_global_discount_day' ) ) {
    function ovabrw_table_price_global_discount_day( $product_id ) {
        return ovabrw_get_template( 'single/table-price/global_discount_day.php',  array(  'product_id' => $product_id ) ); 
    }
}

/**
 * Hook: ovabrw_table_price_global_discount_hour
 * @hooked: ovabrw_table_price_global_discount_hour - 10
 */
add_action( 'ovabrw_table_price_global_discount_hour', 'ovabrw_table_price_global_discount_hour', 10, 1 );
if ( ! function_exists( 'ovabrw_table_price_global_discount_hour' ) ) {
    function ovabrw_table_price_global_discount_hour( $product_id ) {
        return ovabrw_get_template( 'single/table-price/global_discount_hour.php', array(  'product_id' => $product_id ) );
    }
}

/**
 * Hook: ovabrw_table_price_seasons_day
 * @hooked: ovabrw_table_price_seasons_day - 10
 */
add_action( 'ovabrw_table_price_seasons_day', 'ovabrw_table_price_seasons_day', 10, 1 );
if ( ! function_exists( 'ovabrw_table_price_seasons_day' ) ) {
    function ovabrw_table_price_seasons_day( $product_id ) {
        return ovabrw_get_template( 'single/table-price/seasons_day.php', array(  'product_id' => $product_id ) );
    }
}

/**
 * Hook: ovabrw_table_price_seasons_hour
 * @hooked: ovabrw_table_price_seasons_hour - 10
 */
add_action( 'ovabrw_table_price_seasons_hour', 'ovabrw_table_price_seasons_hour', 10, 1 );
if ( ! function_exists( 'ovabrw_table_price_seasons_hour' ) ) {
    function ovabrw_table_price_seasons_hour( $product_id ) {
        return ovabrw_get_template( 'single/table-price/seasons_hour.php', array(  'product_id' => $product_id ) );
    }
}

/**
 * Hook: ovabrw_table_price_period_time
 * @hooked: ovabrw_table_price_period_time - 10
 */
add_action( 'ovabrw_table_price_period_time', 'ovabrw_table_price_period_time', 10, 1 );
if ( ! function_exists( 'ovabrw_table_price_period_time' ) ) {
    function ovabrw_table_price_period_time( $product_id ) {
        return ovabrw_get_template( 'single/table-price/period_time.php', array(  'product_id' => $product_id ) );
    }
}

/**
 * Hook: ovabrw_request_booking_form
 * @hooked: ovabrw_request_booking_form - 10
 */
add_action( 'ovabrw_request_booking_form', 'ovabrw_request_booking_form', 10, 0 );
if ( ! function_exists( 'ovabrw_request_booking_form' ) ) {
    function ovabrw_request_booking_form() {
        return ovabrw_get_template( 'single/request_booking.php' );
    }
}

// Register in wc_order_statuses.
add_filter( 'wc_order_statuses', 'wc_closed_order_statuses' );
if ( ! function_exists( 'wc_closed_order_statuses' ) ) {
    function wc_closed_order_statuses( $order_statuses ) {
        $order_statuses['wc-closed'] = _x( 'Closed', 'Order status', 'ova-brw' );

        return $order_statuses;
    }
}

// Replace product link in Search Result Page
add_filter( 'woocommerce_loop_product_link', 'ovarbrw_woocommerce_loop_product_link', 10, 1 );
if ( ! function_exists( 'ovarbrw_woocommerce_loop_product_link' ) ) {
    function ovarbrw_woocommerce_loop_product_link( $product_link ) {
        if ( isset( $_GET['ovabrw_search'] ) ) {
            if ( isset( $_GET['ovabrw_pickup_date'] ) && $_GET['ovabrw_pickup_date'] ) {
                $product_link = add_query_arg( 'pickup_date', $_GET['ovabrw_pickup_date'], $product_link );
            }
            if ( isset( $_GET['ovabrw_pickoff_date'] ) && $_GET['ovabrw_pickoff_date'] ) {
                $product_link = add_query_arg( 'dropoff_date', $_GET['ovabrw_pickoff_date'], $product_link );
            }
            if ( isset( $_GET['ovabrw_pickup_loc'] ) && $_GET['ovabrw_pickup_loc'] ) {
                $product_link = add_query_arg( 'pickup_loc', $_GET['ovabrw_pickup_loc'], $product_link );
            }
            if ( isset( $_GET['ovabrw_pickoff_loc'] ) && $_GET['ovabrw_pickoff_loc'] ) {
                $product_link = add_query_arg( 'pickoff_loc', $_GET['ovabrw_pickoff_loc'], $product_link );
            }
        }

        return $product_link;
    }
}

add_filter( 'woocommerce_loop_add_to_cart_link', 'ovarbrw_woocommerce_loop_add_to_cart_link', 10, 3 );
if ( ! function_exists( 'ovarbrw_woocommerce_loop_add_to_cart_link' ) ) {
    function ovarbrw_woocommerce_loop_add_to_cart_link( $link, $product, $args ) {
        $product_link = $product->add_to_cart_url();

        if ( isset( $_GET['ovabrw_search'] ) ) {
            if ( isset( $_GET['ovabrw_pickup_date'] ) && $_GET['ovabrw_pickup_date'] ) {
                $product_link = add_query_arg( 'pickup_date', $_GET['ovabrw_pickup_date'], $product_link );
            }
            if ( isset( $_GET['ovabrw_pickoff_date'] ) && $_GET['ovabrw_pickoff_date'] ) {
                $product_link = add_query_arg( 'dropoff_date', $_GET['ovabrw_pickoff_date'], $product_link );
            }
            if ( isset( $_GET['ovabrw_pickup_loc'] ) && $_GET['ovabrw_pickup_loc'] ) {
                $product_link = add_query_arg( 'pickup_loc', $_GET['ovabrw_pickup_loc'], $product_link );
            }
            if ( isset( $_GET['ovabrw_pickoff_loc'] ) && $_GET['ovabrw_pickoff_loc'] ) {
                $product_link = add_query_arg( 'pickoff_loc', $_GET['ovabrw_pickoff_loc'], $product_link );
            }
        }
        
        return sprintf(
            '<a href="%s" data-quantity="%s" class="%s" %s>%s</a>',
            esc_url( $product_link ),
            esc_attr( isset( $args['quantity'] ) ? $args['quantity'] : 1 ),
            esc_attr( isset( $args['class'] ) ? $args['class'] : 'button' ),
            isset( $args['attributes'] ) ? wc_implode_html_attributes( $args['attributes'] ) : '',
            esc_html( $product->add_to_cart_text() )
        );
    }
}

// Allow users cancel Order
add_filter( 'woocommerce_valid_order_statuses_for_cancel', 'ovabrw_woo_valid_order_statuses_for_cancel', 10, 2 );
if ( ! function_exists( 'ovabrw_woo_valid_order_statuses_for_cancel' ) ) {
    function ovabrw_woo_valid_order_statuses_for_cancel( $array_status, $order ) {
        $order_status_can_cancel = $time_can_cancel = $other_condition = $total_order_valid = true;
         
        if ( in_array( $order->get_status(), array( 'pending', 'failed' ) ) ) {
            return array( 'pending', 'failed' );
        }

        // Check order status can order
        if ( !in_array( $order->get_status(), apply_filters( 'ovabrw_order_status_can_cancel', array( 'completed', 'processing', 'on-hold', 'pending', 'failed' ) ) )  ){
            $order_status_can_cancel = false;
        }
        
        // Validate before x hours can cancel
        // Get Meta Data type line_item of Order
        $order_line_items = $order->get_items( apply_filters( 'woocommerce_purchase_order_item_types', 'line_item' ) );
        foreach( $order_line_items as $item_id => $item ) {
            $product_id = $item->get_product_id();
            $product    = wc_get_product( $product_id );

            if ( ! $product ) continue;

            $cancel_valid_minutes   = ovabrw_get_setting( get_option( 'ova_brw_cancel_before_x_hours', 0 ) );
            $cancel_valid_total     = ovabrw_get_setting( get_option( 'ova_brw_cancel_condition_total_order', 1 ) );

            // Check if product type is rental
            if ( $product->get_type() == 'ovabrw_car_rental' ) {
                // Get value of pickup date, pickoff date
                if ( $item && is_object( $item ) ) {
                    $ovabrw_pickup_date = strtotime( $item->get_meta('ovabrw_pickup_date') );

                    if ( ! ( $ovabrw_pickup_date > current_time( 'timestamp' ) && $ovabrw_pickup_date - current_time( 'timestamp' ) > $cancel_valid_minutes*60*60  ) ) {
                       $time_can_cancel = false;
                       break;
                    }
                }
            }
        }

        // Cancel by total order
        if ( empty( $cancel_valid_total ) ) {
            $total_order_valid = true;
        } else if ( $order->get_total() > floatval( $cancel_valid_total ) ) {
            $total_order_valid = false;
        }
        
        // Other condition
        $other_condition = apply_filters( 'ovabrw_other_condition_to_cancel_order', true, $order );
        if ( $order_status_can_cancel && $time_can_cancel && $total_order_valid && $other_condition ) {
            return array( 'completed', 'processing', 'on-hold', 'pending', 'failed' );
        } else {
            return array();
        }
    }
}

if ( ! function_exists( 'ovabrw_woo_new_product_tab' ) ) {
    function ovabrw_woo_new_product_tab( $tabs ) {
        // Add Request Booking Tab
        $product_id = get_the_id();
        $product    = wc_get_product( $product_id );

        if ( $product ) {
            // Check product template
            $flag = true;
            $product_template = get_option( 'ova_brw_template_elementor_template', 'default' );

            if ( ovabrw_global_typography() && $product_template === 'modern' ) {
                $template_by_category = ovabrw_get_product_template( $product_id );

                if ( $template_by_category && $template_by_category !== 'modern' ) {
                    $flag = true;
                } else {
                    $flag = false;
                }
            }

            if ( ovabrw_get_setting( get_option( 'ova_brw_template_show_request_booking', 'yes' ) ) === 'yes' && $product->get_type() == 'ovabrw_car_rental' && apply_filters( 'ovabrw_ft_show_request_booking_in_product_tabs', $flag ) ) {
                $tabs['ovabrw_reqest_booking'] = array(
                    'title'     => esc_html__( 'Request for booking', 'ova-brw' ),
                    'priority'  => (int)ovabrw_get_setting( get_option( 'ova_brw_request_booking_form_order_tab', 9 ) ),
                    'callback'  => 'ovabrw_woo_request_booking_tab_content'
                );
            }

            // Add Extra Tab
            $ovabrw_manage_extra_tab = get_post_meta( $product_id, 'ovabrw_manage_extra_tab', true );

            switch( $ovabrw_manage_extra_tab ) {
                case 'in_setting' : {
                    $short_code_form = ovabrw_get_setting( get_option('ova_brw_extra_tab_shortcode_form', '') );
                    break;
                }
                case 'new_form' : {
                    $short_code_form = get_post_meta( $product_id, 'ovabrw_extra_tab_shortcode', true );
                    break;
                }
                case 'no' : {
                    $short_code_form = '';
                    break;
                }
                default: {
                    $short_code_form = ovabrw_get_setting( get_option('ova_brw_extra_tab_shortcode_form', '') );
                    break;
                }
            }

            if ( ! $product || $product->get_type() !== 'ovabrw_car_rental' ) return $tabs;
            if ( ovabrw_get_setting( get_option( 'ova_brw_template_show_extra_tab', 'yes' ) ) === 'yes' && $short_code_form != ''   ) {
                $tabs['ovabrw_extra_tab'] = array(
                    'title'     => esc_html__( 'Extra Tab', 'ova-brw' ),
                    'priority'  => (int)ovabrw_get_setting( get_option( 'ova_brw_extra_tab_order_tab', 21 ) ),
                    'callback'  => 'ova_new_product_tab_extra_tab'
                );
            }
        }
        return $tabs;
    }
}

if ( ! function_exists( 'ova_new_product_tab_extra_tab' ) ) {
    function ova_new_product_tab_extra_tab() {
        return ovabrw_get_template( 'single/contact_form.php' );
    }
}

if ( ! function_exists( 'ovabrw_woo_request_booking_tab_content' ) ) {
    function ovabrw_woo_request_booking_tab_content() { 
       return ovabrw_get_template( 'single/request_booking.php' );
    }
}