<?php defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'OVABRW_Rental_Types' ) ) {
	class OVABRW_Rental_Types {
		protected static $_instance = null;
		public $rental_types = [];

		public function __construct() {
			// Load
			ovabrw_autoload( OVABRW_PLUGIN_PATH .'rental-types/types/class-ovabrw-rental-by-*.php' );

			// Object Rental Types
			$this->init();

			// Hook calculate totals
			add_action( 'woocommerce_before_calculate_totals', array( $this, 'ovabrw_before_calculate_totals' ), 11 );

			// Checkout Validate
			add_action( 'woocommerce_after_checkout_validation', array( $this, 'ovabrw_after_checkout_validation' ), 11, 2 );

			// Checkout Save
			add_action( 'woocommerce_checkout_create_order_line_item', array( $this, 'ovabrw_checkout_create_order_line_item' ), 11, 4 );

			// Order item display meta from backend
			add_filter( 'woocommerce_order_item_display_meta_key', array( $this, 'ovabrw_order_item_display_meta_key' ), 11, 3 );

			// Order item display meta from email
			add_filter( 'woocommerce_order_item_display_meta_value', array( $this, 'ovabrw_order_item_display_meta_value' ), 11, 3 );

			// Hide meta item fields
			add_filter( 'woocommerce_order_item_get_formatted_meta_data', array( $this, 'ovabrw_order_item_get_formatted_meta_data' ), 11, 2 );

			// Email Order Items - Quantity
			add_filter( 'woocommerce_email_order_item_quantity', array( $this, 'ovabrw_email_order_item_quantity' ), 11, 2 );

			// HTML Product Sticky
			add_action( 'woocommerce_after_single_product', array( $this, 'ovabrw_product_sticky' ) );
		}

		public function ovabrw_product_sticky() {
			do_action( 'ovabrw_before_product_sticky' );

			if ( ! apply_filters( 'ovabrw_before_product_sticky', true ) ) return;

			global $product;

			if ( isset( $args['product_id'] ) && $args['product_id'] ) {
				$product = wc_get_product( $args['product_id'] );
			}

			if ( ! $product ) return;
			$product_id = $product->get_id();
			if ( ! ovabrw_is_rental_product( $product_id ) ) return;

			$rental_type 	= get_post_meta( $product_id, 'ovabrw_price_type', true );
			$rental_object 	= isset( $this->rental_types[$rental_type] ) ? $this->rental_types[$rental_type] : '';
        	if ( empty( $rental_object ) || ! is_object( $rental_object ) ) return;

        	$btn_link = '#booking_form';

        	if ( get_option( 'ova_brw_template_show_booking_form', 'yes' ) != 'yes' ) {
        		if ( get_option( 'ova_brw_template_show_request_booking', 'yes' ) === 'yes' ) {
        			$btn_link = '#request_booking';
        		} else {
        			$btn_link = '#';
        		}
        	}
		?>
			<div class="ovabrw-product-sticky">
				<div class="ovabrw-sticky-content">
					<div class="ovabrw-product-price">
						<label><?php esc_html_e( 'from', 'ova-brw' ); ?></label>
						<span class="ovabrw-regular-price">
							<?php $rental_object->get_html_price( $product_id ); ?>
						</span>
					</div>
					<div class="ovabrw-product-btn">
						<a href="<?php echo esc_attr( $btn_link ); ?>">
							<?php esc_html_e( 'Booking', 'ova-brw' ); ?>
						</a>
					</div>
				</div>
			</div>
		<?php
			do_action( 'ovabrw_after_product_sticky' );
		}

		public function init() {
			$this->rental_types['day'] 				= new OVABRW_Rental_By_Day();
			$this->rental_types['hour'] 			= new OVABRW_Rental_By_Hour();
			$this->rental_types['mixed'] 			= new OVABRW_Rental_By_Mixed();
			$this->rental_types['period_time'] 		= new OVABRW_Rental_By_Period_Time();
			$this->rental_types['transportation'] 	= new OVABRW_Rental_By_Transportation();
			$this->rental_types['taxi'] 			= new OVABRW_Rental_By_Taxi();
			$this->rental_types['hotel'] 			= new OVABRW_Rental_By_Hotel();
		}

		public function ovabrw_before_calculate_totals( $cart_object ) {
			$deposit_amount = $insurance_amount = $remaining_amount = $remaining_tax = 0;
			$is_deposit 	= false;

			foreach ( $cart_object->get_cart() as $cart_item_key => $cart_item ) {
				$product_id = isset( $cart_item['product_id'] ) ? $cart_item['product_id'] : '';

				if ( ! $product_id || ! $cart_item['data']->is_type('ovabrw_car_rental') ) continue;

				$rental_type = isset( $cart_item['rental_type'] ) ? $cart_item['rental_type'] : '';

				// Object Rental Types
            	$rental_object = isset( $this->rental_types[$rental_type] ) ? $this->rental_types[$rental_type] : '';
            	if ( empty( $rental_object ) || ! is_object( $rental_object ) ) continue;

            	// Set Product ID
            	$rental_object->set_ID( $product_id );

            	$sub_deposit 	= $sub_remaining = 0;
            	$item_total 	= $rental_object->get_total( $cart_item );
            	$item_insurance = isset( $cart_item['ovabrw_amount_insurance'] ) ? floatval( $cart_item['ovabrw_amount_insurance'] ) : 0;

            	// Multi Currency
            	if ( is_plugin_active( 'woocommerce-multilingual/wpml-woocommerce.php' ) ) {
	                $item_total 	= ovabrw_convert_price( $item_total );
	                $item_insurance = ovabrw_convert_price( $item_insurance );
	            }

	            // Deposit info
	            WC()->cart->deposit_info = array();

	            // Deposit
	            $deposit = isset( $cart_item['ova_type_deposit'] ) ? $cart_item['ova_type_deposit'] : '';

	            if ( $deposit === 'deposit' ) {
	            	$is_deposit 	= true;
	            	$deposit_type 	= $rental_object->get_value_by_id( $product_id, 'type_deposit' );
	            	$deposit_value 	= floatval( $rental_object->get_value_by_id( $product_id, 'amount_deposit' ) );

	            	// Percent
	            	if ( $deposit_type === 'percent' ) {
	            		$sub_deposit = ( $item_total * $deposit_value ) / 100;
	            	}

	            	// Fixed
	            	if ( $deposit_type === 'value' ) {
	            		$sub_deposit = $deposit_value;
	            	}

	            	$sub_remaining = $item_total - $sub_deposit;

	            	$remaining_amount 	+= OVABRW_Get_Data::instance()->get_price_tax( $sub_remaining, $cart_item );
            		$deposit_amount 	+= $sub_deposit;

            		// Add tax total remanining
		            if ( wc_tax_enabled() ) {
		                $prices_include_tax   	= wc_prices_include_tax() ? 'yes' : 'no';
		                $remaining_tax 			+= OVABRW_Get_Data::instance()->get_taxes_by_price( $sub_remaining, $product_id, $prices_include_tax );
		            }

		            WC()->cart->deposit_info[ '_ova_has_deposit' ]      = $is_deposit;
		            WC()->cart->deposit_info[ 'ova_type_deposit' ]      = $deposit;
		            WC()->cart->deposit_info[ 'ova_deposit_amount' ]    = round( $deposit_amount, wc_get_price_decimals() );
		            WC()->cart->deposit_info[ 'ova_remaining_amount' ]  = round( $remaining_amount, wc_get_price_decimals() );
		            WC()->cart->deposit_info[ 'ova_remaining_taxes' ]   = $remaining_tax;

		            $cart_item['data']->add_meta_data( 'ovabrw_deposit_amount', round( $sub_deposit, wc_get_price_decimals() ), true );
		            $cart_item['data']->add_meta_data( 'ovabrw_remaining_amount', round( $sub_remaining, wc_get_price_decimals() ), true );
	            }

	            // Insurance
	            $insurance_amount += $item_insurance;
	            WC()->cart->deposit_info[ 'ova_insurance_amount' ] = round( $insurance_amount, wc_get_price_decimals() );

	            // Total
	            $cart_item['data']->set_price( round( $item_total, wc_get_price_decimals() ) );
            	$cart_item['data']->add_meta_data( 'pay_total', round( $item_total, wc_get_price_decimals() ), true );

            	if ( $sub_deposit && $is_deposit ) {
	                $cart_item['data']->set_price( $sub_deposit );
	            }

            	// Quantity
            	$cart_object->cart_contents[ $cart_item_key ]['quantity'] = 1;
			}
		}

		public function ovabrw_after_checkout_validation( $data, $errors ) {
			foreach ( WC()->cart->get_cart() as $cart_item ) {
				$product = isset( $cart_item['data'] ) ? $cart_item['data'] : '';

				if ( ! empty( $product ) && is_object( $product ) && $product->is_type( 'ovabrw_car_rental' ) ) {
					$product_id = $product->get_id();

					$rental_type = isset( $cart_item['rental_type'] ) ? $cart_item['rental_type'] : '';

					// Object Rental Types
	            	$rental_object = isset( $this->rental_types[$rental_type] ) ? $this->rental_types[$rental_type] : '';
	            	if ( empty( $rental_object ) || ! is_object( $rental_object ) ) continue;

	            	// Set Product ID
	            	$rental_object->set_ID( $product_id );

	            	// Check qty available
	            	$pickup_location 	= isset( $cart_item['ovabrw_pickup_loc'] ) ? $cart_item['ovabrw_pickup_loc'] : '' ;
		            $dropoff_location 	= isset( $cart_item['ovabrw_pickoff_loc'] ) ? $cart_item['ovabrw_pickoff_loc'] : '';
	            	$pickup_date    	= isset( $cart_item['ovabrw_pickup_date'] ) ? $cart_item['ovabrw_pickup_date'] : '';
		            $dropoff_date   	= isset( $cart_item['ovabrw_pickoff_date'] ) ? $cart_item['ovabrw_pickoff_date'] : '';
		            $input_qty 			= isset( $cart_item['ovabrw_number_vehicle'] ) ? absint( $cart_item['ovabrw_number_vehicle'] ) : 1;
			        $check_in 			= isset( $cart_item['ovabrw_checkin'] ) ? $cart_item['ovabrw_checkin'] : strtotime( $pickup_date );
			        $check_out 			= isset( $cart_item['ovabrw_checkout'] ) ? $cart_item['ovabrw_checkout'] : strtotime( $dropoff_date );

			        // Get qty available
			        $data_available = $rental_object->get_qty_available( $check_in, $check_out, $pickup_location, $dropoff_location, 'checkout' );
	        		$qty_available 	= $data_available['qty_available'];

	        		if ( $input_qty > $qty_available ) {
	        			$errors->add( 'validation', sprintf( esc_html__( '%s isn\'t available for this time, Please book other time.', 'ova-brw' ), $product->get_title() ) );
	        		}
				}
			}
		}

		public function ovabrw_checkout_create_order_line_item( $item, $cart_item_key, $values, $order ) {
			$product_id = $item->get_product_id();

	        // Check product type: rental
	        $product = wc_get_product( $product_id );
	        if ( ! $product || $product->get_type() !== 'ovabrw_car_rental' ) return;

	        // Rental Type
	        $rental_type = isset( $values['rental_type'] ) ? $values['rental_type'] : '';
	        
	        // Object Rental Types
        	$rental_object = isset( $this->rental_types[$rental_type] ) ? $this->rental_types[$rental_type] : '';
        	if ( empty( $rental_object ) || ! is_object( $rental_object ) ) return;

        	// Set Product ID
        	$rental_object->set_ID( $product_id );

        	// Save
        	$rental_object->ovabrw_save_order_line_item( $item, $values );
		}

		public function ovabrw_order_item_display_meta_key( $display_key, $meta, $item ) {
			$product_id = method_exists( $item, 'get_product_id' ) ? $item->get_product_id() : '';

			if ( ! $product_id ) return $display_key;

			$rental_type = get_post_meta( $product_id, 'ovabrw_price_type', true );

			if ( 'ovabrw_pickup_loc' === $meta->key ) $display_key = esc_html__( 'Pick-up Location', 'ova-brw' );
        	if ( 'ovabrw_pickoff_loc' === $meta->key ) $display_key = esc_html__( 'Drop-off Location', 'ova-brw' );
        	if ( 'ovabrw_pickup_date' === $meta->key ) {
        		$display_key = esc_html__( 'Pick-up Date', 'ova-brw' );
        		if ( $rental_type === 'hotel' ) $display_key = esc_html__( 'Check in', 'ova-brw' );
        	}
        	if ( 'ovabrw_pickoff_date' === $meta->key ) {
        		$display_key = esc_html__( 'Drop-off Date', 'ova-brw' );
        		if ( $rental_type === 'hotel' ) $display_key = esc_html__( 'Check out', 'ova-brw' );
        	}
        	if ( 'ovabrw_pickup_date_real' === $meta->key ) $display_key = esc_html__( 'Pick-up Date Real', 'ova-brw' );
        	if ( 'ovabrw_pickoff_date_real' === $meta->key ) $display_key = esc_html__( 'Drop-off Date Real', 'ova-brw' );
        	if ( 'period_label' === $meta->key ) $display_key = esc_html__(' Package ', 'ova-brw' );
        	if ( 'package_id' === $meta->key ) $display_key = esc_html__(' Package ID ', 'ova-brw' );
        	if ( 'ovabrw_number_vehicle' === $meta->key ) $display_key = esc_html__( 'Quantity', 'ova-brw' );
        	if ( 'id_vehicle' === $meta->key ) $display_key = esc_html__( 'Vehicle ID(s)', 'ova-brw' );
        	if ( 'ovabrw_total_days' === $meta->key ) $display_key = esc_html__( 'Total Time', 'ova-brw' );
        	if ( 'ovabrw_distance' === $meta->key ) $display_key = esc_html__( 'Distance', 'ova-brw' );
	        if ( 'ovabrw_extra_time' === $meta->key ) $display_key = esc_html__( 'Extra Time', 'ova-brw' );
	        if ( 'ovabrw_duration' === $meta->key ) $display_key = esc_html__( 'Duration', 'ova-brw' );
	        if ( 'ovabrw_original_order_id' === $meta->key ) $display_key = esc_html__( 'Original Order', 'ova-brw' );
	        if ( 'ovabrw_remaining_balance_order_id' === $meta->key ) $display_key = esc_html__( 'Remaining Balance Order', 'ova-brw' );
	        if ( 'ovabrw_adults' === $meta->key ) $display_key = esc_html__( 'Number of Adults', 'ova-brw' );
	        if ( 'ovabrw_children' === $meta->key ) $display_key = esc_html__( 'Number of Children', 'ova-brw' );
	        if ( 'ovabrw_babies' === $meta->key ) $display_key = esc_html__( 'Number of Babies', 'ova-brw' );

        	// Custom Checkout Fields
        	$list_fields = get_option( 'ovabrw_booking_form', array() );

	        if ( ! empty( $list_fields ) && is_array( $list_fields ) ) {
	            foreach ( $list_fields as $key => $field ) {
	                if ( $key === $meta->key ) {
	                    $display_key = $field['label'];
	                }
	            }
	        }

	        // Deposit
	        $tax_text = $tax_text_remaining = '';

	        if ( wc_tax_enabled() ) {
	            $order = $item->get_order();

	            $remaining_item  = $item->get_meta( 'ovabrw_remaining_amount_product' );
	            $is_tax_included = $order->get_meta( '_ova_tax_display_cart', true );
	            $remaining_taxes = $order->get_meta( '_ova_remaining_taxes', true );
	            $tax_message     = $is_tax_included ? esc_html__( '(incl. tax)', 'ova-brw' ) : esc_html__( '(excl. tax)', 'ova-brw' );

	            if ( ! empty( $remaining_taxes ) ) {
	                $tax_tex = ' <small class="tax_label">' . $tax_message . '</small>';
	            }

	            if ( ! empty( $remaining_item && ! empty( $remaining_taxes ) ) ) {
	                $tax_text_remaining = ' <small class="tax_label">' . $tax_message . '</small>';
	            }
	        }

	        if ( 'ovabrw_amount_insurance_product' === $meta->key ) $display_key = esc_html__( 'Amount Of Insurance', 'ova-brw' );
	        if ( 'ovabrw_deposit_amount_product' === $meta->key ) $display_key = esc_html__( 'Deposit Amount', 'ova-brw' ).$tax_text;
	        if ( 'ovabrw_remaining_amount_product' === $meta->key ) $display_key = esc_html__( 'Remaining Amount', 'ova-brw' ).$tax_text_remaining;
	        if ( 'ovabrw_deposit_full_amount' === $meta->key ) $display_key = esc_html__( 'Full Amount', 'ova-brw' ).$tax_text;

        	return $display_key;
		}

		public function ovabrw_order_item_display_meta_value( $meta_value, $meta, $item ) {
			$order = $item->get_order();

			if ( 'ovabrw_amount_insurance_product' === $meta->key ) { 
	            $meta_value = wc_price( $meta->value, array( 'currency' => $order->get_currency() ) );
	        }
	        if ( 'ovabrw_deposit_amount_product' === $meta->key ) { 
	            $meta_value = wc_price( $meta->value, array( 'currency' => $order->get_currency() ) );
	        }
	        if ( 'ovabrw_remaining_amount_product' === $meta->key ) { 
	            $meta_value = wc_price( $meta->value, array( 'currency' => $order->get_currency() ) );
	        }
	        if ( 'ovabrw_deposit_full_amount' === $meta->key ) { 
	            $meta_value = wc_price( $meta->value, array( 'currency' => $order->get_currency() ) );
	        }

			return $meta_value;
		}

		public function ovabrw_order_item_get_formatted_meta_data( $meta_data, $item ) {
			$hide_fields = array(
	            'rental_type',
	            'ovabrw_price_detail',
	            'ovabrw_total_days',
	            'package_id',
	            'package_type',
	            'define_day',
	            'ovabrw_pickup_date_real',
	            'ovabrw_pickoff_date_real'
	        );
	        
	        $new_meta = array();

	        foreach ( $meta_data as $id => $meta_array ) {
	        	if ( $meta_array->key === 'ovabrw_amount_insurance_product' ) {
	        		$amount_insurance = floatval( $meta_array->value );

	        		if ( ! $amount_insurance ) continue;
	        	}

	            if ( in_array( $meta_array->key , apply_filters( 'ovabrw_ft_hide_fields', $hide_fields, $item ) ) ) { continue; }
	            $new_meta[ $id ] = $meta_array;
	        }

	        return $new_meta;
		}

		public function ovabrw_email_order_item_quantity( $qty_display, $item ) {
			$qty_rental = intval( $item->get_meta( 'ovabrw_number_vehicle' ) );

		    if ( $qty_rental ) return $qty_rental;

		    return $qty_display;
		}

		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}

			return self::$_instance;
		}
	}

	new OVABRW_Rental_Types();
}