<?php defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'OVABRW_Rental_By_Taxi' ) ) {
	class OVABRW_Rental_By_Taxi extends OVABRW_Abstract_Rental_Types {
		protected $_instance = null;

		public function __construct() {
			$this->ID 		= '';
			$this->type 	= 'taxi';
			$this->title 	= esc_html__( 'Taxi', 'ova-brw' );
			$this->prefix 	= OVABRW_PREFIX;

			parent::__construct();
		}

		// Abstract Method
		public function ovabrw_wc_add_to_cart_validation( $passed_validation, $product_id, $quantity ) {
			do_action( 'ovabrw_before_wc_add_to_cart_validation', $passed_validation, $product_id, $quantity, $this );

			if ( ! ovabrw_is_rental_product( $product_id ) ) return $passed_validation;

			// Set Product ID
			$this->set_ID( $product_id );

			// Get Type
			$rental_type = $this->get_value( 'price_type' );

			// Check Type
			if ( $rental_type != $this->type ) return $passed_validation;

			// Data Form
			$pickup_location 	= isset( $_REQUEST[$this->get_name('pickup_loc')] ) ? trim( sanitize_text_field( $_REQUEST[$this->get_name('pickup_loc')] ) ) : '';
			$dropoff_location 	= isset( $_REQUEST[$this->get_name('pickoff_loc')] ) ? trim( sanitize_text_field( $_REQUEST[$this->get_name('pickoff_loc')] ) ) : '';
			$pickup_date 		= isset( $_REQUEST[$this->get_name('pickup_date')] ) ? sanitize_text_field( $_REQUEST[$this->get_name('pickup_date')] ) : '';
			$pickup_time 		= isset( $_REQUEST[$this->get_name('pickup_time')] ) ? sanitize_text_field( $_REQUEST[$this->get_name('pickup_time')] ) : '';
			$duration 			= isset( $_REQUEST['ovabrw-duration'] ) ? sanitize_text_field( $_REQUEST['ovabrw-duration'] ) : '';
			$input_qty 			= isset( $_REQUEST[$this->get_name('number_vehicle')] ) ? absint( sanitize_text_field( $_REQUEST[$this->get_name('number_vehicle')] ) ) : '';

			// Stock quantity does not exist
	        if ( ! absint( $input_qty ) ) $input_qty = 1;

	        // Required Pickup Location
	        if ( ! $pickup_location ) {
	        	wc_clear_notices();
	            echo wc_add_notice( esc_html__( 'Pick-up location is required', 'ova-brw' ), 'error' );
	            return false;
	        }

	        // Required Dropoff Location
	        if ( ! $dropoff_location ) {
	        	wc_clear_notices();
	            echo wc_add_notice( esc_html__( 'Drop-off location is required', 'ova-brw' ), 'error' );
	            return false;
	        }

	        // Get strtotime input date
	        $new_input_date = $this->get_strtotime_input_date( $pickup_date, $pickup_time, $duration );
	        $pickup_date 	= $new_input_date['pickup_date_new'];
	        $dropoff_date 	= $new_input_date['dropoff_date_new'] ? $new_input_date['dropoff_date_new'] : $pickup_date;

	        // Required Pickup Date & Dropoff Date
            if ( ! $pickup_date ) {
            	wc_clear_notices();
                echo wc_add_notice( esc_html__( 'Pick-up date is required', 'ova-brw' ), 'error' );
                return false;
			}

            if ( $pickup_date < current_time('timestamp') ) {
	            wc_clear_notices();
	            echo wc_add_notice( esc_html__( 'Pick-up Date must be greater than Current Time', 'ova-brw' ), 'error' );   
	            return false;
	        }

	        if ( ! $dropoff_date ) {
				wc_clear_notices();
                echo wc_add_notice( esc_html__( 'Drop-off date is required', 'ova-brw' ), 'error' );
                return false;
			}

            if ( $pickup_date > $dropoff_date ) {
                wc_clear_notices();
                echo wc_add_notice( esc_html__( 'Dropoff date must be greater than Pickup date', 'ova-brw' ), 'error' );
                return false;
            }

            // Check Perparation Time
	        if ( $this->check_preparation_time( $pickup_date ) ) {
	        	return false;
	        }

	        // Check input quantity
            if ( $input_qty < 1 ) {
            	wc_clear_notices();
                echo wc_add_notice( esc_html__( 'Quantity must be greater than 0', 'ova-brw' ), 'error' );
                return false;
            }

            // Check Services required
            if ( $this->required_service_fields() ) {
            	return false;
            }
	        // End
	        
	        // Custom Checkout Field
	        if ( $this->required_custom_checkout_fields() ) {
	        	return false;
	        }
	        // End
	        
	        // Check unavailable time
	        if ( $this->check_unavailable_time( $pickup_date, $dropoff_date ) ) {
	        	return false;
	        }
	        // End
	        
	        // Check disable week day
	        if ( $this->check_disable_week_day( $pickup_date, $dropoff_date ) ) {
	        	return false;
	        }
	        // End
	        
	        // Check available quantity
	        $data_available = $this->get_qty_available( $pickup_date, $dropoff_date, $pickup_location, $dropoff_location, 'cart' );
	        $qty_available 		= $data_available['qty_available'];
	        $vehicle_available 	= $data_available['vehicle_available'];

	        if ( $input_qty > $qty_available ) {
	        	wc_clear_notices();

	        	if ( $qty_available > 0 ) {
                	echo wc_add_notice( sprintf( esc_html__( 'Available vehicle is %s', 'ova-brw'  ), $qty_available ), 'error');
	        	} else {
	        		echo wc_add_notice( esc_html__( 'Vehicle isn\'t available for this time. Please book other time.', 'ova-brw' ), 'error' );
	        	}

                return false;
	        }

	        // Add vehicle ids to Woo session
	        if ( $this->is_array_exists( $vehicle_available ) ) {
	        	WC()->session->set( 'id_vehicle_available', implode( ', ', array_slice( $vehicle_available, 0, $input_qty ) ) );
	        }
	        // End
	        
	        do_action( 'ovabrw_after_wc_add_to_cart_validation', $passed_validation, $product_id, $quantity, $this );
			
			return apply_filters( 'ovabrw_wc_add_to_cart_validation', $passed_validation, $product_id, $quantity, $this );
		}

		public function ovabrw_wc_add_cart_item_data( $cart_item_data, $product_id, $variation_id, $quantity ) {
			do_action( 'ovabrw_before_wc_add_cart_item_data', $cart_item_data, $product_id, $quantity, $this );

			if ( ! ovabrw_is_rental_product( $product_id ) || empty( $_REQUEST ) ) return $cart_item_data;

			// Set Product ID
			$this->set_ID( $product_id );

			// Get Type
			$rental_type = $this->get_value( 'price_type' );

			// Check Type
			if ( $rental_type != $this->type ) return $cart_item_data;

			// Waypoints
			$ovabrw_waypoints = [];

			// Data Form
			$pickup_location 	= isset( $_REQUEST[$this->get_name('pickup_loc')] ) ? trim( sanitize_text_field( $_REQUEST[$this->get_name('pickup_loc')] ) ) : '';
			$dropoff_location 	= isset( $_REQUEST[$this->get_name('pickoff_loc')] ) ? trim( sanitize_text_field( $_REQUEST[$this->get_name('pickoff_loc')] ) ) : '';
			$pickup_date 		= isset( $_REQUEST[$this->get_name('pickup_date')] ) ? trim( sanitize_text_field( $_REQUEST[$this->get_name('pickup_date')] ) ) : '';
			$pickup_time 		= isset( $_REQUEST[$this->get_name('pickup_time')] ) ? trim( sanitize_text_field( $_REQUEST[$this->get_name('pickup_time')] ) ) : '';
			$input_qty 			= isset( $_REQUEST[$this->get_name('number_vehicle')] ) ? absint( sanitize_text_field( $_REQUEST[$this->get_name('number_vehicle')] ) ) : '';

			$ovabrw_waypoints   = isset( $_REQUEST['ovabrw_waypoint_address'] ) ? $_REQUEST['ovabrw_waypoint_address'] : [];
            $duration_map   	= isset( $_REQUEST['ovabrw-duration-map'] ) ? sanitize_text_field( $_REQUEST['ovabrw-duration-map'] ) : '';
            $duration       	= isset( $_REQUEST['ovabrw-duration'] ) ? sanitize_text_field( $_REQUEST['ovabrw-duration'] ) : '';
            $distance       	= isset( $_REQUEST['ovabrw-distance'] ) ? sanitize_text_field( $_REQUEST['ovabrw-distance'] ) : '';
            $extra_time     	= isset( $_REQUEST['ovabrw_extra_time'] ) ? sanitize_text_field( $_REQUEST['ovabrw_extra_time'] ) : '';

			// Stock quantity does not exist
	        if ( ! absint( $input_qty ) ) $input_qty = 1;

	        // Get strtotime input date
	        $new_date 		= $this->get_strtotime_input_date( $pickup_date, $pickup_time, $duration );
	        $pickup_date 	= $new_date['pickup_date_new'];
	        $dropoff_date 	= $new_date['dropoff_date_new'] ? $new_date['dropoff_date_new'] : $pickup_date;

	        $datetime_format = ovabrw_get_date_format() . ' ' . ovabrw_get_time_format_php();

	        $pickup_date 	= date( $datetime_format, $pickup_date );
	        $dropoff_date 	= date( $datetime_format, $dropoff_date );

	        // Check input
	        if ( ! $pickup_date || ! $dropoff_date ) {
	            return $cart_item_data;
	        }

	        // Rental Type
	        $cart_item_data['rental_type'] 	= $this->type;

	        $cart_item_data['duration_map'] = $duration_map;
            $cart_item_data['duration']     = $duration;
            $cart_item_data['distance']     = $distance;
            $cart_item_data['extra_time']   = $extra_time;

            // Pickup & Dropoff locations
	        $cart_item_data['ovabrw_pickup_loc'] 	= $pickup_location;
	        $cart_item_data['ovabrw_waypoints'] 	= $ovabrw_waypoints;
	        $cart_item_data['ovabrw_pickoff_loc'] 	= $dropoff_location;

	        // Pickup & Dropoff dates
	        $cart_item_data['ovabrw_pickup_date'] 	= $pickup_date;
	        $cart_item_data['ovabrw_pickoff_date'] 	= $dropoff_date;

	        // Real pickup & dropoff dates
	        $cart_item_data['ovabrw_pickup_date_real'] 	= $pickup_date;
	        $cart_item_data['ovabrw_pickoff_date_real'] = $dropoff_date;

	        // Validate
	        $cart_item_data['ovabrw_checkin'] 	= $new_date['pickup_date_new'];
	        $cart_item_data['ovabrw_checkout'] 	= $new_date['dropoff_date_new'] ? $new_date['dropoff_date_new'] : $new_date['pickup_date_new'];

	        // Quantity
	        $cart_item_data['ovabrw_number_vehicle'] = $input_qty;

	        // Vehicle ids
	        $vehicle_available = '';

	        if ( WC()->session->__isset( 'id_vehicle_available' ) ) {
	            $vehicle_available = WC()->session->get( 'id_vehicle_available' );
	            WC()->session->__unset( 'id_vehicle_available' );
	        }

        	$cart_item_data['id_vehicle'] = trim( $vehicle_available );

        	// Real Quantity and Price
        	$regular_price = floatval( $this->get_value( 'regul_price_taxi' ) );
        	$cart_item_data['real_quantity'] = $input_qty;
        	$cart_item_data['real_price'] = ovabrw_wc_price( OVABRW_Get_Data::instance()->get_price_include_tax( $this->ID, $regular_price ) );

	        // Custom Checkout Fields
	        $list_ckf = $this->get_custom_checkout_fields();
	        $args_ckf = $args_ckf_qty = [];

	        if ( $this->is_array_exists( $list_ckf ) ) {
	            foreach( $list_ckf as $key => $field ) {
	                if ( $field['enabled'] == 'on' ) {
	                    if ( $field['type'] === 'file' ) {
	                        $prefix = 'ovabrw_'.$key;

	                        if ( isset( $_REQUEST[$prefix] ) && is_array( $_REQUEST[$prefix] ) ) {
	                            $cart_item_data[$key] = '<a href="'.esc_url( $_REQUEST[$prefix]['url'] ).'" title="'.esc_attr( $_REQUEST[$prefix]['name'] ).'" target="_blank">'.esc_attr( $_REQUEST[$prefix]['name'] ).'</a>';
	                        } else {
	                            $cart_item_data[$key] = '';
	                        }
	                    } elseif ( $field['type'] === 'select' ) {
	                        $options_key = $options_text = array();

	                        $val_op = sanitize_text_field( filter_input( INPUT_POST, $key ) );
	                        $args_ckf[$key] = $val_op;

	                        if ( isset( $_REQUEST[$key.'_qty'] ) && ! empty( $_REQUEST[$key.'_qty'] ) ) {
	                            if ( isset( $_REQUEST[$key.'_qty'][$val_op] ) && absint( $_REQUEST[$key.'_qty'][$val_op] ) ) {
	                                $args_ckf_qty[$val_op] = absint( $_REQUEST[$key.'_qty'][$val_op] );
	                            }
	                        }
	                        
	                        if ( ovabrw_check_array( $field, 'ova_options_key' ) ) {
	                            $options_key = $field['ova_options_key'];
	                        }

	                        if ( ovabrw_check_array( $field, 'ova_options_text' ) ) {
	                            $options_text = $field['ova_options_text'];
	                        }

	                        $key_op = array_search( $val_op, $options_key );

	                        if ( ! is_bool( $key_op ) ) {
	                            if ( ovabrw_check_array( $options_text, $key_op ) ) {
	                                if ( isset( $args_ckf_qty[$val_op] ) && absint( $args_ckf_qty[$val_op] ) ) {
	                                    $val_op = $options_text[$key_op] . ' (x'.absint( $args_ckf_qty[$val_op] ).')';
	                                } else {
	                                    $val_op = $options_text[$key_op];
	                                }
	                            }
	                        }

	                        $cart_item_data[$key] = $val_op;
	                    } elseif ( $field['type'] === 'checkbox' ) {
	                        $checkbox_val = $checkbox_key = $checkbox_text = array();

	                        $val_checkbox = isset( $_REQUEST[$key] ) && $_REQUEST[$key] ? $_REQUEST[$key] : '';

	                        if ( ! empty( $val_checkbox ) && is_array( $val_checkbox ) ) {
	                            $args_ckf[$key] = $val_checkbox;

	                            if ( isset( $_REQUEST[$key.'_qty'] ) && ! empty( $_REQUEST[$key.'_qty'] && is_array( $_REQUEST[$key.'_qty'] ) ) ) {
	                                $args_ckf_qty = $args_ckf_qty + $_REQUEST[$key.'_qty'];
	                            }

	                            if ( ovabrw_check_array( $field, 'ova_checkbox_key' ) ) {
	                                $checkbox_key = $field['ova_checkbox_key'];
	                            }

	                            if ( ovabrw_check_array( $field, 'ova_checkbox_text' ) ) {
	                                $checkbox_text = $field['ova_checkbox_text'];
	                            }

	                            foreach ( $val_checkbox as $val_cb ) {
	                                $key_cb = array_search( $val_cb, $checkbox_key );

	                                if ( ! is_bool( $key_cb ) ) {
	                                    if ( ovabrw_check_array( $checkbox_text, $key_cb ) ) {
	                                        if ( isset( $args_ckf_qty[$val_cb] ) && absint( $args_ckf_qty[$val_cb] ) ) {
	                                            array_push( $checkbox_val , $checkbox_text[$key_cb] . ' (x'.absint( $args_ckf_qty[$val_cb] ).')' );
	                                        } else {
	                                            array_push( $checkbox_val , $checkbox_text[$key_cb] );
	                                        }
	                                    }
	                                }
	                            }
	                        }

	                        if ( ! empty( $checkbox_val ) && is_array( $checkbox_val ) ) {
	                            $cart_item_data[$key] = join( ", ", $checkbox_val );
	                        }
	                    } else {
	                        $cart_item_data[$key] = sanitize_text_field( filter_input( INPUT_POST, $key ) );

	                        if ( in_array( $field['type'], array( 'radio' ) ) ) {
	                            $args_ckf[$key] = sanitize_text_field( filter_input( INPUT_POST, $key ) );

	                            if ( $args_ckf[$key] && isset( $_REQUEST[$key.'_qty'] ) && ! empty( $_REQUEST[$key.'_qty'] ) ) {
	                                if ( isset( $_REQUEST[$key.'_qty'][$cart_item_data[$key]] ) && absint( $_REQUEST[$key.'_qty'][$cart_item_data[$key]] ) ) {
	                                    $args_ckf_qty[$key] = absint( $_REQUEST[$key.'_qty'][$cart_item_data[$key]] );
	                                    $cart_item_data[$key] .= ' (x'.absint( $_REQUEST[$key.'_qty'][$cart_item_data[$key]] ).')';
	                                }
	                            }
	                        }
	                    }
	                }
	            }
	        }

	        if ( $this->is_array_exists( $args_ckf ) ) {
	            $cart_item_data['custom_ckf']       = $args_ckf;
	            $cart_item_data['custom_ckf_qty']   = $args_ckf_qty;
	        }
	        // End

	        // Resources
	        $resources      = isset( $_REQUEST['ovabrw_resource_checkboxs'] ) ? $_REQUEST['ovabrw_resource_checkboxs'] : [];
	        $resources_qty  = isset( $_REQUEST['ovabrw_resource_quantity'] ) ? $_REQUEST['ovabrw_resource_quantity'] : [];

	        $cart_item_data['resources']        = $resources;
        	$cart_item_data['resources_qty']    = $resources_qty;
        	// End

        	// Services
        	$services       = isset( $_REQUEST['ovabrw_service'] ) ? $_REQUEST['ovabrw_service'] : [];
	        $ser_qty        = isset( $_REQUEST['ovabrw_service_qty'] ) ? $_REQUEST['ovabrw_service_qty'] : [];
	        $services_qty   = [];
	        $data_services 	= [];

	        if ( $this->is_array_exists( $services ) ) {
	            foreach ( $services as $ser_id ) {
	            	if ( $ser_id ) {
	            		$data_services[] = $ser_id;
	            	}

	                if ( isset( $ser_qty[$ser_id] ) && absint( $ser_qty[$ser_id] ) ) {
	                    $services_qty[$ser_id] = absint( $ser_qty[$ser_id] );
	                }
	            }
	        }

	        $cart_item_data['ovabrw_service']       = $data_services;
        	$cart_item_data['ovabrw_service_qty']   = $services_qty;
        	// End
        	
        	// Deposit
        	$type_deposit = isset( $_REQUEST['ova_type_deposit'] ) ? sanitize_text_field( $_REQUEST['ova_type_deposit'] ) : '';
        	$cart_item_data['ova_type_deposit'] = $type_deposit;

        	// Amount Insurance
        	$amount_insurance = $input_qty * floatval( $this->get_value( 'amount_insurance' ) );
        	$cart_item_data['ovabrw_amount_insurance'] = $amount_insurance;

			do_action( 'ovabrw_after_wc_add_cart_item_data', $cart_item_data, $product_id, $quantity, $this );

			return apply_filters( 'ovabrw_wc_add_cart_item_data', $cart_item_data, $product_id, $quantity, $this );
		}

		public function ovabrw_show_item_data( $item_data, $cart_item ) {
			do_action( 'ovabrw_before_show_item_data', $item_data, $cart_item, $this );

			if ( ! $cart_item['data']->is_type('ovabrw_car_rental') ) return $item_data;

			$product_id = isset( $cart_item['product_id'] ) ? $cart_item['product_id'] : '';
			if ( ! $product_id ) return $item_data;

			// Set Product ID
			$this->set_ID( $product_id );

			// Get Type
			$rental_type = $this->get_value( 'price_type' );

			// Check Type
			if ( $rental_type != $this->type ) return $item_data;
			
			if ( $this->is_array_exists( $item_data ) ) $item_data = [];

			$pickup_location 	= isset( $cart_item['ovabrw_pickup_loc'] ) ? $cart_item['ovabrw_pickup_loc'] : '';
			$dropoff_location 	= isset( $cart_item['ovabrw_pickoff_loc'] ) ? $cart_item['ovabrw_pickoff_loc'] : '';
			$pickup_date 		= isset( $cart_item['ovabrw_pickup_date'] ) ? $cart_item['ovabrw_pickup_date'] : '';
			$dropoff_date 		= isset( $cart_item['ovabrw_pickoff_date'] ) ? $cart_item['ovabrw_pickoff_date'] : '';
			$waypoints 			= isset( $cart_item['ovabrw_waypoints'] ) ? $cart_item['ovabrw_waypoints'] : [];

			if ( ! $pickup_date || ! $dropoff_date ) return $item_data;

			// Pickup Location
			if ( $this->show_location( 'pickup' ) ) {
				$item_data[] = array(
	                'key'     => esc_html__( 'Pick-up Location', 'ova-brw' ),
	                'value'   => wc_clean( $pickup_location ),
	                'display' => ''
	            );
			}

			// Waypoints
			if ( $this->is_array_exists( $waypoints ) ) {
				foreach ( $waypoints as $k => $address ) {
	                $item_data[] = array(
	                    'key'     => sprintf( esc_html__( 'Waypoint %s', 'ova_brw' ), $k + 1 ),
	                    'value'   => wc_clean( $address ),
	                    'display' => '',
	                );
	            }
			}

			// Dropoff Location
			if ( $this->show_location( 'dropoff' ) ) {
				$item_data[] = array(
	                'key'     => esc_html__( 'Drop-off Location', 'ova-brw' ),
	                'value'   => wc_clean( $dropoff_location ),
	                'display' => ''
	            );
			}

			// Pickup Date
			$item_data[] = array(
                'key'     => esc_html__( 'Pick-up Date', 'ova-brw' ),
                'value'   => wc_clean( $pickup_date ),
                'display' => ''
            );

			// Dropoff Date
            if ( $this->show_date( 'dropoff' ) ) {
            	$item_data[] = array(
                    'key'     => esc_html__( 'Drop-off Date', 'ova-brw' ),
                    'value'   => wc_clean( $dropoff_date ),
                    'display' => ''
                );
            }

            if ( isset( $cart_item['distance'] ) && $cart_item['distance'] ) {
	            $item_data[] = array(
	                'key'     => esc_html__( 'Distance', 'ova-brw' ),
	                'value'   => wc_clean( $this->get_distance_text( $cart_item['distance'] ) ),
	                'display' => '',
	            );
	        }

	        if ( isset( $cart_item['extra_time'] ) && $cart_item['extra_time'] ) {
	            $item_data[] = array(
	                'key'     => esc_html__( 'Extra Time', 'ova-brw' ),
	                'value'   => wc_clean( sprintf( esc_html__( '%s hour(s)', 'ova-brw' ), $cart_item['extra_time'] ) ),
	                'display' => '',
	            );
	        }

	        if ( isset( $cart_item['duration'] ) && $cart_item['duration'] ) {
	            $item_data[] = array(
	                'key'     => esc_html__( 'Duration', 'ova-brw' ),
	                'value'   => wc_clean( $this->get_duration_text( $cart_item['duration'] ) ),
	                'display' => '',
	            );
	        }

            // Quantity
            if ( $this->show_quantity() ) {
            	$quantity = isset( $cart_item['ovabrw_number_vehicle'] ) ? absint( $cart_item['ovabrw_number_vehicle'] ) : 1;

            	$item_data[] = array(
	                'key'     => esc_html__( 'Quantity', 'ova-brw' ),
	                'value'   => wc_clean( $quantity ),
	                'display' => ''
	            );
            }

            // Vehicle ID
            $vehicle_ids = isset( $cart_item['id_vehicle'] ) ? $cart_item['id_vehicle'] : '';

            if ( $vehicle_ids && apply_filters( 'brw_show_vehicle_order_frontend', false ) ) {
                $item_data[] = array(
                    'key'     => esc_html__( 'Vehicle ID', 'ova-brw' ),
                    'value'   => wc_clean( $vehicle_ids ),
                    'display' => ''
                );
            }

            // Custom Checkout Fields
            $list_fields = $this->get_custom_checkout_fields();

	        if ( is_array( $list_fields ) && ! empty( $list_fields ) ) {
	            foreach ( $list_fields as $key => $field ) {
	                $value = array_key_exists( $key, $cart_item ) ? $cart_item[$key] : '';

	                if ( ! empty( $value ) && $field['enabled'] == 'on' ) {
	                    if ( $field['type'] === 'file' ) {
	                        $item_data[] = array(
	                            'key'     => $field['label'],
	                            'value'   => $value,
	                            'display' => ''
	                        );
	                    } else {
	                        $item_data[] = array(
	                            'key'     => $field['label'],
	                            'value'   => wc_clean( $value ),
	                            'display' => ''
	                        );
	                    }
	                }
	            }
	        }

	        // Resources
	        if ( isset( $cart_item['resources'] ) && $cart_item['resources'] ) {
	            $resources_name = $cart_item['resources'];

	            if ( isset( $cart_item['resources_qty'] ) && $cart_item['resources_qty'] ) {
	                foreach ( $resources_name as $k => $v ) {
	                    if ( isset( $cart_item['resources_qty'][$k] ) && absint( $cart_item['resources_qty'][$k] ) ) {
	                        $resources_name[$k] = $v.' (x'.absint( $cart_item['resources_qty'][$k] ).')';
	                    }
	                }
	            }

	            if ( count( $cart_item['resources'] ) == 1 ) {
	                $item_data[] = array(
	                    'key'     => esc_html__( 'Resource', 'ova-brw' ),
	                    'value'   => wc_clean( join( ', ', $resources_name ) ),
	                    'display' => '',
	                );   
	            } else {
	                $item_data[] = array(
	                    'key'     => esc_html__( 'Resources', 'ova-brw' ),
	                    'value'   => wc_clean( join( ', ', $resources_name ) ),
	                    'display' => '',
	                );   
	            }
	        }

	        // Services
	        if ( isset( $cart_item['ovabrw_service'] ) && $cart_item['ovabrw_service'] ) {
	        	$services 		= $cart_item['ovabrw_service'];
	        	$services_qty 	= $cart_item['ovabrw_service_qty'];

	        	if ( $this->is_array_exists( $services ) ) {
	        		$serv_labels 	= $this->get_value( 'label_service', [] );
	        		$serv_ids 		= $this->get_value( 'service_id', [] );
	        		$serv_names 	= $this->get_value( 'service_name', [] );

	        		foreach ( $services as $k ) {
			    		if ( $this->is_array_exists( $serv_ids ) ) {
			    			$qty = isset( $services_qty[$k] ) ? $services_qty[$k] : '';

			    			foreach ( $serv_ids as $i => $ids ) {
			    				$option_index = array_search( $k, $ids );

			        			if ( is_bool( $option_index ) ) continue;

			        			$name   = isset( $serv_names[$i][$option_index] ) ? $serv_names[$i][$option_index] : '';
                                $label  = isset( $serv_labels[$i] ) ? $serv_labels[$i] : '';

                                if ( $qty ) {
                                    $name .= ' (x'.absint( $qty ).')';
                                }

                                $item_data[] = array(
                                    'key'     => $label,
                                    'value'   => wc_clean( $name ),
                                    'display' => '',
                                );
			    			}
			    		}
			    	}
	        	}
	        }

            // Insurance
            if ( isset( $cart_item['ovabrw_amount_insurance'] ) && $cart_item['ovabrw_amount_insurance'] ) {
            	$item_data[] = array(
	                'key'     => esc_html__( 'Amount Of Insurance', 'ova-brw' ),
	                'value'   => ovabrw_wc_price( $cart_item['ovabrw_amount_insurance'] ),
	                'display' => ''
	            );
            }

			do_action( 'ovabrw_after_show_item_data', $item_data, $cart_item, $this );

			return apply_filters( 'ovabrw_show_item_data', $item_data, $cart_item, $this );
		}

		public function ovabrw_cart_show_item_price( $product_price, $cart_item, $cart_item_key ) {
			do_action( 'ovabrw_before_cart_show_item_price', $product_price, $cart_item, $cart_item_key, $this );

			$rental_type = isset( $cart_item['rental_type'] ) ? $cart_item['rental_type'] : '';

			if ( $cart_item['data']->is_type('ovabrw_car_rental') && $this->type === $rental_type ) {
				if ( isset( $cart_item['real_price'] ) && $cart_item['real_price'] ) {
					$product_price = $cart_item['real_price'];
				} else {
					$product_price = '';
				}
			}

			do_action( 'ovabrw_after_cart_show_item_price', $product_price, $cart_item, $cart_item_key, $this );

			return apply_filters( 'ovabrw_cart_show_item_price', $product_price, $cart_item, $cart_item_key, $this );
		}

		public function ovabrw_cart_show_item_quantity( $product_quantity, $cart_item_key, $cart_item ) {
			do_action( 'ovabrw_before_cart_show_item_quantity', $product_quantity, $cart_item_key, $cart_item, $this );

			$rental_type = isset( $cart_item['rental_type'] ) ? $cart_item['rental_type'] : '';

			if ( $cart_item['data']->is_type('ovabrw_car_rental') && $this->type === $rental_type ) {
				if ( isset( $cart_item['real_quantity'] ) && $cart_item['real_quantity'] ) {
					$product_quantity = $cart_item['real_quantity'];
				} else {
					$product_quantity = '';
				}
			}

			do_action( 'ovabrw_after_cart_show_item_quantity', $product_quantity, $cart_item_key, $cart_item, $this );

			return apply_filters( 'ovabrw_cart_show_item_quantity', $product_quantity, $cart_item_key, $cart_item, $this );
		}

		public function ovabrw_cart_show_item_subtotal( $item_subtotal, $cart_item, $cart_item_key ) {
			do_action( 'ovabrw_before_cart_show_item_subtotal', $item_subtotal, $cart_item, $cart_item_key, $this );

			$rental_type = isset( $cart_item['rental_type'] ) ? $cart_item['rental_type'] : '';

			if ( $cart_item['data']->is_type('ovabrw_car_rental') && $this->type === $rental_type ) {
				$item_subtotal = $this->get_html_subtotal_from_cart( $item_subtotal, $cart_item, $cart_item_key );
			}

			do_action( 'ovabrw_after_cart_show_item_subtotal', $item_subtotal, $cart_item, $cart_item_key, $this );

			return apply_filters( 'ovabrw_cart_show_item_subtotal', $item_subtotal, $cart_item, $cart_item_key, $this );
		}

		public function ovabrw_checkout_show_item_quantity( $product_quantity, $cart_item, $cart_item_key ) {
			do_action( 'ovabrw_before_checkout_show_item_quantity', $product_quantity, $cart_item, $cart_item_key, $this );

			$rental_type = isset( $cart_item['rental_type'] ) ? $cart_item['rental_type'] : '';

			if ( $cart_item['data']->is_type('ovabrw_car_rental') && $this->type === $rental_type ) {
				if ( isset( $cart_item['real_quantity'] ) && $cart_item['real_quantity'] ) {
					$product_quantity = ' <strong class="product-quantity">' . sprintf( '&times;&nbsp;%s', $cart_item['real_quantity'] ) . '</strong>';
				} else {
					$product_quantity = '';
				}
			}

			do_action( 'ovabrw_after_checkout_show_item_quantity', $product_quantity, $cart_item, $cart_item_key, $this );

			return apply_filters( 'ovabrw_checkout_show_item_quantity', $product_quantity, $cart_item, $cart_item_key, $this );
		}

		public function ovabrw_order_item_quantity_html( $item_quantity, $item ) {
			do_action( 'ovabrw_before_order_item_quantity_html', $item_quantity, $item, $this );

			$rental_type = $item->get_meta( 'rental_type' );

			if ( $this->type === $rental_type ) {
				$total_days = $item->get_meta( 'ovabrw_total_days' );

				if ( ! $total_days ) return '';

				$item_quantity = ' <strong class="product-quantity">' . sprintf( '&times;&nbsp;%s', $total_days ) . '</strong>';
			}

			do_action( 'ovabrw_after_order_item_quantity_html', $item_quantity, $item, $this );

			return apply_filters( 'ovabrw_order_item_quantity_html', $item_quantity, $item, $this );
		}

		public function ovabrw_order_show_subtotal( $subtotal, $item, $order ) {
			do_action( 'ovabrw_before_order_show_subtotal', $subtotal, $item, $order, $this );

			$pay_total_html = $extra_html = '';
			$rental_type 	= $item->get_meta( 'rental_type' );

			if ( $this->type === $rental_type ) {
				$subtotal = $this->get_html_subtotal_from_order_detail( $subtotal, $item, $order );
			}

			do_action( 'ovabrw_after_order_show_subtotal', $subtotal, $item, $order, $this );

			return apply_filters( 'ovabrw_order_show_subtotal', $subtotal, $item, $order, $this );
		}

		public function ovabrw_get_product_price_html( $price_html, $product ) {
			do_action( 'ovabrw_before_get_product_price_html', $price_html, $product, $this );

			if ( $product && $product->is_type('ovabrw_car_rental') ) {
				$rental_type = $this->get_value_by_id( $product->get_id(), 'price_type' );

				if ( $this->type === $rental_type ) {
					$price 		= floatval( $this->get_value_by_id( $product->get_id(), 'regul_price_taxi' ) );
					$price_by 	= $this->get_value_by_id( $product->get_id(), 'map_price_by' );

					if ( $price_by === 'km' ) {
						$price_html = sprintf( esc_html__( '%s / Km', 'ova-brw' ), wc_price( $price ) );
					} elseif ( $price_by === 'mi' ) {
						$price_html = sprintf( esc_html__( '%s / Mi', 'ova-brw' ), wc_price( $price ) );
					}
				}
			}

			do_action( 'ovabrw_after_get_product_price_html', $price_html, $product, $this );

			return apply_filters( 'ovabrw_get_product_price_html', $price_html, $product, $this );
		}

		// Ajax validation data booking
		public function ovabrw_ajax_validation_booking( $pickup_date = '', $dropoff_date = '', $args = [] ) {
			do_action( 'ovabrw_before_ajax_validation_booking', $pickup_date, $dropoff_date, $args, $this );

			if ( ! $pickup_date ) {
				return esc_html__( 'Pick-up date is required', 'ova-brw' );
			}

			if ( ! $dropoff_date ) {
				return esc_html__( 'Drop-off date is required', 'ova-brw' );
			}

			if ( $pickup_date < current_time('timestamp') ) {
	            return esc_html__( 'Pick-up Date must be greater than Current Time', 'ova-brw' );   
	        }

            if ( $pickup_date > $dropoff_date ) {
            	return esc_html__( 'Drop-off date must be greater than Pick-up date', 'ova-brw' );
            }

            // Perparation Time
	        $preparation_time = $this->get_value( 'preparation_time' );

	        if ( $preparation_time ) {
	            $today = strtotime( date( 'Y-m-d', current_time( 'timestamp' ) ) );

	            if ( $pickup_date < ( $today + $preparation_time*86400 ) ) {
	                if ( absint( $preparation_time ) === 1 ) {
	                    return sprintf( esc_html__( 'Book in advance %s day from the current date', 'ova-brw' ), $preparation_time );
	                } else {
	                    return sprintf( esc_html__( 'Book in advance %s days from the current date', 'ova-brw' ), $preparation_time );
	                }
	            }
	        }
            
            // Check unavailable time
            $untime_startdate = $this->get_value( 'untime_startdate' );
        	$untime_enddate   = $this->get_value( 'untime_enddate' );

        	if ( $this->is_array_exists( $untime_startdate ) && $this->is_array_exists( $untime_enddate ) ) {
        		foreach ( $untime_startdate as $k => $start_date ) {
        			$start_date = strtotime( $start_date );
        			$end_date 	= isset( $untime_enddate[$k] ) ? strtotime( $untime_enddate[$k] ) : '';

        			if ( ! ( $start_date > $dropoff_date || $end_date < $pickup_date ) ) {
        				return esc_html__( 'This time is not available for renting', 'ova-brw' );
        			}
        		}
        	}

        	// Check disable week day
        	$disable_week_day = $this->get_value( 'product_disable_week_day' );

	        if ( ! $disable_week_day ) {
	            $disable_week_day = get_option( 'ova_brw_calendar_disable_week_day', '' );
	        }

	        $disable_week_day = $disable_week_day != '' ? explode( ',', $disable_week_day ) : [];
	        $disable_week_day = array_map( 'trim', $disable_week_day );

	        if ( $this->is_array_exists( $disable_week_day ) ) {
	        	if ( ovabrw_allow_boooking_incl_disable_week_day() ) {
	                $pickup_date_of_week    = date('w', $pickup_date );
	                $dropoff_date_of_week   = date('w', $dropoff_date );

	                if ( in_array( $pickup_date_of_week, $disable_week_day ) || in_array( $dropoff_date_of_week, $disable_week_day ) ) {
	                    return esc_html__( 'This time is not available for renting', 'ova-brw' );
	                }
	            } else {
	                $datediff       = (int)$dropoff_date - (int)$pickup_date;
	                $total_datediff = round( $datediff / (60 * 60 * 24), wc_get_price_decimals() ) + 1;

	                // get number day
	                $pickup_date_of_week   = date('w', $pickup_date );
	                $pickup_date_timestamp = $pickup_date;
	                
	                $i = 0;
	                while ( $i <= $total_datediff ) {
	                    if ( in_array( $pickup_date_of_week, $disable_week_day ) ) {
	                        return esc_html__( 'This time is not available for renting', 'ova-brw' );
	                    }

	                    $pickup_date_of_week    = date('w', $pickup_date_timestamp );
	                    $pickup_date_timestamp  = strtotime('+1 day', $pickup_date_timestamp);
	                    $i++;
	                }
	            }
	        }

	        do_action( 'ovabrw_after_ajax_validation_booking', $pickup_date, $dropoff_date, $args, $this );

			return false;
		}
		// End

		public function ovabrw_save_order_line_item( $item, $values ) {
			do_action( 'ovabrw_before_save_order_line_item', $item, $values, $this );

			// Rental Type
	        $item->add_meta_data( 'rental_type', $values['rental_type'] );

			// Pickup location
            if ( $this->show_location( 'pickup' ) ) {
            	$item->add_meta_data( 'ovabrw_pickup_loc', $values['ovabrw_pickup_loc'] );
            }

            // Waypoints
            if ( $this->is_array_exists( $values['ovabrw_waypoints'] ) ) {
	            foreach ( $values['ovabrw_waypoints'] as $k => $address ) {
	                $item->add_meta_data( sprintf( esc_html__( 'Waypoint %s', 'ova_brw' ), $k + 1 ), $address );
	            }
	        }

            // Dropoff location
            if ( $this->show_location( 'dropoff' ) ) {
            	$item->add_meta_data( 'ovabrw_pickoff_loc', $values['ovabrw_pickoff_loc'] );
            }

            // Pickup date
            $item->add_meta_data( 'ovabrw_pickup_date', $values['ovabrw_pickup_date'] );

            // Dropoff date
        	$item->add_meta_data( 'ovabrw_pickoff_date', $values['ovabrw_pickoff_date'] );

        	// Pickup date real
        	$item->add_meta_data( 'ovabrw_pickup_date_real', $values['ovabrw_pickup_date_real'] );

        	// Dropoff date real
        	$item->add_meta_data( 'ovabrw_pickoff_date_real', $values['ovabrw_pickoff_date_real'] );

        	// Quantity
        	if ( $this->show_quantity() ) {
	            $item->add_meta_data( 'ovabrw_number_vehicle', $values['ovabrw_number_vehicle'] );
	        } else {
	            $item->add_meta_data( 'ovabrw_number_vehicle', 1 );
	        }

	        // Vehicle ids
	        if ( $values['id_vehicle'] ) {
	        	$item->add_meta_data( 'id_vehicle', $values['id_vehicle'] );
	        }

	        // Distance
	        if ( isset( $values['distance'] ) && $values['distance'] ) {
                $item->add_meta_data( 'ovabrw_distance', $this->get_distance_text( $values['distance'] ) );
            }

            // Extra Time
            if ( isset( $values['extra_time'] ) && $values['extra_time'] ) {
                $item->add_meta_data( 'ovabrw_extra_time', sprintf( esc_html__( '%s hour(s)', 'ova-brw' ), $values['extra_time'] ) );
            }

            // Duration
            if ( isset( $values['duration'] ) && $values['duration'] ) {
                $item->add_meta_data( 'ovabrw_duration', $this->get_duration_text( $values['duration'] ) );
            }

	        // Custom Checkout Fields
	        $list_fields = $this->get_custom_checkout_fields();

	        if ( is_array( $list_fields ) && ! empty( $list_fields ) ) {
	            foreach( $list_fields as $key => $field ) {
	                $value = array_key_exists( $key, $values ) ? $values[$key] : '';

	                if ( ! empty( $value ) && $field['enabled'] == 'on' ) {
	                    if ( 'select' === $field['type'] ) {
	                        $options_key = $options_text = array();

	                        if ( ovabrw_check_array( $field, 'ova_options_key' ) ) {
	                            $options_key = $field['ova_options_key'];
	                        }

	                        if ( ovabrw_check_array( $field, 'ova_options_text' ) ) {
	                            $options_text = $field['ova_options_text'];
	                        }

	                        $key_op = array_search( $value, $options_key );

	                        if ( ! is_bool( $key_op ) ) {
	                            if ( ovabrw_check_array( $options_text, $key_op ) ) {
	                                $value = $options_text[$key_op];
	                            }
	                        }
	                    }

	                    $item->add_meta_data( $key, $value );
	                }
	            }
	        }

	        if ( isset( $values['custom_ckf'] ) && $values['custom_ckf'] ) {
	            $item->add_meta_data( 'ovabrw_custom_ckf', $values['custom_ckf'] );
	        }

	        if ( isset( $values['custom_ckf_qty'] ) && $values['custom_ckf_qty'] ) {
	            $item->add_meta_data( 'ovabrw_custom_ckf_qty', $values['custom_ckf_qty'] );
	        }

	        // Resources
	        if ( $this->is_array_exists( $values['resources'] ) ) {
	            $resources_name = $values['resources'];

	            if ( isset( $values['resources_qty'] ) && $values['resources_qty'] ) {
	                foreach ( $resources_name as $k => $v ) {
	                    if ( isset( $values['resources_qty'][$k] ) && absint( $values['resources_qty'][$k] ) ) {
	                        $resources_name[$k] = $v.' (x'.absint( $values['resources_qty'][$k] ).')';
	                    }
	                }
	            }

	            if ( count( $values['resources'] ) == 1 ) {
	                $item->add_meta_data( esc_html__( 'Resource', 'ova-brw' ), join( ', ', $resources_name ) );
	            } else {
	                $item->add_meta_data( esc_html__( 'Resources', 'ova-brw' ), join( ', ', $resources_name ) );
	            }

	            $item->add_meta_data( 'ovabrw_resources', $values['resources'] );
	            $item->add_meta_data( 'ovabrw_resources_qty', $values['resources_qty'] );
	        }

	        // Services
	        if ( $this->is_array_exists( $values['ovabrw_service'] ) ) {
	        	$services 		= $values['ovabrw_service'];
	        	$services_qty 	= $values['ovabrw_service_qty'];

	        	$item->add_meta_data( 'ovabrw_services', $services );
                $item->add_meta_data( 'ovabrw_services_qty', $services_qty );

	        	if ( $this->is_array_exists( $services ) ) {
	        		$serv_labels 	= $this->get_value( 'label_service', [] );
	        		$serv_ids 		= $this->get_value( 'service_id', [] );
	        		$serv_names 	= $this->get_value( 'service_name', [] );

	        		foreach ( $services as $k ) {
			    		if ( $this->is_array_exists( $serv_ids ) ) {
			    			$qty = isset( $services_qty[$k] ) ? $services_qty[$k] : '';

			    			foreach ( $serv_ids as $i => $ids ) {
			    				$option_index = array_search( $k, $ids );

			        			if ( is_bool( $option_index ) ) continue;

			        			$name   = isset( $serv_names[$i][$option_index] ) ? $serv_names[$i][$option_index] : '';
                                $label  = isset( $serv_labels[$i] ) ? $serv_labels[$i] : '';

                                if ( $qty ) {
                                    $name .= ' (x'.absint( $qty ).')';
                                }

                                $item->add_meta_data( $label, $name );
			    			}
			    		}
			    	}
	        	}
	        }

	        // Deposit
	        if ( isset( $values['ova_type_deposit'] ) && $values['ova_type_deposit'] === 'deposit' ) {
	        	$deposit_amount 	= $values['data']->get_meta('ovabrw_deposit_amount');
				$remaining_amount 	= $values['data']->get_meta('ovabrw_remaining_amount');

				$item->add_meta_data( 'ovabrw_deposit_amount_product', ovabrw_convert_price( $deposit_amount ) );
	        	$item->add_meta_data( 'ovabrw_remaining_amount_product', ovabrw_convert_price( $remaining_amount ) );
	            $item->add_meta_data( 'ovabrw_deposit_full_amount', ovabrw_convert_price( $deposit_amount + $remaining_amount ) );
	        }

	        // Insurance Amount
	        if ( isset( $values['ovabrw_amount_insurance'] ) ) {
	            $item->add_meta_data( 'ovabrw_amount_insurance_product', ovabrw_convert_price( $values['ovabrw_amount_insurance'] ) );
	        }

	        do_action( 'ovabrw_after_save_order_line_item', $item, $values, $this );
		}

		public function get_total( $cart_item = [] ) {
			do_action( 'ovabrw_before_get_total', $cart_item, $this );

			$pickup_date 	= isset( $cart_item['ovabrw_checkin'] ) ? $cart_item['ovabrw_checkin'] : '';
			$dropoff_date 	= isset( $cart_item['ovabrw_checkout'] ) ? $cart_item['ovabrw_checkout'] : '';

			if ( ! $this->ID ) return 0;

			$total = 0;

			$regular_price  = floatval( $this->get_value( 'regul_price_taxi' ) );
			$price_by       = $this->get_value( 'map_price_by', 'km' );
            $distance       = isset( $cart_item['distance'] ) ? floatval( $cart_item['distance'] ) : 0;

            if ( $distance ) {
                if ( $price_by === 'km' ) {
                    $distance = apply_filters( 'ovabrw_ft_distance', round( $distance / 1000, 2 ), $this->ID );
                } else {
                    $distance = apply_filters( 'ovabrw_ft_distance', round( $distance / 1609.34, 2 ), $this->ID );
                }
            }

            // Subtotal
            $subtotal = $regular_price * $distance;

            // Get discount
            $subtotal = $this->get_discount_price( $distance, $subtotal );

            // Special Date
            $total = $this->get_special_price( $distance, $subtotal, $pickup_date );

            // Extra time
            if ( isset( $cart_item['extra_time'] ) && $cart_item['extra_time'] ) {
                $extra_time_hour    = $this->get_value( 'extra_time_hour', [] );
                $extra_time_price   = $this->get_value( 'extra_time_price', [] );

                if ( ! empty( $extra_time_hour ) && is_array( $extra_time_hour ) ) {
                    foreach ( $extra_time_hour as $k => $val ) {
                        $extt_price = isset( $extra_time_price[$k] ) ? floatval( $extra_time_price[$k] ) : 0;

                        if ( $val == $cart_item['extra_time'] ) {
                            $total += $extt_price;
                            break;
                        }
                    }
                }
            }

			// Insurance
			$insurance 	= isset( $cart_item[$this->get_name('amount_insurance')] ) ? floatval( $cart_item[$this->get_name('amount_insurance')] ) : 0;
			$total 		+= $insurance;

			// Resource Prices
			$resources      	= isset( $cart_item['resources'] ) ? $cart_item['resources'] : [];
        	$resources_qty  	= isset( $cart_item['resources_qty'] ) ? $cart_item['resources_qty'] : [];
			$resource_prices 	= $this->get_resource_prices( $pickup_date, $dropoff_date, $resources, $resources_qty );
			$total 				+= $resource_prices;

			// Service Prices
			$services 		= isset( $cart_item['ovabrw_service'] ) ? $cart_item['ovabrw_service'] : [];
        	$services_qty   = isset( $cart_item['ovabrw_service_qty'] ) ? $cart_item['ovabrw_service_qty'] : [];
        	$service_prices = $this->get_service_prices( $pickup_date, $dropoff_date, $services, $services_qty );
        	$total 			+= $service_prices;

        	// Custom Checkout Fields
        	$custom_ckf 	= isset( $cart_item['custom_ckf'] ) ? $cart_item['custom_ckf'] : [];
        	$custom_ckf_qty = isset( $cart_item['custom_ckf_qty'] ) ? $cart_item['custom_ckf_qty'] : [];
        	$ckf_prices 	= $this->get_ckf_prices( $custom_ckf, $custom_ckf_qty );
        	$total 			+= $ckf_prices;

        	// Quantity
        	$quantity 	= isset( $cart_item['ovabrw_number_vehicle'] ) ? absint( $cart_item['ovabrw_number_vehicle'] ) : 1;
			$total 		*= $quantity;

			do_action( 'ovabrw_after_get_total', $cart_item, $this );

			return apply_filters( 'ovabrw_get_total', $total, $cart_item, $this );
		}

		public function get_discount_price( $distance = 0, $subtotal = 0 ) {
			do_action( 'ovabrw_before_get_discount_price', $distance, $subtotal, $this );

			if ( ! $distance ) return $subtotal;

			$regular_price 	= floatval( $this->get_value( 'regul_price_taxi' ) );
			$distance_price = $this->get_value( 'discount_distance_price' );

	        if ( $this->is_array_exists( $distance_price ) ) {
	            $distance_from  = $this->get_value( 'discount_distance_from', [] );
	            $distance_to    = $this->get_value( 'discount_distance_to', [] );

	            $total_discount     = 0;
	            $remaining_distance = $distance;

	            foreach ( $distance_price as $k => $price ) {
	                $from   = isset( $distance_from[$k] ) ? $distance_from[$k] : '';
	                $to     = isset( $distance_to[$k] ) ? $distance_to[$k] : '';

	                $distance_discount = 0;

	                if ( $from != '' && $to != '' && $from <= $to ) {
	                    if ( $from < $distance && $to <= $distance ) {
	                        $distance_discount  = $to - $from;
	                        $total_discount     += floatval( $price ) * floatval( $distance_discount );
	                        $remaining_distance -= $distance_discount;
	                    } else if ( $from < $distance && $to >= $distance ) {
	                        $distance_discount  = $distance - $from;
	                        $total_discount     += floatval( $price ) * floatval( $distance_discount );
	                        $remaining_distance -= $distance_discount;
	                    } else {
	                        continue;
	                    }
	                }
	            }

	            $subtotal = $regular_price * floatval( $remaining_distance ) + $total_discount;
	        }

	        do_action( 'ovabrw_after_get_discount_price', $distance, $subtotal, $this );

			return apply_filters( 'ovabrw_get_discount_price', floatval( $subtotal ), $distance, $subtotal, $this );
		}

		public function get_special_price( $distance = 0, $subtotal = 0, $pickup_date = 0 ) {
			do_action( 'ovabrw_before_get_special_price', $distance, $subtotal, $pickup_date, $this );

			if ( ! $distance || ! $pickup_date ) return $subtotal;

			$pickup_st = $this->get_value( 'st_pickup_distance' );

	        if ( $this->is_array_exists( $pickup_st ) ) {
	            $dropoff_st     = $this->get_value( 'st_pickoff_distance', [] );
	            $price_st       = $this->get_value( 'st_price_distance', [] );
	            $discount_st    = $this->get_value( 'st_discount_distance' );

	            foreach ( $pickup_st as $k => $pickup ) {
	                $dropoff    = isset( $dropoff_st[$k] ) ? $dropoff_st[$k] : '';
	                $price      = isset( $price_st[$k] ) ? $price_st[$k] : '';
	                $dsc_from   = isset( $discount_st[$k]['from'] ) ? $discount_st[$k]['from'] : '';
	                $dsc_to     = isset( $discount_st[$k]['to'] ) ? $discount_st[$k]['to'] : '';
	                $dsc_price  = isset( $discount_st[$k]['price'] ) ? $discount_st[$k]['price'] : '';

	                if ( strtotime( $pickup ) && strtotime( $dropoff ) ) {
	                    if ( strtotime( $pickup ) <= $pickup_date && $pickup_date <= strtotime( $dropoff ) ) {
	                        $subtotal = floatval( $price ) * floatval( $distance );

	                        if ( ! empty( $dsc_from ) && is_array( $dsc_from ) ) {
	                            $total_discount     = 0;
	                            $remaining_distance = $distance;

	                            foreach ( $dsc_from as $k_dsc => $from ) {
	                                $to         = isset( $dsc_to[$k_dsc] ) ? $dsc_to[$k_dsc] : '';
	                                $disc_price = isset( $dsc_price[$k_dsc] ) ? $dsc_price[$k_dsc] : '';

	                                $distance_discount = 0;

	                                if ( $from != '' && $to != '' && $from <= $to ) {
	                                    if ( $from < $distance && $to <= $distance ) {
	                                        $distance_discount  = $to - $from;
	                                        $total_discount     += floatval( $disc_price ) * floatval( $distance_discount );
	                                        $remaining_distance -= $distance_discount;
	                                    } else if ( $from < $distance && $to >= $distance ) {
	                                        $distance_discount  = $distance - $from;
	                                        $total_discount     += floatval( $disc_price ) * floatval( $distance_discount );
	                                        $remaining_distance -= $distance_discount;
	                                    } else {
	                                        continue;
	                                    }
	                                }
	                            }

	                            $subtotal = floatval( $price ) * floatval( $remaining_distance ) + $total_discount;
	                        }
	                    }
	                }
	            }
	        }

	        do_action( 'ovabrw_after_get_special_price', $distance, $subtotal, $pickup_date, $this );

	        return apply_filters( 'ovabrw_get_special_price', floatval( $subtotal ), $distance, $pickup_date, $this );
		}

		public function get_strtotime_input_date( $pickup_date = '', $pickup_time = '', $duration = 0 ) {
			do_action( 'ovabrw_before_get_strtotime_input_date', $pickup_date, $pickup_time, $duration, $this );

			$new_date = [
				'pickup_date_new' 	=> '',
				'dropoff_date_new' 	=> ''
			];

			if ( ! $pickup_date ) return $new_date;

			if ( $pickup_time ) $pickup_date .= ' ' . $pickup_time;
			if ( ! $duration ) $duration = 0;

			if ( strtotime( $pickup_date ) ) {
				$new_date = [
					'pickup_date_new' 	=> strtotime( $pickup_date ),
					'dropoff_date_new' 	=> strtotime( $pickup_date ) + $duration
				];
			}

			do_action( 'ovabrw_after_get_strtotime_input_date', $pickup_date, $pickup_time, $duration, $this );

			return apply_filters( 'ovabrw_get_strtotime_input_date', $new_date, $pickup_date, $pickup_time, $duration, $this );
		}

		public function get_distance_text( $distance = 0 ) {
			do_action( 'ovabrw_before_get_distance_text', $distance, $this );

			$price_by = $this->get_value( 'map_price_by' );

			if ( ! $price_by ) $price_by = 'km';

	        if ( $distance ) {
	        	if ( $price_by === 'km' ) {
	        		$distance = apply_filters( 'ovabrw_ft_distance_text', round( $distance / 1000, 2 ), $this->ID );
	        	} else {
	        		$distance = apply_filters( 'ovabrw_ft_distance_text', round( $distance / 1609.34, 2 ), $this->ID );
	        	}
	        } else {
	            $distance = 0;
	        }

	        do_action( 'ovabrw_before_get_distance_text', $distance, $this );

	        return apply_filters( 'ovabrw_get_distance_text', sprintf( esc_html__( '%s %s', 'ova-brw' ), $distance, $price_by ), $distance, $this );
		}

		public function get_duration_text( $duration = 0 ) {
			do_action( 'ovabrw_before_get_duration_text', $duration, $this );

			$hour = $minute = 0;

	        if ( $duration ) {
	            $hour 	= absint( $duration / 3600 );
	            $minute = round( ( $duration % 3600 ) / 60 );
	        }

	        do_action( 'ovabrw_after_get_duration_text', $duration, $this );

	        return apply_filters( 'ovabrw_get_duration_text', sprintf( esc_html__( '%sh%sm', 'ova-brw' ), $hour, $minute ), $duration, $this );
		}

		public function get_html_price( $product_id = null ) {
			if ( ! $this->ID ) $this->ID = $product_id;

			$price 		= $this->get_value( 'regul_price_taxi' );
			$price_by 	= $this->get_value( 'map_price_by' );

			if ( ! $price_by ) $price_by = 'km';

			$unit = esc_html__( '/km', 'ova-brw' );

			if ( $price_by === 'mi' ) $unit = esc_html__( '/mi', 'ova-brw' );
		?>
			<span class="amount"><?php echo ovabrw_wc_price( $price, [], false ); ?></span>
			<span class="unit"><?php echo esc_html( $unit ); ?></span>
		<?php
		}

		// Request Booking
		public function request_booking_get_mail_body( $data = [] ) {
			do_action( 'ovabrw_before_request_booking_get_mail_body', $data, $this );

			if ( ! $this->is_array_exists( $data ) ) return false;

			// Get Data
			$product_name 		= isset( $data['product_name'] ) ? $data['product_name'] : '';
			$customer_name 		= isset( $data['name'] ) ? $data['name'] : '';
			$customer_email 	= isset( $data['email'] ) ? $data['email'] : '';
			$customer_phone 	= isset( $data['number'] ) ? $data['number'] : '';
			$customer_address 	= isset( $data['address'] ) ? $data['address'] : '';
			$customer_note 		= isset( $data['extra'] ) ? $data['extra'] : '';
			$pickup_date    	= isset( $data['pickup_date'] ) ? sanitize_text_field( $data['pickup_date'] ) : '';
            $pickup_time    	= isset( $data['pickup_time'] ) ? sanitize_text_field( $data['pickup_time'] ) : '';
			$pickup_location 	= isset( $data['ovabrw_req_pickup_loc'] ) ? trim( sanitize_text_field( $data['ovabrw_req_pickup_loc'] ) ) : '';
			$dropoff_location 	= isset( $data['ovabrw_req_pickoff_loc'] ) ? trim( sanitize_text_field( $data['ovabrw_req_pickoff_loc'] ) ) : '';
			$waypoints   		= isset( $data['ovabrw_req_waypoint_address'] ) ? $data['ovabrw_req_waypoint_address'] : [];
			$duration_map       = isset( $data['ovabrw-req-duration-map'] ) ? sanitize_text_field( $data['ovabrw-req-duration-map'] ) : '';
            $duration       	= isset( $data['ovabrw-req-duration'] ) ? sanitize_text_field( $data['ovabrw-req-duration'] ) : '';
            $distance       	= isset( $data['ovabrw-req-distance'] ) ? sanitize_text_field( $data['ovabrw-req-distance'] ) : '';
            $extra_time     	= isset( $data['ovabrw_req_extra_time'] ) ? sanitize_text_field( $data['ovabrw_req_extra_time'] ) : '';
			$qty_input 			= isset( $data['ovabrw_number_vehicle'] ) ? absint( $data['ovabrw_number_vehicle'] ) : '';

			if ( ! $qty_input ) $qty_input = 1;

			// Get strtotime input date
	        $new_date 		= $this->get_strtotime_input_date( $pickup_date, $pickup_time, $duration );
	        $pickup_date 	= $new_date['pickup_date_new'];
	        $dropoff_date 	= $new_date['dropoff_date_new'] ? $new_date['dropoff_date_new'] : $pickup_date;

	        $datetime_format = ovabrw_get_date_format() . ' ' . ovabrw_get_time_format_php();

	        $pickup_date 	= date( $datetime_format, $pickup_date );
	        $dropoff_date 	= date( $datetime_format, $dropoff_date );

	        // Get Order Detail
	        $order_detail = '<h2>'. esc_html__( 'Order details: ', 'ova-brw' ) . '</h2>';
        	$order_detail .= '<table>';

    		// Product
    		if ( $this->ID ) {
    			$order_detail .= '<tr>';
        			$order_detail .= '<td style="width: 15%">'.esc_html__( 'Product: ', 'ova-brw' ).'</td>';
        			$order_detail .= '<td style="width: 85%">';
        				$order_detail .= '<a href="'.get_permalink( $this->ID ).'">'.$product_name.'</a>';
        			$order_detail .= '</td>';
        		$order_detail .= '</tr>';
    		}

    		// Customer name
    		if ( $customer_name ) {
    			$order_detail .= '<tr>';
    				$order_detail .= '<td>'.esc_html__( 'Name: ', 'ova-brw' ).'</td>';
    				$order_detail .= '<td>'.$customer_name.'</td>';
    			$order_detail .= '</tr>';
    		}

    		// Customer email
    		if ( $customer_email ) {
    			$order_detail .= '<tr>';
    				$order_detail .= '<td>'.esc_html__( 'Email: ', 'ova-brw' ).'</td>';
    				$order_detail .= '<td>'.$customer_email.'</td>';
    			$order_detail .= '</tr>';
    		}

    		// Customer phone
    		if ( get_option( 'ova_brw_request_booking_form_show_number', 'yes' ) === 'yes' && $customer_phone ) {
    			$order_detail .= '<tr>';
    				$order_detail .= '<td>'.esc_html__( 'Phone: ', 'ova-brw' ).'</td>';
    				$order_detail .= '<td>'.$customer_phone.'</td>';
    			$order_detail .= '</tr>';
    		}

    		// Customer address
    		if ( get_option( 'ova_brw_request_booking_form_show_address', 'yes' ) === 'yes' && $customer_address ) {
    			$order_detail .= '<tr>';
    				$order_detail .= '<td>'.esc_html__( 'Address: ', 'ova-brw' ).'</td>';
    				$order_detail .= '<td>'.$customer_address.'</td>';
    			$order_detail .= '</tr>';
    		}

    		// Pickup location
    		if ( get_option( 'ova_brw_request_booking_form_show_pickup_location', 'yes' ) === 'yes' && $pickup_location ) {
    			$order_detail .= '<tr>';
    				$order_detail .= '<td>'.esc_html__( 'Pick-up Location: ', 'ova-brw' ).'</td>';
    				$order_detail .= '<td>'.$pickup_location.'</td>';
    			$order_detail .= '</tr>';
    		}

    		// Waypoints
    		if ( $this->is_array_exists( $waypoints ) ) {
                foreach ( $waypoints as $k => $address ) {
                	$order_detail .= '<tr>';
	    				$order_detail .= '<td>'.sprintf( esc_html__( 'Waypoint %s', 'ova_brw' ), $k + 1 ).'</td>';
	    				$order_detail .= '<td>'.$address.'</td>';
	    			$order_detail .= '</tr>';
	            }
    		}

    		// Dropoff location
    		if ( get_option( 'ova_brw_request_booking_form_show_pickoff_location', 'yes' ) === 'yes' && $dropoff_location ) {
    			$order_detail .= '<tr>';
    				$order_detail .= '<td>'.esc_html__( 'Drop-off Location: ', 'ova-brw' ).'</td>';
    				$order_detail .= '<td>'.$dropoff_location.'</td>';
    			$order_detail .= '</tr>';
    		}

    		// Pickup date
    		if ( get_option( 'ova_brw_request_booking_form_show_pickup_date', 'yes' ) === 'yes' && $pickup_date ) {
    			$order_detail .= '<tr>';
    				$order_detail .= '<td>'.esc_html__( 'Pick-up Date: ', 'ova-brw' ).'</td>';
    				$order_detail .= '<td>'.$pickup_date.'</td>';
    			$order_detail .= '</tr>';
    		}

    		// Dropoff date
    		if ( get_option( 'ova_brw_request_booking_form_show_pickoff_date', 'yes' ) === 'yes' && $dropoff_date ) {
    			$order_detail .= '<tr>';
    				$order_detail .= '<td>'.esc_html__( 'Drop-off Date: ', 'ova-brw' ).'</td>';
    				$order_detail .= '<td>'.$dropoff_date.'</td>';
    			$order_detail .= '</tr>';
    		}

    		// Distance
    		if ( $distance ) {
    			$order_detail .= '<tr>';
    				$order_detail .= '<td>'.esc_html__( 'Distance: ', 'ova-brw' ).'</td>';
    				$order_detail .= '<td>'.$this->get_distance_text( $distance ).'</td>';
    			$order_detail .= '</tr>';
    		}

    		// Extra Time
    		if ( $extra_time ) {
    			$order_detail .= '<tr>';
    				$order_detail .= '<td>'.esc_html__( 'Extra Time: ', 'ova-brw' ).'</td>';
    				$order_detail .= '<td>'.sprintf( esc_html__( '%s hour(s)', 'ova-brw' ), $extra_time ).'</td>';
    			$order_detail .= '</tr>';
    		}

    		// Duration
	        if ( $duration ) {
	        	$order_detail .= '<tr>';
    				$order_detail .= '<td>'.esc_html__( 'Duration: ', 'ova-brw' ).'</td>';
    				$order_detail .= '<td>'.$this->get_duration_text( $duration ).'</td>';
    			$order_detail .= '</tr>';
	        }

    		// Quantity Input
    		if ( get_option( 'ova_brw_request_booking_form_show_number_vehicle', 'yes' ) === 'yes' && $qty_input ) {
    			$order_detail .= '<tr>';
    				$order_detail .= '<td>'.esc_html__( 'Quantity: ', 'ova-brw' ).'</td>';
    				$order_detail .= '<td>'.$qty_input.'</td>';
    			$order_detail .= '</tr>';
    		}

    		// Custom Checkout Fields
    		$list_fields = $this->get_custom_checkout_fields();
    		$custom_ckf         = array();
	        $custom_ckf_qty     = [];
	        $custom_ckf_save    = array();

	        if ( ! empty( $list_fields ) && is_array( $list_fields ) ) {
	            foreach ( $list_fields as $key => $field ) {
	                if ( $field['type'] === 'file' ) {
	                    $files = isset( $_FILES[$key] ) ? $_FILES[$key] : '';

	                    if ( ! empty( $files ) ) {
	                        if ( isset( $files['size'] ) && $files['size'] ) {
	                            $mb = absint( $files['size'] ) / 1048576;

	                            if ( $mb > $field['max_file_size'] ) {
	                                continue;
	                            }
	                        }

	                        $overrides = [
	                            'test_form' => false,
	                            'mimes'     => apply_filters( 'ovabrw_ft_file_mimes', [
	                                'jpg'   => 'image/jpeg',
	                                'jpeg'  => 'image/pjpeg',
	                                'png'   => 'image/png',
	                                'pdf'   => 'application/pdf',
	                                'doc'   => 'application/msword',
	                            ]),
	                        ];

	                        require_once( ABSPATH . 'wp-admin/includes/admin.php' );

	                        $upload = wp_handle_upload( $files, $overrides );

	                        if ( isset( $upload['error'] ) ) {
	                            continue;
	                        }

	                        $order_detail .= '<tr>';
	                        	$order_detail .= '<td>'.sprintf( '%s: ', esc_html( $field['label'] ) ).'</td>';
	                        	$order_detail .= '<td>';
	                        		$order_detail .= '<a href="'.esc_url( $upload['url'] ).'" title="'.esc_attr( basename( $upload['file'] ) ).'" target="_blank">'.esc_attr( basename( $upload['file'] ) ).'</a>';
	                        	$order_detail .= '</td>';
	                        $order_detail .= '</tr>';

	                        $custom_ckf_save[$key] = '<a href="'.esc_url( $upload['url'] ).'" title="'.esc_attr( basename( $upload['file'] ) ).'" target="_blank">'.esc_attr( basename( $upload['file'] ) ).'</a>';
	                    }
	                } else {
	                    $value = array_key_exists( $key, $data ) ? $data[$key] : '';

	                    if ( ! empty( $value ) && 'on' === $field['enabled'] ) {
	                        if ( 'select' === $field['type'] ) {
	                            $custom_ckf[$key] = sanitize_text_field( $value );

	                            if ( isset( $data[$key.'_qty'] ) && ! empty( $data[$key.'_qty'] ) ) {
	                                if ( isset( $data[$key.'_qty'][$value] ) && absint( $data[$key.'_qty'][$value] ) ) {
	                                    $custom_ckf_qty[$value] = absint( $data[$key.'_qty'][$value] );
	                                }
	                            }

	                            $options_key = $options_text = array();
	                            if ( ovabrw_check_array( $field, 'ova_options_key' ) ) {
	                                $options_key = $field['ova_options_key'];
	                            }

	                            if ( ovabrw_check_array( $field, 'ova_options_text' ) ) {
	                                $options_text = $field['ova_options_text'];
	                            }

	                            $key_op = array_search( $value, $options_key );

	                            if ( ! is_bool( $key_op ) ) {
	                                if ( ovabrw_check_array( $options_text, $key_op ) ) {
	                                    if ( isset( $custom_ckf_qty[$value] ) && absint( $custom_ckf_qty[$value] ) ) {
	                                        $value = $options_text[$key_op] . ' (x'.absint( $custom_ckf_qty[$value] ).')';
	                                    } else {
	                                        $value = $options_text[$key_op];
	                                    }
	                                }
	                            }
	                        }

	                        if ( 'checkbox' === $field['type'] ) {
	                            $checkbox_val = $checkbox_key = $checkbox_text = array();

	                            $custom_ckf[$key] = $value;

	                            if ( isset( $data[$key.'_qty'] ) && ! empty( $data[$key.'_qty'] ) && is_array( $data[$key.'_qty'] ) ) {
	                                $custom_ckf_qty = $custom_ckf_qty + $data[$key.'_qty'];
	                            }

	                            if ( ovabrw_check_array( $field, 'ova_checkbox_key' ) ) {
	                                $checkbox_key = $field['ova_checkbox_key'];
	                            }

	                            if ( ovabrw_check_array( $field, 'ova_checkbox_text' ) ) {
	                                $checkbox_text = $field['ova_checkbox_text'];
	                            }

	                            foreach ( $value as $val_cb ) {
	                                $key_cb = array_search( $val_cb, $checkbox_key );
	                                $qty    = isset( $custom_ckf_qty[$val_cb] ) && absint( $custom_ckf_qty[$val_cb] ) ? absint( $custom_ckf_qty[$val_cb] ) : '';

	                                if ( ! is_bool( $key_cb ) ) {
	                                    if ( ovabrw_check_array( $checkbox_text, $key_cb ) ) {
	                                        if ( $qty ) {
	                                            array_push( $checkbox_val , $checkbox_text[$key_cb] . ' (x'.$qty.')' );
	                                        } else {
	                                            array_push( $checkbox_val , $checkbox_text[$key_cb] );
	                                        }
	                                    }
	                                }
	                            }

	                            if ( ! empty( $checkbox_val ) && is_array( $checkbox_val ) ) {
	                                $value = join( ", ", $checkbox_val );
	                            }
	                        }

	                        if ( 'radio' === $field['type'] ) {
	                            $custom_ckf[$key] = sanitize_text_field( $value );

	                            if ( isset( $data[$key.'_qty'] ) && ! empty( $data[$key.'_qty'] ) ) {
	                                $qty = isset( $data[$key.'_qty'][$custom_ckf[$key]] ) && absint( $data[$key.'_qty'][$custom_ckf[$key]] ) ? absint( $data[$key.'_qty'][$custom_ckf[$key]] ) : 1;
	                                $custom_ckf_qty[$key] = $qty;

	                                $value .= ' (x'.$qty.')';
	                            }
	                        }

	                        $order_detail .= '<tr>';
	                        	$order_detail .= '<td>'.sprintf( '%s: ', esc_html( $field['label'] ) ).'</td>';
	                        	$order_detail .= '<td>'.esc_html( $value ).'</td>';
	                        $order_detail .= '</tr>';

	                        $custom_ckf_save[$key] = $value;
	                    }
	                }
	            }
	        }

    		// Resources
	        $resources          = array();
	        $resource_names     = array();
	        $resource_checkboxs = isset( $data['ovabrw_resource_checkboxs'] ) ? $data['ovabrw_resource_checkboxs'] : [];
	        $resource_qty       = isset( $data['ovabrw_resource_quantity'] ) ? $data['ovabrw_resource_quantity'] : [];

	        if ( $this->is_array_exists( $resource_checkboxs ) ) {
	            $resource_ids 	= $this->get_value( 'resource_id', [] );
	            $resource_name 	= $this->get_value( 'resource_name', [] );

	            foreach ( $resource_checkboxs as $rs_id ) {
	                $rs_key = array_search( $rs_id, $resource_ids );
	                
	                if ( ! is_bool( $rs_key ) ) {
	                    $rs_name = isset( $resource_name[$rs_key] ) ? $resource_name[$rs_key] : '';

	                    if ( isset( $resource_qty[$rs_id] ) && absint( $resource_qty[$rs_id] ) ) {
	                        $rs_name .= ' (x'.absint( $resource_qty[$rs_id] ).')';
	                    }

	                    $resources[$rs_id] = $rs_name;
	                    array_push( $resource_names, $rs_name );
	                }
	            }
	        }

    		if ( get_option( 'ova_brw_request_booking_form_show_extra_service', 'yes' ) === 'yes' && $this->is_array_exists( $resource_names ) ) {
    			$order_detail .= '<tr>';
    				if ( count( $resource_names ) === 1 ) {
    					$order_detail .= '<td>'.esc_html__( 'Resource: ', 'ova-brw' ).'</td>';
    				} else {
    					$order_detail .= '<td>'.esc_html__( 'Resources: ', 'ova-brw' ).'</td>';
    				}
    				$order_detail .= '<td>'.implode( ', ', $resource_names ).'</td>';
    			$order_detail .= '</tr>';
    		}

    		// Services
    		$service_str 	= '';
        	$services_qty 	= [];
        	$services 		= isset( $data['ovabrw_service'] ) ? $data['ovabrw_service'] : [];
	        $ser_qty 		= isset( $data['ovabrw_service_qty'] ) ? $data['ovabrw_service_qty'] : [];

	        if ( $this->is_array_exists( $services ) ) {
	        	$serv_labels 	= $this->get_value( 'label_service', [] );
	        	$serv_ids 		= $this->get_value( 'service_id', [] );
	        	$serv_names 	= $this->get_value( 'service_name', [] );

	        	foreach ( $services as $ser_id ) {
	        		if ( isset( $ser_qty[$ser_id] ) && absint( $ser_qty[$ser_id] ) ) {
	                    $services_qty[$ser_id] = absint( $ser_qty[$ser_id] );
	                }

	        		if ( $this->is_array_exists( $serv_ids ) ) {
	        			foreach ( $serv_ids as $i => $ids ) {
	        				$serv_label = isset( $serv_labels[$i] ) ? $serv_labels[$i] : '';

	        				$option_index = array_search( $ser_id, $ids );

	        				if ( is_bool( $option_index ) ) continue;

	        				$serv_name = isset( $serv_names[$i][$option_index] ) ? $serv_names[$i][$option_index] : '';

	        				$service_str .= '<tr>';
                            $service_str .= '<td>'.$serv_label.':</td>';

                            if ( isset( $services_qty[$ser_id] ) && absint( $services_qty[$ser_id] ) ) {
                                $service_str .= '<td>'.$serv_name.' (x'.absint( $services_qty[$ser_id] ).')'.'</td>';
                            } else {
                                $service_str .= '<td>'.$serv_name.'</td>';
                            }

                            $service_str .= '</tr>';
	        			}
	        		}
	        	}
	        }

    		if ( get_option( 'ova_brw_request_booking_form_show_service', 'yes' ) === 'yes' ) {
    			$order_detail .= $service_str;
    		}

	        // Customer note
	        if ( get_option( 'ova_brw_request_booking_form_show_extra_info', 'yes' ) === 'yes' && $customer_note ) {
	        	$order_detail .= '<tr>';
    				$order_detail .= '<td>'.esc_html__( 'Extra: ', 'ova-brw' ).'</td>';
    				$order_detail .= '<td>'.$customer_note.'</td>';
    			$order_detail .= '</tr>';
	        }

        	$order_detail .= '</table>';

        	$body = get_option( 'ova_brw_request_booking_mail_content' );

        	if ( ! $body ) {
        		$body = esc_html__( 'You have hired a vehicle: [ovabrw_vehicle_name] at [ovabrw_order_pickup_date] - [ovabrw_order_pickoff_date]. [ovabrw_order_details]', 'ova-brw' );
        	}

        	// Product link
        	$product_link = '<a href="'.get_permalink($this->ID).'" target="_blank">'.$product_name.'</a>';

        	// Replace body
        	$body = str_replace( '[ovabrw_vehicle_name]', $product_link, $body );
        	$body = str_replace( '[ovabrw_order_pickup_date]', $pickup_date, $body );
        	$body = str_replace( '[ovabrw_order_pickoff_date]', $dropoff_date, $body );
        	$body = str_replace( '[ovabrw_order_details]', $order_detail, $body );

        	// Create Order
        	if ( get_option( 'ova_brw_request_booking_create_order', 'no' ) === 'yes' ) {
        		$order_data = [
        			'customer_name' 		=> $customer_name,
        			'customer_email' 		=> $customer_email,
        			'customer_phone' 		=> $customer_phone,
        			'customer_address' 		=> $customer_address,
        			'customer_note' 		=> $customer_note,
        			'pickup_location' 		=> $pickup_location,
        			'dropoff_location' 		=> $dropoff_location,
        			'waypoints' 			=> $waypoints,
        			'pickup_date' 			=> $pickup_date,
        			'dropoff_date' 			=> $dropoff_date,
        			'check_in' 				=> $new_date['pickup_date_new'],
        			'check_out' 			=> $new_date['dropoff_date_new'],
        			'duration_map' 			=> $duration_map,
        			'duration' 				=> $duration,
        			'distance' 				=> $distance,
        			'extra_time' 			=> $extra_time,
        			'quantity' 				=> $qty_input,
        			'custom_ckf' 			=> $custom_ckf,
        			'custom_ckf_qty' 		=> $custom_ckf_qty,
        			'custom_ckf_save' 		=> $custom_ckf_save,
        			'resources' 			=> $resources,
        			'resources_qty' 		=> $resource_qty,
        			'ovabrw_service' 		=> $services,
        			'ovabrw_service_qty' 	=> $services_qty,
        		];

	            $order_id = $this->request_booking_create_new_order( $order_data );
	        }

			do_action( 'ovabrw_after_request_booking_get_mail_body', $data, $this );

			return apply_filters( 'ovabrw_request_booking_get_mail_body', $body, $data, $this );
		}

		public function request_booking_create_new_order( $data = [] ) {
			do_action( 'ovabrw_before_request_booking_create_new_order', $data, $this );

			if ( ! $this->is_array_exists( $data ) ) return false;

        	// Add Cart item
	        $cart_item = [
	        	'ovabrw_checkin' 			=> $data['check_in'],
	        	'ovabrw_checkout' 			=> $data['check_out'],
	        	'distance' 					=> $data['distance'],
	        	'extra_time' 				=> $data['extra_time'],
	        	'ovabrw_pickup_loc' 		=> $data['pickup_location'],
	        	'ovabrw_pickoff_loc' 		=> $data['dropoff_location'],
	        	'ovabrw_number_vehicle' 	=> $data['quantity'],
	        	'custom_ckf' 				=> $data['custom_ckf'],
	        	'custom_ckf_qty' 			=> $data['custom_ckf_qty'],
	        	'resources' 				=> $data['resources'],
	        	'resources_qty' 			=> $data['resources_qty'],
	        	'ovabrw_service' 			=> $data['ovabrw_service'],
	        	'ovabrw_service_qty' 		=> $data['ovabrw_service_qty'],
	        	'ovabrw_amount_insurance' 	=> intval( $data['quantity'] ) * floatval( $this->get_value( 'amount_insurance' ) ),
	        ];

	        $line_total = ovabrw_convert_price( $this->get_total( $cart_item ) );
	        $insurance 	= ovabrw_convert_price( floatval( $cart_item['ovabrw_amount_insurance'] ) );

	        // Create Order
	        $args = array(
	            'status'        => '',
	            'customer_note' => $data['customer_note'],
	        );
	        
	        $order      = wc_create_order( $args ); // Create new order
	        $order_id   = $order->get_id(); // Get order id
	        $products   = wc_get_product( $this->ID );

	        // Tax
	        if ( wc_tax_enabled() && wc_prices_include_tax() ) {
	        	$tax_rates 	= WC_Tax::get_rates( $products->get_tax_class() );
	        	$incl_tax 	= WC_Tax::calc_inclusive_tax( $line_total, $tax_rates );
                $line_total -= round( array_sum( $incl_tax ), wc_get_price_decimals() ); 
	        }

	        // Add product to order
	        $order->add_product( $products, $data['quantity'], array( 'total' => $line_total ) );

	        // Order Item
	        $order_items = $order->get_items();

	        if ( $this->is_array_exists( $order_items ) ) {
	        	foreach ( $order_items as $item_id => $product ) {
	        		$item = WC_Order_Factory::get_order_item( absint( $item_id ) );

		            if ( ! $item ) continue;

		            $data_item  = array();

		            // Rental Type
			        $data_item['rental_type'] 	= $this->type;
			        $data_item['define_day'] 	= $this->get_value( 'define_1_day' );

			        // Pickup location
			        $data_item['ovabrw_pickup_loc'] = $data['pickup_location'];

			        // Waypoints
			        if ( $this->is_array_exists( $data['waypoints'] ) ) {
			        	foreach ( $data['waypoints'] as $k => $address ) {
			        		$data_item[sprintf( esc_html__( 'Waypoint %s', 'ova_brw' ), $k + 1 )] = $address;
			            }
			        }

			        // Dropoff location
			        $data_item['ovabrw_pickoff_loc'] = $data['dropoff_location'];

			        // Pickup & Dropoff dates
			        $data_item['ovabrw_pickup_date'] 	= $data['pickup_date'];
			        $data_item['ovabrw_pickoff_date'] 	= $data['dropoff_date'];

			        // Real pickup & dropoff dates
			        $data_item['ovabrw_pickup_date_real'] 	= $data['pickup_date'];
			        $data_item['ovabrw_pickoff_date_real'] 	= $data['dropoff_date'];

			        // Quantity
			        $data_item['ovabrw_number_vehicle'] = $data['quantity'];

			        // Real Quantity & Price
			        $regular_price = floatval( $this->get_value( 'regul_price_taxi' ) );
		        	$data_item['ovabrw_total_days'] 	= $data['quantity'];
		        	$data_item['ovabrw_price_detail'] 	= ovabrw_wc_price( OVABRW_Get_Data::instance()->get_price_include_tax( $this->ID, $regular_price ) );

		        	// Distance
		        	$data_item['ovabrw_distance'] = $this->get_distance_text( $data['distance'] );

		            // Extra Time
		            $data_item['ovabrw_extra_time'] = sprintf( esc_html__( '%s hour(s)', 'ova-brw' ), $data['extra_time'] );

		            // Duration
		            $data_item['ovabrw_duration'] = $this->get_duration_text( $data['duration'] );

		        	// Custom Checkout Fields
		        	if ( $this->is_array_exists( $data['custom_ckf'] ) ) {
		                $data_item[ 'ovabrw_custom_ckf' ] = $data['custom_ckf'];

		                if ( $this->is_array_exists( $data['custom_ckf_qty'] ) ) {
		                	$data_item[ 'ovabrw_custom_ckf_qty' ] = $data['custom_ckf_qty'];
		                }

		                if ( $this->is_array_exists( $data['custom_ckf_save'] ) ) {
			                foreach ( $data['custom_ckf_save'] as $k => $val ) {
			                    $data_item[$k] = $val;
			                }
			            }
		            }

		            // Resources
			        if ( $this->is_array_exists( $data['resources'] ) ) {
			            $resources_name = $data['resources'];

			            if ( $this->is_array_exists( $data['resources_qty'] ) ) {
			                foreach ( $resources_name as $k => $v ) {
			                    if ( isset( $data['resources_qty'][$k] ) && absint( $data['resources_qty'][$k] ) ) {
			                        $resources_name[$k] = $v.' (x'.absint( $data['resources_qty'][$k] ).')';
			                    }
			                }
			            }

			            if ( count( $data['resources'] ) == 1 ) {
			            	$data_item[esc_html__( 'Resource', 'ova-brw' )] = join( ', ', $resources_name );
			            } else {
			            	$data_item[esc_html__( 'Resources', 'ova-brw' )] = join( ', ', $resources_name );
			            }

			            $data_item['ovabrw_resources']      = $data['resources'];
                		$data_item['ovabrw_resources_qty']  = $data['resources_qty'];
			        }

			        // Services
			        if ( $this->is_array_exists( $data['ovabrw_service'] ) ) {
			        	$services 		= $data['ovabrw_service'];
			        	$services_qty 	= $data['ovabrw_service_qty'];

			        	$data_item['ovabrw_services'] 		= $services;
			        	$data_item['ovabrw_services_qty'] 	= $services_qty;

			        	if ( $this->is_array_exists( $services ) ) {
			        		$serv_labels 	= $this->get_value( 'label_service', [] );
			        		$serv_ids 		= $this->get_value( 'service_id', [] );
			        		$serv_names 	= $this->get_value( 'service_name', [] );

			        		foreach ( $services as $k ) {
					    		if ( $this->is_array_exists( $serv_ids ) ) {
					    			$qty = isset( $services_qty[$k] ) ? $services_qty[$k] : '';

					    			foreach ( $serv_ids as $i => $ids ) {
					    				$option_index = array_search( $k, $ids );

					        			if ( is_bool( $option_index ) ) continue;

					        			$name   = isset( $serv_names[$i][$option_index] ) ? $serv_names[$i][$option_index] : '';
		                                $label  = isset( $serv_labels[$i] ) ? $serv_labels[$i] : '';

		                                if ( $qty ) {
		                                    $name .= ' (x'.absint( $qty ).')';
		                                }

		                                $data_item[$label] = $name;
					    			}
					    		}
					    	}
			        	}
			        }

			        // Insurance
			        if ( $insurance ) {
		                $data_item[ 'ovabrw_amount_insurance_product' ] = $insurance;
		            }

		            // Add item
		            foreach ( $data_item as $meta_key => $meta_value ) {
		                wc_add_order_item_meta( $item_id, $meta_key, $meta_value );
		            }

		            // Update item meta
		            $item->set_props(
		                array(
		                    'total'     => $line_total,
		                    'subtotal'  => $line_total,
		                )
		            );

		            $item->save();
	        	}
	        }

	        // Insurace
	        $order->update_meta_data( '_ova_insurance_amount' , $insurance );

	        // Address
	        $billing = [
	        	'first_name' => $data['customer_name'],
                'last_name'  => '',
                'company'    => '',
                'email'      => $data['customer_email'],
                'phone'      => $data['customer_phone'],
                'address_1'  => $data['customer_address'],
                'address_2'  => '',
                'city'       => '',
                'country'    => '',
	        ];

	        $order->set_address( $billing, 'billing' );

	        // Set Order Status
	        $status_order = get_option( 'ova_brw_request_booking_order_status', 'wc-on-hold' );
	        $order->set_status( $status_order );

	        // Set date created
	        $order->set_date_created( date( 'Y-m-d H:i:s', current_time( 'timestamp' ) ) );

	        // Set Tax
	        $order->calculate_totals( wc_tax_enabled() );

	        // Save
	        $order->save();

	        do_action( 'ovabrw_after_request_booking_create_new_order', $data, $order, $this );

	        return apply_filters( 'ovabrw_request_booking_create_new_order', $order_id, $data, $this );
		}
		// End

		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}

			return self::$_instance;
		}
	}
}